﻿Imports XSP
Imports XCM

''' ---------------------------------------------
''' <summary>
''' 医療費明細一覧
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public Class MEN020F050

#Region "コンスタント"

	'修正ボタンの参照モード時表記
	Private Const CST_F4_BUTTONFACE_REFERENCE As String = "参照" & vbNewLine & "(F4)"
	'グリッド名
	Private Const COL_MED_COST_DATE As String = "c01008MEN020F050"	'日付
	Private Const COL_SERIAL_NO As String = "c02008MEN020F050"		'連番
	'子画面ID
	Private Const CST_SHOW_MEN020F060_ID As String = "MEN020F060"

#End Region

#Region "変数"

	Private pMedCostDetails As SortedList	'医療費明細情報
	Private pDateSt As String				'範囲開始日
	Private pDateEd As String				'範囲終了日

	Private pMedCostScrMode As clsMENCOMMON.Enum_MedCostScrMode		'医療費登録画面動作モード

	Private pDateWk As Date					'一覧中選択行の日付
	Private pSerialNoWk As Integer			'一覧中選択行の連番

	Private updFlg As Boolean = False		'更新フラグ

	Private frmMEN020F060 As MEN020F060 = Nothing					'遷移先画面(医療費明細登録画面)

#End Region

#Region "コンストラクタ"

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ（入退院明細モード）
	''' </summary>
	''' <param name="execMode">処理モード</param>
	''' <param name="patientNo">患者番号</param>
	''' <param name="historyNo">入退院歴番号</param>
	''' <param name="dateSt">範囲開始日</param>
	''' <param name="dateEd">範囲終了日</param>
	''' <param name="medCostDetails">医療費明細情報</param>
	''' <remarks>
	''' 2010/12/06 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New(ByVal execMode As Enum_ExeMode, ByVal patientNo As String, ByVal historyNo As Integer, _
	ByVal dateSt As String, ByVal dateEd As String, ByVal medCostDetails As ArrayList)
		' この呼び出しはデザイナーで必要です。
		InitializeComponent()

		' InitializeComponent() 呼び出しの後で初期化を追加します。
		Me.ExeMode = execMode					'処理モード
		Me.HistoryMode = Enum_HistMode.eHSP		'歴モード＝「入退院」
		Me.PatientNo = patientNo				'患者番号
		Me.HspHistoryNo = historyNo				'入退院歴番号
		Me.ChNo = 0								'科歴番号

		Me.pDateSt = dateSt						'範囲開始日
		Me.pDateEd = dateEd						'範囲終了日
		Me.MedCostDetails = medCostDetails		'医療費明細情報

		Me.pMedCostScrMode = clsMENCOMMON.Enum_MedCostScrMode.eHspDetailMode	'医療費登録画面動作モード
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ（科歴明細モード）
	''' </summary>
	''' <param name="execMode">処理モード</param>
	''' <param name="patientNo">患者番号</param>
	''' <param name="historyNo">入退院歴番号</param>
	''' <param name="chNo">科歴番号</param>
	''' <param name="dateSt">範囲開始日</param>
	''' <param name="dateEd">範囲終了日</param>
	''' <param name="medCostDetails">医療費明細情報</param>
	''' <remarks>
	''' 2010/12/06 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New(ByVal execMode As Enum_ExeMode, ByVal patientNo As String, ByVal historyNo As Integer, ByVal chNo As Integer, _
	ByVal dateSt As String, ByVal dateEd As String, ByVal medCostDetails As ArrayList)
		' この呼び出しはデザイナーで必要です。
		InitializeComponent()

		' InitializeComponent() 呼び出しの後で初期化を追加します。
		Me.ExeMode = execMode				'処理モード
		Me.HistoryMode = Enum_HistMode.eCH	'歴モード＝「科歴」
		Me.PatientNo = patientNo			'患者番号
		Me.HspHistoryNo = historyNo			'入退院歴番号
		Me.ChNo = chNo						'科歴番号

		Me.pDateSt = dateSt					'範囲開始日
		Me.pDateEd = dateEd					'範囲終了日
		Me.MedCostDetails = medCostDetails	'医療費明細情報

		Me.pMedCostScrMode = clsMENCOMMON.Enum_MedCostScrMode.eChDetailMode	'医療費登録画面動作モード
	End Sub

#End Region

#Region "プロパティ"

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報（プロパティ）
	''' </summary>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Property MedCostDetails() As ArrayList
		Get
			If pMedCostDetails Is Nothing OrElse pMedCostDetails.Count = 0 Then
				Return Nothing
			Else
				Return New ArrayList(pMedCostDetails.Values)
			End If
		End Get
		Set(ByVal value As ArrayList)
			If value Is Nothing Then
				pMedCostDetails = Nothing
			Else
				pMedCostDetails = New SortedList
				For Each rec As datMTI_MED_COST_DETAILS_PLUS_OneRec In value
					Me.MedCostDetails(rec.PATIENT_NO, rec.MED_COST_DATE, rec.SERIAL_NO) = rec
				Next
			End If
		End Set
	End Property

	''' ---------------------------------------------
	''' <summary>
	''' 医療費明細情報取得（プロパティ）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <param name="pSerialNo">連番</param>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Property MedCostDetails(ByVal pPatientNo As String, ByVal pMedCostDate As Date, ByVal pSerialNo As Integer) As datMTI_MED_COST_DETAILS_PLUS_OneRec
		Get
			Dim datKey As datMTI_MED_COST_DETAILS_KeyRec
			Try
				Select Case False
					Case Not String.IsNullOrEmpty(pPatientNo)
					Case Not pMedCostDate.Equals(Nothing)
					Case pSerialNo > 0
					Case Else
						datKey = New datMTI_MED_COST_DETAILS_KeyRec
						datKey.PATIENT_NO = pPatientNo
						datKey.MED_COST_DATE = pMedCostDate
						datKey.SERIAL_NO = pSerialNo
						If pMedCostDetails IsNot Nothing AndAlso pMedCostDetails.ContainsKey(datKey) Then
							Return pMedCostDetails(datKey)
						End If
				End Select
				Return Nothing
			Catch ex As Exception
				Throw
			Finally
				datKey = Nothing
			End Try
		End Get
		Set(ByVal value As datMTI_MED_COST_DETAILS_PLUS_OneRec)
			Dim datKey As datMTI_MED_COST_DETAILS_KeyRec
			Try
				Select Case False
					Case Not String.IsNullOrEmpty(pPatientNo)
					Case Not pMedCostDate.Equals(Nothing)
					Case pSerialNo > 0
					Case Else
						datKey = New datMTI_MED_COST_DETAILS_KeyRec
						datKey.PATIENT_NO = Me.PatientNo
						datKey.MED_COST_DATE = pMedCostDate
						datKey.SERIAL_NO = pSerialNo
						If value Is Nothing Then
							If pMedCostDetails IsNot Nothing AndAlso pMedCostDetails.ContainsKey(datKey) Then
								pMedCostDetails.Remove(datKey)
							End If
						Else
							If pMedCostDetails Is Nothing Then
								pMedCostDetails = New SortedList
							End If
							If pMedCostDetails.ContainsKey(datKey) Then
								pMedCostDetails(datKey) = value
							Else
								pMedCostDetails.Add(datKey, value)
							End If
						End If
				End Select
			Catch ex As Exception
				Throw
			Finally
				datKey = Nothing
			End Try
		End Set
	End Property

	''' ---------------------------------------------
	''' <summary>
	''' 連番の最大値取得（プロパティ）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pMedCostDate">日付</param>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private ReadOnly Property MaxSerialNo(ByVal pPatientNo As String, ByVal pMedCostDate As Date) As Integer
		Get
			Dim retVal As Integer = 0
			Dim datKey As datMTI_MED_COST_DETAILS_KeyRec
			Try
				Select Case False
					Case Not String.IsNullOrEmpty(pPatientNo)
					Case Not pMedCostDate.Equals(Nothing)
					Case pMedCostDetails IsNot Nothing
					Case Else
						datKey = New datMTI_MED_COST_DETAILS_KeyRec
						datKey.PATIENT_NO = pPatientNo
						datKey.MED_COST_DATE = pMedCostDate
						datKey.SERIAL_NO = 0
						Do
							retVal = datKey.SERIAL_NO
							datKey.SERIAL_NO = retVal + 1
						Loop While pMedCostDetails.ContainsKey(datKey)
						Return retVal
				End Select
				Return 0
			Catch ex As Exception
				Throw
			Finally
				datKey = Nothing
			End Try
		End Get
	End Property

#End Region

#Region "イベント"

	''' ---------------------------------------------
	''' <summary>
	''' 画面終了時イベント
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/12/08 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub MEN020F050_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
		log(clsSysMst.logLevel.NRM, "MEN020F050_FormClosing", "画面終了時イベント Start")
		Try
			' 画面途中でエラーの場合は処理しない
			If Me.LoadError OrElse e.Cancel Then
				Exit Try
			End If
		Catch ex As Exception
			e.Cancel = True		'エラー時は画面を閉じない
			Me.ErrorProc(ex)
		Finally
			' 変数の解放は ClosedProc に記述する
			Me.ClosedProc(e.Cancel)
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 画面ロード時イベント
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/12/06 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub MEN020F050_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
		If Me.DesignMode OrElse Me.LoadError Then
			Exit Sub
		End If
		log(clsSysMst.logLevel.NRM, "MEN020F050_Load", "画面ロード時イベント Start")
		Dim cliGridStyle As clsGridStyle
		Try
			'処理モード「参照」の場合
			If Me.ExeMode = Enum_ExeMode.eReference Then
				'医療費日付入力パネル非表示
				Me.pnl001MEN020F050.Visible = False
				'削除ボタン非表示
				Me.btn013MEN000F010.Visible = False
				'修正ボタンの表記を「参照」に変更
				Me.btn012MEN000F010.Text = CST_F4_BUTTONFACE_REFERENCE
			End If
			' グリッド１行の高さを設定
			cliGridStyle = New clsGridStyle
			cliGridStyle.setGridHeight(Me.dgv008MEN020F050)
			' グリッド行の自動追加は許可しない
			Me.dgv008MEN020F050.AutoGenerateColumns = False
			'選択行のキーを初期化
			Me.pDateWk = Nothing
			Me.pSerialNoWk = Nothing
		Catch ex As Exception
			Me.ErrorProc(ex)
			Me.EndProc4Load()
		Finally
			cliGridStyle = Nothing
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 画面初回起動時イベント
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/12/06 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub MEN020F050_Shown(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Shown
		If Me.DesignMode OrElse Me.LoadError Then
			Exit Sub
		End If
		log(clsSysMst.logLevel.NRM, "MEN020F050_Shown", "画面初回起動時イベント Start")
		Dim arLastValueCtl As ArrayList = Nothing
		Try
			arLastValueCtl = New ArrayList
			'前回値取得コントロール
			arLastValueCtl.Add(Me.rdo006MEN020F050.Name)	'個人情報・有り
			arLastValueCtl.Add(Me.rdo007MEN020F050.Name)	'個人情報・無し
			If arLastValueCtl.Count > 0 Then
				Me.LastValueCtls = arLastValueCtl.ToArray(GetType(String))
			End If
			Me.LoadLastValue(Me.LastValueCtls)
			Me.rdo006MEN020F050.TabStop = False
			Me.rdo007MEN020F050.TabStop = False
			'画面の再描画を行う。
			Me.repaint()
		Catch ex As Exception
			Me.ErrorProc(ex)
			Me.EndProc4Shown()
		Finally
			arLastValueCtl = Nothing
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 「医療費明細情報一覧」ダブルクリック時イベント
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/12/09 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub dgv008MEN020F050_CellDoubleClick(ByVal sender As Object, ByVal e As System.Windows.Forms.DataGridViewCellEventArgs) Handles dgv008MEN020F050.CellDoubleClick
		log(clsSysMst.logLevel.NRM, "dgv008MEN020F050_CellDoubleClick", "「医療費明細情報一覧」ダブルクリック時イベント Start")
		Try
			If e.RowIndex < 0 Then
				Exit Sub
			End If
			'医療費明細登録画面表示
			Me.dspMedCostDetails()
		Catch ex As Exception
			Me.ErrorProc(ex)
		End Try
	End Sub

#End Region

#Region "メソッド"

	''' -------------------------------------------------------
	''' <summary>
	''' 医療費明細登録画面表示処理
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Private Function dspMedCostDetails() As Boolean
		log(clsSysMst.logLevel.DBG, "dspMedCostDetails", "医療費明細登録画面表示処理 Start")
		Dim sMedCostDate As Date = Nothing
		Dim iSerialNo As Integer = 0
		Dim selMedCostDetails As datMTI_MED_COST_DETAILS_PLUS_OneRec
		Try
			selMedCostDetails = New datMTI_MED_COST_DETAILS_PLUS_OneRec
			With Me.dgv008MEN020F050
				If .SelectedRows Is Nothing Then
					'選択行が無い場合終了
					Return False
				End If
				'一覧のキーで内部変数から取得
				For Each row As DataGridViewRow In .SelectedRows
					sMedCostDate = row.Cells(COL_MED_COST_DATE).Value
					iSerialNo = row.Cells(COL_SERIAL_NO).Value
					Exit For
				Next
				selMedCostDetails = Me.MedCostDetails(Me.PatientNo, sMedCostDate, iSerialNo)
				If selMedCostDetails Is Nothing Then
					'選択行が無い場合終了
					Return False
				End If
				'画面遷移
				frmMEN020F060 = Nothing
				Select Case Me.pMedCostScrMode
					Case clsMENCOMMON.Enum_MedCostScrMode.eHspDetailMode	'入退院明細モードの場合
						frmMEN020F060 = New MEN.MEN020F060(Me.ExeMode, Me.PatientNo, Me.HspHistoryNo, selMedCostDetails)
						Me.nextForm(frmMEN020F060)
					Case clsMENCOMMON.Enum_MedCostScrMode.eChDetailMode		'科歴明細モードの場合
						frmMEN020F060 = New MEN.MEN020F060(Me.ExeMode, Me.PatientNo, Me.HspHistoryNo, Me.ChNo, selMedCostDetails)
						Me.nextForm(frmMEN020F060)
					Case Else
						Return False
				End Select
			End With
			Return True
		Catch ex As Exception
			Throw
		Finally
			selMedCostDetails = Nothing
		End Try
	End Function

#End Region

#Region "オーバーライドメソッド"

	''' -------------------------------------------------------
	''' <summary>
	''' 画面再描画
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Sub repaint()
		log(clsSysMst.logLevel.DBG, "repaint", "画面再描画 Start")
		Dim listDataTbl As DataTable
		Dim addRow As DataRow = Nothing
		Dim wkStDate As Date
		Dim wkEdDate As Date
		Try
			'医療費明細情報一覧にデータをセットする。
			'列の設定
			listDataTbl = New DataTable
			listDataTbl.Columns.Add(sqlMTI_MED_COST_DETAILS.itmMED_COST_DATE, GetType(Date))		'日付
			listDataTbl.Columns.Add(sqlMTI_MED_COST_DETAILS.itmSERIAL_NO, GetType(Integer))			'連番
			listDataTbl.Columns.Add(sqlMTI_MED_COST_DETAILS.itmDEPT_NM, GetType(String))			'診療科名
			listDataTbl.Columns.Add(sqlMTI_MED_COST_DETAILS.itmDATA_CAPTURE_DT, GetType(Date))		'データ取込日
			listDataTbl.Columns.Add(sqlMTI_MED_COST_DETAILS.itmLASTUPD_DT, GetType(Date))			'最終更新日
			If Me.MedCostDetails IsNot Nothing Then
				For Each rec As datMTI_MED_COST_DETAILS_PLUS_OneRec In Me.MedCostDetails
					Select Case True
						Case Not Date.TryParse(Me.pDateSt, wkStDate)
							' 範囲開始日が未設定の場合、全て表示する
							Exit Select
						Case wkStDate > rec.MED_COST_DATE
							' 範囲開始日＞医療費日付の場合、読み飛ばし
							Continue For
						Case Date.TryParse(Me.pDateEd, wkEdDate) AndAlso rec.MED_COST_DATE > wkEdDate
							' 医療費日付＞範囲終了日の場合、読み飛ばし
							Continue For
						Case Else
					End Select
					addRow = listDataTbl.NewRow()
					addRow(sqlMTI_MED_COST_DETAILS.itmMED_COST_DATE) = rec.MED_COST_DATE
					addRow(sqlMTI_MED_COST_DETAILS.itmSERIAL_NO) = rec.SERIAL_NO
					addRow(sqlMTI_MED_COST_DETAILS.itmDEPT_NM) = rec.DEPT_NM
					addRow(sqlMTI_MED_COST_DETAILS.itmDATA_CAPTURE_DT) = rec.DATA_CAPTURE_DT
					addRow(sqlMTI_MED_COST_DETAILS.itmLASTUPD_DT) = rec.LASTUPD_DT
					listDataTbl.Rows.Add(addRow)
				Next
			End If
			Me.dgv008MEN020F050.DataSource = listDataTbl
			'保持している日付、連番と一致する行を選択（一致しない場合は先頭行を選択）
			With Me.dgv008MEN020F050
				If .RowCount > 0 Then
					'先に先頭を選択しておく
					.Rows(0).Selected = True
					.Rows(0).Cells(0).Selected = True
					Select Case True
						Case Me.pDateWk.Equals(Nothing)
						Case Me.pSerialNoWk = 0
						Case Else
							For i As Integer = 0 To .RowCount - 1
								If .Rows(i).Cells(COL_MED_COST_DATE).Value = Me.pDateWk AndAlso .Rows(i).Cells(COL_SERIAL_NO).Value = Me.pSerialNoWk Then
									.Rows(i).Selected = True
									.Rows(i).Cells(0).Selected = True
									.FirstDisplayedScrollingRowIndex = i
									.Refresh()
									Exit For
								End If
							Next
					End Select
					'フォーカスの設定（医療費明細情報一覧）
					.Focus()
				Else
					'フォーカスの設定（医療費日付入力欄）
					Me.dte003MEN020F050.Focus()
				End If
			End With
			'医療費日付欄をクリア
			Me.dte003MEN020F050.DateValue = Nothing
		Catch ex As Exception
			Throw
		Finally
			listDataTbl = Nothing
			addRow = Nothing
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 確認メッセージを表示しない（更新前確認メッセージ）
	''' </summary>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overrides Function PreUpdConfirm() As MsgBoxResult
		log(clsSysMst.logLevel.DBG, "PreUpdConfirm", "更新前確認メッセージ Start")
		Try
			If Me.updFlg Then
				Return MsgBoxResult.Yes
			Else
				Return MsgBoxResult.No
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 更新処理
	''' </summary>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function UpdProc() As Boolean
		log(clsSysMst.logLevel.DBG, "UpdProc", "更新処理 Start")
		Try
			'戻り値セット
			Me.ReturnValue = Me.MedCostDetails
			Me.FormReturn = Enum_FormReturn.OK
			Return True
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 追加処理
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function FuncAddProc() As Boolean
		log(clsSysMst.logLevel.DBG, "FuncAddProc", "追加処理 Start")
		Dim newMedCostDetails As datMTI_MED_COST_DETAILS_PLUS_OneRec
		Dim wkDate As Date
		Dim wkStDate As Date
		Dim wkEdDate As Date
		Try
			Select Case True
				Case Not Date.TryParse(Me.dte003MEN020F050.DisplayText, wkDate)
					' 医療費日付が未入力の場合、エラーメッセージを出力し処理を抜ける。
					Me.showMsg("E0020", "日付を入力", Nothing)
					If Me.dte003MEN020F050.ContainsFocus Then
						' 医療費日付にフォーカスがある場合、一旦グリッドに退避
						Me.dgv008MEN020F050.Focus()
					End If
					Me.dte003MEN020F050.Focus()
					Return False
				Case Not Date.TryParse(Me.pDateSt, wkStDate) OrElse wkStDate > wkDate
					' 範囲開始日＞医療費日付の場合、エラーメッセージを出力し処理を抜ける。
					Me.showMsg("E0022", "有効", Nothing)
					If Me.dte003MEN020F050.ContainsFocus Then
						' 医療費日付にフォーカスがある場合、一旦グリッドに退避
						Me.dgv008MEN020F050.Focus()
					End If
					Me.dte003MEN020F050.Focus()
					Return False
				Case Date.TryParse(Me.pDateEd, wkEdDate) AndAlso wkDate > wkEdDate
					' 医療費日付＞範囲終了日の場合、エラーメッセージを出力し処理を抜ける。
					Me.showMsg("E0022", "有効", Nothing)
					If Me.dte003MEN020F050.ContainsFocus Then
						' 医療費日付にフォーカスがある場合、一旦グリッドに退避
						Me.dgv008MEN020F050.Focus()
					End If
					Me.dte003MEN020F050.Focus()
					Return False
				Case Else
			End Select

			'新規明細データ作成
			newMedCostDetails = New datMTI_MED_COST_DETAILS_PLUS_OneRec
			With newMedCostDetails
				.PATIENT_NO = Me.PatientNo
				.MED_COST_DATE = wkDate
				.SERIAL_NO = Me.MaxSerialNo(.PATIENT_NO, .MED_COST_DATE) + 1
			End With
			'画面遷移
			frmMEN020F060 = Nothing
			Select Case Me.pMedCostScrMode
				Case clsMENCOMMON.Enum_MedCostScrMode.eHspDetailMode	'入退院明細モードの場合
					frmMEN020F060 = New MEN.MEN020F060(Me.ExeMode, Me.PatientNo, Me.HspHistoryNo, newMedCostDetails)
					Me.nextForm(frmMEN020F060)
				Case clsMENCOMMON.Enum_MedCostScrMode.eChDetailMode		'科歴明細モードの場合
					frmMEN020F060 = New MEN.MEN020F060(Me.ExeMode, Me.PatientNo, Me.HspHistoryNo, Me.ChNo, newMedCostDetails)
					Me.nextForm(frmMEN020F060)
				Case Else
					Return False
			End Select
			Return True
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＥＮＴＥＲキー押下処理
	''' </summary>
	''' <returns></returns>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overrides Function EnterProc() As Boolean
		log(clsSysMst.logLevel.DBG, "EnterProc", "ＥＮＴＥＲキー押下処理 Start")
		Try
			Select Case Me.ActiveControl.Name
				Case Me.dte003MEN020F050.Name
					' 追加処理
					Return Me.FuncAddProc() OrElse True
				Case Me.dgv008MEN020F050.Name
					' 医療費明細登録画面表示
					Return Me.dspMedCostDetails() OrElse True
				Case Else
					Return MyBase.EnterProc()
			End Select
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 修正ボタン（Ｆ４）クリック処理
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function FuncModifyProc() As Boolean
		log(clsSysMst.logLevel.DBG, "FuncModifyProc", "修正ボタン（Ｆ４）クリック処理 Start")
		Try
			'医療費明細登録画面表示
			Return Me.dspMedCostDetails() OrElse True
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 削除ボタン（Ｆ５）クリック処理
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function FuncDeleteProc() As Boolean
		log(clsSysMst.logLevel.DBG, "FuncDeleteProc", "削除ボタン（Ｆ５）クリック処理 Start")
		Dim dMedCostDate As Date = Nothing
		Dim iSerialNo As Integer = 0
		Dim datKey As datMTI_MED_COST_DETAILS_KeyRec
		Dim aryWK As ArrayList
		Try
			With Me.dgv008MEN020F050
				If .SelectedRows Is Nothing Then
					'選択行が無い場合終了
					Return False
				End If
				'選択行削除
				For Each row As DataGridViewRow In .SelectedRows
					dMedCostDate = row.Cells(COL_MED_COST_DATE).Value
					iSerialNo = row.Cells(COL_SERIAL_NO).Value
					Exit For
				Next
				Me.MedCostDetails(Me.PatientNo, dMedCostDate, iSerialNo) = Nothing
				'更新フラグON
				Me.updFlg = True
				'再描画
				Me.repaint()
			End With
			Return True
		Catch ex As Exception
			Throw
		Finally
			aryWK = Nothing
			datKey = Nothing
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 印刷ボタンクリック処理
	''' </summary>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function Func1Proc() As Boolean
		log(clsSysMst.logLevel.DBG, "Func1Proc", "印刷ボタンクリック処理 Start")
		Try
			If Me.MedCostDetails Is Nothing OrElse Me.MedCostDetails.Count <= 0 Then
				'明細が無い場合終了
				Return False
			End If
			'印刷
			Using eMEN020R020 As MEN020R010 = New MEN020R010(Me)
				eMEN020R020.Prn_MedCostDetails(Me.MedCostDetails, Me.rdo006MEN020F050.Checked, True)
			End Using
			'再描画
			Me.repaint()
			Return True
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 子画面データ受信処理
	''' </summary>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Sub rcvData(ByVal ret As Enum_FormReturn, ByVal de As DictionaryEntry)
		log(clsSysMst.logLevel.DBG, "rcvData", "子画面データ受信処理 Start")
		Dim rcvKey As datMTI_MED_COST_DETAILS_KeyRec
		Dim rcvRec As datMTI_MED_COST_DETAILS_PLUS_OneRec
		Try
			Select Case de.Key.ToString
				Case CST_SHOW_MEN020F060_ID
					If ret = Enum_FormReturn.OK Then
						If de.Value IsNot Nothing AndAlso TypeOf de.Value Is DictionaryEntry Then
							'更新 or 追加
							With CType(de.Value, DictionaryEntry)
								rcvKey = .Key
								rcvRec = .Value
							End With
							If rcvKey IsNot Nothing Then
								'選択行のキーを保持
								Me.pDateWk = rcvKey.MED_COST_DATE
								Me.pSerialNoWk = rcvKey.SERIAL_NO
								'子画面更新結果を反映
								Me.MedCostDetails(Me.PatientNo, Me.pDateWk, Me.pSerialNoWk) = rcvRec
								'更新フラグON
								Me.updFlg = True
								'再描画
								Me.repaint()
							End If
						End If
					End If
				Case Else
					MyBase.rcvData(ret, de)
			End Select
		Catch ex As Exception
			Throw
		Finally
			rcvKey = Nothing
			rcvRec = Nothing
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 画面終了後処理
	''' </summary>
	''' <param name="bCancel">キャンセルフラグ</param>
	''' <remarks>
	''' 2010/12/09 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overrides Sub ClosedProc(ByVal bCancel As Boolean)
		If bCancel Then
			Exit Sub
		End If
		Try
			' インスタンス開放
			If pMedCostDetails IsNot Nothing Then
				pMedCostDetails.Clear()
			End If
			If frmMEN020F060 IsNot Nothing Then
				frmMEN020F060.Dispose()
			End If
			' 画面終了後処理
			MyBase.ClosedProc(bCancel)
		Catch ex As Exception
			Me.ErrorProc(ex)
		Finally
			frmMEN020F060 = Nothing
			pMedCostDetails = Nothing
		End Try
	End Sub

#End Region

End Class