﻿Imports System.Runtime.ConstrainedExecution
Imports XCM

''' ---------------------------------------------
''' <summary>
''' 診療情報管理 検索・共通帳票  ワーク作成クラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public Class clsMakeWork

#Region "解放処理"
	'確実な解放処理を実行するために指定
	Inherits CriticalFinalizerObject
	'解放処理を実装する為に指定
	Implements IDisposable

	''' ---------------------------------------------
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/10/19 新規作成　ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overridable Overloads Sub Dispose(ByVal disposing As Boolean)
		If disposing Then
			Me.DpcHeader = Nothing
			If Me.DpcHeaderHash IsNot Nothing Then
				Me.DpcHeaderHash.Clear()
				Me.DpcHeaderHash = Nothing
			End If
			If Me.DpcCodeList IsNot Nothing Then
				Me.DpcCodeList.Clear()
				Me.DpcCodeList = Nothing
			End If
		End If
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/10/19 新規作成　ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		MyBase.Finalize()
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/10/19 新規作成　ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub

#End Region

#Region "コンスタント"

	''' ---------------------------------------------
	''' <summary>
	''' 検索処理ワーク　作成キー項目
	''' </summary>
	''' <remarks>
	''' 2010/10/20 新規作成 ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Enum ENUM_SEARCH_WORK_KEY As Byte
		''' <summary>
		''' リスト判断
		''' </summary>
		AUTO = 0
		''' <summary>
		''' 患者番号
		''' </summary>
		PATIENT_NO = 1
		''' <summary>
		''' 入退院歴番号
		''' </summary>
		HSP_NO = 2
		''' <summary>
		''' 科歴番号
		''' </summary>
		CH_NO = 3
		''' <summary>
		''' 連番
		''' </summary>
		SERIAL_NO = 4
	End Enum

	''' ---------------------------------------------
	''' <summary>
	''' ＳＱＬ文設定
	''' </summary>
	''' <remarks>
	''' 2010/12/08 新規作成 ACS)仙頭<BR/><BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Enum ENUM_DPC_SQL As Byte
		''' <summary>
		''' ワーククリア
		''' </summary>
		DEL_DPC = 0
		''' <summary>
		''' ワーク作成
		''' </summary>
		INS_DPC = 1
		''' <summary>
		''' ワーク更新(病名)
		''' </summary>
		UPD_DISEASE1 = 2
		''' <summary>
		''' ワーク更新(病名)
		''' </summary>
		UPD_DISEASE5 = 3
		''' <summary>
		''' ワーク更新(病名)
		''' </summary>
		UPD_DISEASE9 = 4
		''' <summary>
		''' ワーク更新(手術)
		''' </summary>
		UPD_OPE = 6
		''' <summary>
		''' DPCマスタの取得
		''' </summary>
		SEL_DPC = 10
		''' <summary>
		''' ワーク更新(補足)
		''' </summary>
		UPD_ASST1 = 12
		''' <summary>
		''' ワーク更新(補足)
		''' </summary>
		UPD_ASST2 = 13
	End Enum

	Private Const CST_LOG_PRODUCT As String = "診療情報管理"
	Private Const CST_LOG_CLASS As String = "ワーク作成クラス"

#End Region

#Region "変数"

	Private DpcHeader() As String										'DPCの補足項目ヘッダ
	Private DpcHeaderHash As Hashtable									'DPCの補足項目ヘッダ
	Private DpcCodeList As List(Of String)								'DPCにコード出力した項目リスト
#End Region

#Region "パプリックメソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 検索ワークの作成（一覧より)
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="pDgv">入力元一覧</param>
	''' <param name="type">作成キー項目</param>
	''' <remarks>
	''' 2010/10/19 新規作成 ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function setSearchWork(ByVal db As XCM.clsDB,
								  ByRef pDgv As DataGridView,
						 Optional ByVal type As ENUM_SEARCH_WORK_KEY = ENUM_SEARCH_WORK_KEY.AUTO) As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name,
						Reflection.MethodBase.GetCurrentMethod.Name, CST_LOG_PRODUCT, CST_LOG_CLASS, "ワークの作成 START")
		Dim row As DataRow
		Dim no As Integer = 0
		Try
			With db
'(A) STR V4-14020-000 003 20130422 ID)平井(ＣＳＶ出力の高速化)
				.ctlTran(clsDB.Enum_TranMode.Begin)
'(A) END V4-14020-000 003 20130422
				'ワークの削除
				.setSQL(sqlMakeWork.sqlDel_SEARCH_WORK)
				.setParam(sqlMRPCOMMON.prmHOST_NM, XCM.clsDB.Enum_dbType.dbNVarChar)			'ホスト名
				.setVal(sqlMRPCOMMON.prmHOST_NM, XCM.clsConst.CST_HOST_NM)
'(M) STR V4-14020-000 004 20130422 ID)平井(ＣＳＶ出力の高速化)
				'.execNonQuery()
				.execNonQuery(False)
'(M) END V4-14020-000 004 20130422

				'ワークの追加(準備)
				.setSQL(sqlMakeWork.sqlIns_SEARCH_WORK)
				.setParam(sqlMRPCOMMON.prmHOST_NM, XCM.clsDB.Enum_dbType.dbNVarChar)			'ホスト名
				.setVal(sqlMRPCOMMON.prmHOST_NM, XCM.clsConst.CST_HOST_NM)
				.setParam(sqlMRPCOMMON.prmPATIENT_NO, XCM.clsDB.Enum_dbType.dbNVarChar)		'患者番号
				.setParam(sqlMRPCOMMON.prmHSP_NO, XCM.clsDB.Enum_dbType.dbInt)				'入退院歴番号
				.setVal(sqlMRPCOMMON.prmHSP_NO, 0, False)
				.setParam(sqlMRPCOMMON.prmCH_NO, XCM.clsDB.Enum_dbType.dbInt)				'科歴番号
				.setVal(sqlMRPCOMMON.prmCH_NO, 0, False)
				.setParam(sqlMRPCOMMON.prmSERIAL_NO, XCM.clsDB.Enum_dbType.dbInt)			'連番
				.setVal(sqlMRPCOMMON.prmSERIAL_NO, 0, False)
				.setParam(sqlMakeWork.prmOUT_ORDER, XCM.clsDB.Enum_dbType.dbInt)				'出力順
				.setParam(sqlMRPCOMMON.prmLASTUPDUSER_CD, XCM.clsDB.Enum_dbType.dbNVarChar)	'更新者コード
				.setVal(sqlMRPCOMMON.prmLASTUPDUSER_CD, XCM.clsSysMst.getLoginId)
				.setParam(sqlMRPCOMMON.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)			'更新日
				.setVal(sqlMRPCOMMON.prmLASTUPD_DT, DateTime.Now())

				'追加する項目を一覧内容より選択する
				If type = ENUM_SEARCH_WORK_KEY.AUTO Then
					With DirectCast(pDgv.DataSource, DataTable).Columns
						Select Case True
							Case .Contains(sqlMRPCOMMON.itmSERIAL_NO)
								type = ENUM_SEARCH_WORK_KEY.SERIAL_NO
							Case .Contains(sqlMRPCOMMON.itmCH_NO)
								type = ENUM_SEARCH_WORK_KEY.CH_NO
							Case .Contains(sqlMRPCOMMON.itmHSP_NO)
								type = ENUM_SEARCH_WORK_KEY.HSP_NO
							Case Else
								type = ENUM_SEARCH_WORK_KEY.PATIENT_NO
						End Select
					End With
				End If

				'一覧より選択データを取得しワークに追加する
				For Each pRow As DataGridViewRow In pDgv.Rows
					row = DirectCast(pRow.DataBoundItem, DataRowView).Row
					If row.Item(sqlMRPCOMMON.itmSELECTED) = CStr(XCM.clsConst.Enum_Chk.ChkOn) Then
						no += 1																							'表示順 カウンタUP
						.setVal(sqlMakeWork.prmOUT_ORDER, no)
						.setVal(sqlMRPCOMMON.prmPATIENT_NO, row.Item(sqlMRPCOMMON.itmPATIENT_NO).ToString)				'患者番号
						Select Case type
							Case ENUM_SEARCH_WORK_KEY.HSP_NO
								.setVal(sqlMRPCOMMON.prmHSP_NO, row.Item(sqlMRPCOMMON.itmHSP_NO).ToString)				'入退院歴番号
							Case ENUM_SEARCH_WORK_KEY.CH_NO
								.setVal(sqlMRPCOMMON.prmHSP_NO, row.Item(sqlMRPCOMMON.itmHSP_NO).ToString)				'入退院歴番号
								.setVal(sqlMRPCOMMON.prmCH_NO, row.Item(sqlMRPCOMMON.itmCH_NO).ToString)				'科歴番号
							Case ENUM_SEARCH_WORK_KEY.SERIAL_NO
								.setVal(sqlMRPCOMMON.prmHSP_NO, row.Item(sqlMRPCOMMON.itmHSP_NO).ToString)				'入退院歴番号
								.setVal(sqlMRPCOMMON.prmCH_NO, row.Item(sqlMRPCOMMON.itmCH_NO).ToString)				'科歴番号
								.setVal(sqlMRPCOMMON.prmSERIAL_NO, row.Item(sqlMRPCOMMON.itmSERIAL_NO).ToString)		'連番
							Case Else
								'追加パラメータなし
						End Select
						Try
'(M) STR V4-14020-000 004 20130422 ID)平井(ＣＳＶ出力の高速化)
							'.execNonQuery()
							.execNonQuery(False)
'(M) END V4-14020-000 004 20130422
						Catch ex As SqlClient.SqlException
							Select Case ex.Number
								Case clsSysMst.sqlErrCode.KeyDuplicate													'重複エラーなら無視して次のレコード追加
																														'管理物の場合、貸出履歴のため発生の可能性あり
								Case Else
									Throw
							End Select
						Catch ex As Exception
							Throw
						End Try
					End If
				Next

				'最新入退院歴番号・科歴番号の更新
				.setSQL(sqlMakeWork.sqlUpd_SEARCH_WORK)
				.setParam(sqlMRPCOMMON.prmHOST_NM, clsDB.Enum_dbType.dbNVarChar)				'ホスト名
				.setVal(sqlMRPCOMMON.prmHOST_NM, clsConst.CST_HOST_NM)
				.setParam(sqlMRPCOMMON.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)		'更新者コード
				.setVal(sqlMRPCOMMON.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
				.setParam(sqlMRPCOMMON.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)			'更新日
				.setVal(sqlMRPCOMMON.prmLASTUPD_DT, DateTime.Now())

'(M) STR V4-14020-000 004 20130422 ID)平井(ＣＳＶ出力の高速化)
				'.execNonQuery()
				.execNonQuery(False)
'(M) END V4-14020-000 004 20130422

'(A) STR V4-14020-000 003 20130422 ID)平井(ＣＳＶ出力の高速化)
				.ctlTran(clsDB.Enum_TranMode.Commit)
'(A) END V4-14020-000 003 20130422

				Return True
			End With
'(A) STR V4-14020-000 004 20130422 ID)平井(ＣＳＶ出力の高速化)
		Catch ex As SqlClient.SqlException
			If db.statTran Then db.ctlTran(clsDB.Enum_TranMode.RollBack)
'(A) END V4-14020-000 004 20130422
		Catch ex As Exception
'(A) STR V4-14020-000 003 20130422 ID)平井(ＣＳＶ出力の高速化)
			If db.statTran Then db.ctlTran(clsDB.Enum_TranMode.RollBack)
'(A) END V4-14020-000 003 20130422
			Throw
		Finally
			row = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 検索ワークの作成(患者番号～科歴番号指定)
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="PatientNo">患者番号</param>
	''' <param name="HspNo">入退院歴番号</param>
	''' <param name="ChNo">科歴歴番号</param>
	''' <remarks>
	''' 2010/10/19 新規作成 ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function setSearchWork(ByVal db As XCM.clsDB,
								  ByRef PatientNo As String, ByRef HspNo As Integer, ByRef ChNo As Integer) As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name,
						Reflection.MethodBase.GetCurrentMethod.Name, CST_LOG_PRODUCT, CST_LOG_CLASS, "ワークの作成 START")
		Try
			With db
				'ワークの削除
				.setSQL(sqlMakeWork.sqlDel_SEARCH_WORK)
				.setParam(sqlMRPCOMMON.prmHOST_NM, XCM.clsDB.Enum_dbType.dbNVarChar)			'ホスト名
				.setVal(sqlMRPCOMMON.prmHOST_NM, XCM.clsConst.CST_HOST_NM)
				.execNonQuery()

				'ワークの追加
				.setSQL(sqlMakeWork.sqlIns_SEARCH_WORK)
				.setParam(sqlMRPCOMMON.prmHOST_NM, XCM.clsDB.Enum_dbType.dbNVarChar)			'ホスト名
				.setVal(sqlMRPCOMMON.prmHOST_NM, XCM.clsConst.CST_HOST_NM)
				.setParam(sqlMRPCOMMON.prmPATIENT_NO, XCM.clsDB.Enum_dbType.dbNVarChar)		'患者番号
				.setVal(sqlMRPCOMMON.prmPATIENT_NO, PatientNo, False)
				.setParam(sqlMRPCOMMON.prmHSP_NO, XCM.clsDB.Enum_dbType.dbInt)				'入退院歴番号
				.setVal(sqlMRPCOMMON.prmHSP_NO, HspNo, False)
				.setParam(sqlMRPCOMMON.prmCH_NO, XCM.clsDB.Enum_dbType.dbInt)				'科歴番号
				.setVal(sqlMRPCOMMON.prmCH_NO, ChNo, False)
				.setParam(sqlMRPCOMMON.prmSERIAL_NO, XCM.clsDB.Enum_dbType.dbInt)			'連番
				.setVal(sqlMRPCOMMON.prmSERIAL_NO, 0, False)
				.setParam(sqlMakeWork.prmOUT_ORDER, XCM.clsDB.Enum_dbType.dbInt)				'出力順
				.setVal(sqlMakeWork.prmOUT_ORDER, 1)
				.setParam(sqlMRPCOMMON.prmLASTUPDUSER_CD, XCM.clsDB.Enum_dbType.dbNVarChar)	'更新者コード
				.setVal(sqlMRPCOMMON.prmLASTUPDUSER_CD, XCM.clsSysMst.getLoginId)
				.setParam(sqlMRPCOMMON.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)			'更新日
				.setVal(sqlMRPCOMMON.prmLASTUPD_DT, DateTime.Now())
				.execNonQuery()

				'最新入退院歴番号・科歴番号の更新
				.setSQL(sqlMakeWork.sqlUpd_SEARCH_WORK)
				.setParam(sqlMRPCOMMON.prmHOST_NM, clsDB.Enum_dbType.dbNVarChar)				'ホスト名
				.setVal(sqlMRPCOMMON.prmHOST_NM, clsConst.CST_HOST_NM)
				.setParam(sqlMRPCOMMON.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)		'更新者コード
				.setVal(sqlMRPCOMMON.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
				.setParam(sqlMRPCOMMON.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)			'更新日
				.setVal(sqlMRPCOMMON.prmLASTUPD_DT, DateTime.Now())
				.execNonQuery()

				Return True
			End With
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＤＰＣワークの作成
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <remarks>
	''' 2010/10/19 新規作成 ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function setDpcWork(ByVal db As XCM.clsDB) As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name,
						Reflection.MethodBase.GetCurrentMethod.Name, CST_LOG_PRODUCT, CST_LOG_CLASS, "ＤＰＣワークの作成 START")
		Try
			'返却用変数を初期化
			Me.DpcHeader = New String(99) {}
			Me.DpcHeaderHash = New Hashtable
			Me.DpcCodeList = New List(Of String)

			'DPCを作成
			For Each sqltype As ENUM_DPC_SQL In {ENUM_DPC_SQL.DEL_DPC, ENUM_DPC_SQL.INS_DPC, ENUM_DPC_SQL.UPD_DISEASE1, ENUM_DPC_SQL.UPD_DISEASE5, ENUM_DPC_SQL.UPD_DISEASE9, ENUM_DPC_SQL.UPD_OPE}
				Me.setDpcSql(db, sqltype)
				db.execNonQuery()
			Next

			'補足項目を対応
			Dim aryData As ArrayList = New ArrayList()
			Dim row As Integer = 0
			Dim fieldName As String = Nothing
			Dim sql As String = Nothing
			Try
				'DPCマスタの取得
				Me.setDpcSql(db, ENUM_DPC_SQL.SEL_DPC)
				db.execQuery(GetType(sqlMakeWork.datDpcMst), aryData)
				For Each dat As sqlMakeWork.datDpcMst In aryData
					'項目名＝行
					row += 1
					fieldName = row.ToString("000")
					Select Case dat.TABLE_CD
						'補足項目１で更新
						Case clsMRPCOMMON.Enum_Tbl_CD.MTI_ASST1
								Me.DpcCodeList.Add(String.Format("ASST_CD{0}", fieldName))				'CSV出力用にコード出力リストの作成

								Select Case dat.EXTRACT_OBJECT
								Case 1 : sql = sqlMakeWork.sqlUpd_Asst1_1
								Case 2 : sql = sqlMakeWork.sqlUpd_Asst1_2
								Case Else : sql = Nothing
								End Select
								sql = String.Format(sql, fieldName, dat.FIELD_NM)
								db.setSQL(sql)
								Me.setDpcSql(db, ENUM_DPC_SQL.UPD_ASST1)

						'補足項目２で更新
						Case clsMRPCOMMON.Enum_Tbl_CD.MTI_ASST2
								If dat.FIELD_NM.ToLower.IndexOf("combo") = -1 Then
									Select Case dat.EXTRACT_OBJECT
									Case 1 : sql = String.Format(sqlMakeWork.sqlUpd_Asst2_1, fieldName, dat.FIELD_NM)
									Case 3 : sql = String.Format(sqlMakeWork.sqlUpd_Asst2_3, fieldName, dat.FIELD_NM, sqlMakeWork.sqlAdd_Asst_Sort_3)
									Case 4 : sql = String.Format(sqlMakeWork.sqlUpd_Asst2_3, fieldName, dat.FIELD_NM, sqlMakeWork.sqlAdd_Asst_Sort_4)
									Case 5 : sql = String.Format(sqlMakeWork.sqlUpd_Asst2_3, fieldName, dat.FIELD_NM, String.Format(sqlMakeWork.sqlAdd_Asst_Sort_5, Nothing, dat.FIELD_NM))
									Case Else : sql = Nothing
									End Select
								Else
									Me.DpcCodeList.Add(String.Format("ASST_CD{0}", fieldName))			'CSV出力用にコード出力リストの作成
									Select Case dat.EXTRACT_OBJECT
									Case 1 : sql = String.Format(sqlMakeWork.sqlUpd_Asst2_1_cmb, fieldName, dat.FIELD_NM)
									Case 3 : sql = String.Format(sqlMakeWork.sqlUpd_Asst2_3_cmb, fieldName, dat.FIELD_NM, sqlMakeWork.sqlAdd_Asst_Sort_3)
									Case 4 : sql = String.Format(sqlMakeWork.sqlUpd_Asst2_3_cmb, fieldName, dat.FIELD_NM, sqlMakeWork.sqlAdd_Asst_Sort_4)
									Case 5 : sql = String.Format(sqlMakeWork.sqlUpd_Asst2_3_cmb, fieldName, dat.FIELD_NM, String.Format(sqlMakeWork.sqlAdd_Asst_Sort_5, Nothing, dat.FIELD_NM))
									Case Else : sql = Nothing
									End Select
								End If
								db.setSQL(sql)
								Me.setDpcSql(db, ENUM_DPC_SQL.UPD_ASST2)
						Case Else
							Continue For
					End Select
					db.execNonQuery()

					'ヘッダ項目の追加
					Me.DpcHeader(row - 1) = String.Format("{0},{1}", dat.CONTENT, dat.CONTENT_RNM)
					Me.DpcHeaderHash(String.Format("ASST_CD{0}", fieldName)) = dat.CONTENT
				Next
				Return True
			Catch ex As Exception
				Throw
			Finally
				If aryData IsNot Nothing Then
					aryData.Clear()
					aryData = Nothing
				End If
				sql = Nothing
			End Try
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＤＰＣヘッダの返却(Excel用)
	''' </summary>
	''' <returns>DPCヘッダ配列</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDpcHeader() As String()
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name,
						Reflection.MethodBase.GetCurrentMethod.Name, CST_LOG_PRODUCT, CST_LOG_CLASS, "ＤＰＣヘッダの返却 START")
		Try
			Return Me.DpcHeader
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＤＰＣヘッダの返却(CSV用)
	''' </summary>
	''' <param name="key">項目名</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/12/24 新規作成 ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDpcHeader(ByVal key As String) As String
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name,
						Reflection.MethodBase.GetCurrentMethod.Name, CST_LOG_PRODUCT, CST_LOG_CLASS, "ＤＰＣヘッダの返却 START")
		Try
			If Me.DpcHeaderHash.ContainsKey(key) = True Then
				Return Me.DpcHeaderHash(key)
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ＤＰＣ補足項目の存在チェック
	''' </summary>
	''' <param name="key">項目名</param>
	''' <returns></returns>
	''' <remarks>
	''' 2010/12/24 新規作成 ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function chkDpcAsstCode(ByVal key As String) As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name,
					Reflection.MethodBase.GetCurrentMethod.Name, CST_LOG_PRODUCT, CST_LOG_CLASS, "ＤＰＣ補足項目の存在チェック START")
		Try
			If Me.DpcCodeList.IndexOf(key) >= 0 Then
				Return True
			Else
				Return False
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function
#End Region

#Region "メソッド"

	''' ---------------------------------------------
	''' <summary>
	''' SQL文/パラメータ設定
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="type">ENUM_SQLTYPE</param>
	''' <remarks>
	''' 2010/12/08 新規作成 ACS)仙頭<BR/><BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setDpcSql(ByVal db As clsDB, ByRef type As ENUM_DPC_SQL)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setSql", clsMRPCOMMON.CST_LOG_PRODUCT, CST_LOG_CLASS, "SQL文/パラメータ設定")
		Try
			With db
				Select Case type
					'ワーククリア
					Case ENUM_DPC_SQL.DEL_DPC
						.setSQL(sqlMakeWork.sqlDel_DPC)

					'ワーク作成
					Case ENUM_DPC_SQL.INS_DPC
						.setSQL(sqlMakeWork.sqlIns_DPC)

					'ワークをトラン(病名)で更新
					Case ENUM_DPC_SQL.UPD_DISEASE1
						.setSQL(sqlMakeWork.sqlUpd_Disease1)
						.setParam(sqlMRPCOMMON.prmFLG_ON, clsDB.Enum_dbType.dbInt)			'フラグ
						.setVal(sqlMRPCOMMON.prmFLG_ON, clsConst.Enum_CheckBox_Flg.CheckOn)
						.setParam(sqlMRPCOMMON.prmFIXED_CD, clsDB.Enum_dbType.dbNVarChar)		'固定コード
						.setVal(sqlMRPCOMMON.prmFIXED_CD, clsConst.Enum_Disease_Div_Fix1.MainDisease)

					'ワークをトラン(病名)で更新
					Case ENUM_DPC_SQL.UPD_DISEASE5
						.setSQL(sqlMakeWork.sqlUpd_Disease5)
						.setParam(sqlMRPCOMMON.prmFLG_ON, clsDB.Enum_dbType.dbInt)			'フラグ
						.setVal(sqlMRPCOMMON.prmFLG_ON, clsConst.Enum_CheckBox_Flg.CheckOn)

					'ワークをトラン(病名)で更新
					Case ENUM_DPC_SQL.UPD_DISEASE9
						.setSQL(sqlMakeWork.sqlUpd_Disease9)
						.setParam(sqlMRPCOMMON.prmFLG_ON, clsDB.Enum_dbType.dbInt)			'フラグ
						.setVal(sqlMRPCOMMON.prmFLG_ON, clsConst.Enum_CheckBox_Flg.CheckOn)

					'ワーク(手術)を作成
					Case ENUM_DPC_SQL.UPD_OPE
						Dim sql As String = sqlMakeWork.sqlUpd_Ope
						Dim env As String = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00076).ToLower
						Try
							Select Case env
							Case "a" : sql = String.Format(sql, sqlMakeWork.sqlAdd_Ope_Sort_A, sqlMakeWork.sqlAdd_Ope_Where_A)
							Case "b" : sql = String.Format(sql, sqlMakeWork.sqlAdd_Ope_Sort_B, sqlMakeWork.sqlAdd_Ope_Where_B)
							Case "c" : sql = String.Format(sql, sqlMakeWork.sqlAdd_Ope_Sort_C, sqlMakeWork.sqlAdd_Ope_Where_C)
							Case "d" : sql = String.Format(sql, sqlMakeWork.sqlAdd_Ope_Sort_D, sqlMakeWork.sqlAdd_Ope_Where_D)
							Case Else
									'数値の場合
									If IsNumeric(env) = True Then
										sql = String.Format(sql, sqlMakeWork.sqlAdd_Ope_Sort_N, sqlMakeWork.sqlAdd_Ope_Where_N)
										.setSQL(sql)
										.setParam(sqlMakeWork.prmOPE_DIV, clsDB.Enum_dbType.dbNVarChar)			'手術区分
										.setVal(sqlMakeWork.prmOPE_DIV, env, False)
										sql = Nothing
									'上記以外
									Else
										sql = String.Format(sql, sqlMakeWork.sqlAdd_Ope_Sort_Z, sqlMakeWork.sqlAdd_Ope_Where_Z)
									End If
							End Select
							If sql IsNot Nothing Then
								.setSQL(sql)
							End If
						Catch ex As Exception
							Throw
						Finally
							sql = Nothing
							env = Nothing
						End Try

					'DPCマスタ読込
					Case ENUM_DPC_SQL.SEL_DPC
						.setSQL(sqlMakeWork.sqlSel_DpcMst)
						Return		'共通パラメータは必要ないのでここで終了

					'ワーク(補足)を更新
					Case ENUM_DPC_SQL.UPD_ASST1
						.setParam(sqlMRPCOMMON.prmFLG_ON, clsDB.Enum_dbType.dbInt)			'フラグ
						.setVal(sqlMRPCOMMON.prmFLG_ON, clsConst.Enum_CheckBox_Flg.CheckOn)
						Dim dt As DataTable = clsConst.getCheckBox
						Try
							.setParam(sqlMRPCOMMON.prmFLG_NM_ON, clsDB.Enum_dbType.dbNVarChar)
							.setVal(sqlMRPCOMMON.prmFLG_NM_ON, clsMRPCOMMON.getDtItem(dt, clsConst.Enum_CheckBox_Flg.CheckOn))
						Finally
							dt.Dispose()
							dt = Nothing
						End Try

					'ワーク(補足)を更新
					Case ENUM_DPC_SQL.UPD_ASST2
						.setParam(sqlMRPCOMMON.prmFLG_ON, clsDB.Enum_dbType.dbInt)			'フラグ
						.setVal(sqlMRPCOMMON.prmFLG_ON, clsConst.Enum_CheckBox_Flg.CheckOn)

					Case Else
						Return
				End Select

				'共通パラメータ
				.setParam(sqlMRPCOMMON.prmHOST_NM, clsDB.Enum_dbType.dbNVarChar)				'ホスト名
				.setVal(sqlMRPCOMMON.prmHOST_NM, clsConst.CST_HOST_NM)
				.setParam(sqlMRPCOMMON.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)			'更新日
				.setVal(sqlMRPCOMMON.prmLASTUPD_DT, DateTime.Now())

			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

#End Region

End Class
