﻿Imports System.ComponentModel
Imports System.Windows.Forms
'''---------------------------------------------
''' <summary>
''' ユーザーコントロール（テキストボックス）
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
'''---------------------------------------------
Public Class BT_TextBox

#Region "コンスタント"

	Private Const CST_WM_CHAR As Integer = &H102
	Private Const CST_WM_PASTE As Integer = &H302

'(A) STR V4-15013-000 024 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
	'''----------------------------------------
	''' <summary>
	''' テキストタイプ
	''' </summary>
	''' <remarks>
	''' 2014/03/28 新規作成　ID)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	Public Enum Enum_TextType
		'''----------------------------------------
		''' <summary>
		''' デフォルト
		''' </summary>
		'''----------------------------------------
		Nomarl = 0
		'''----------------------------------------
		''' <summary>
		''' 点数表コード
		''' </summary>
		'''----------------------------------------
		ScoreCode = 1
	End Enum
'(A) END V4-15013-000 024 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応

#End Region

#Region "変数"

	Private _caninput As Boolean = True									'True:入力可(通常表示),False:入力不可(ラベル表示)
	Private _comment As String = Nothing								'日本語での項目説明(検索条件保存で利用)
	Private _maxbytelength As Integer = 0								'バイト数チェック（０はしない　０以上は指定したバイト数できる）
	Private _linkfuricontrol As String = Nothing						'ふりがなコントロール
'(A) STR V4-15013-000 003 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
	Private _texttype As Enum_TextType = Enum_TextType.Nomarl			'テキストタイプ
'(A) END V4-15013-000 003 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
	Private WithEvents _cliFuriganaConv As clsFuriganaConv.Furigana

#End Region

#Region "プロパティ"

	'''----------------------------------------
	''' <summary>
	''' 入力可・不可設定
	''' </summary>
	''' <value>True:入力可，False:入力不可</value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("True:入力可，False:入力不可"), _
	DefaultValue(True), _
	Category("カスタムプロパティ")> _
	Public Property CanInput() As Boolean
		Get
			Return (_caninput)
		End Get
		Set(ByVal value As Boolean)
			_caninput = value
			If Me.DesignMode = False Then
				If _caninput = True Then				'入力可の場合、有効化
					Me.ReadOnly = False
					Me.TabStop = True
					BackColor = Nothing
				Else									'入力不可の場合、無効化
					Me.ReadOnly = True
					Me.TabStop = False
					BackColor = clsConst.CST_INACTIVE_BACK_COLOR
				End If
			End If
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 項目説明
	''' </summary>
	''' <value>項目説明</value>
	''' <returns></returns>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("項目説明"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Property Comment() As String
		Get
			Return (_comment)
		End Get
		Set(ByVal value As String)
			_comment = value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' 最大バイト数プロパティ
	''' </summary>
	''' <value>入力最大バイト数を指定する(0はバイト数チェックしない)</value>
	''' <returns>入力最大バイト数</returns>
	''' <remarks>
	''' 2010/09/29 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("最大バイト数"), _
	DefaultValue(0), _
	Category("カスタムプロパティ")> _
	Public Property MaxByteLength() As Integer
		Get
			Return (_maxbytelength)
		End Get
		Set(ByVal value As Integer)
			_maxbytelength = value
		End Set
	End Property

	'''----------------------------------------
	''' <summary>
	''' テキスト（カスタム化[Shadows]）
	''' </summary>
	''' <value>テキスト</value>
	''' <returns>テキスト</returns>
	''' <remarks>
	''' 2010/10/12 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("テキスト（カスタム化[Shadows]）"), _
	Category("カスタムプロパティ")> _
	Public Shadows Property Text() As String
		Get
			If String.IsNullOrEmpty(MyBase.Text) OrElse String.IsNullOrEmpty(MyBase.Text.Replace(Space(1), String.Empty).Replace("　", String.Empty)) Then
				Return String.Empty
			Else
				Return MyBase.Text
			End If
		End Get
		Set(ByVal value As String)
			'MAXLengthチェック
			If Not String.IsNullOrEmpty(value) AndAlso value.Length > MyBase.MaxLength Then
				value = value.Substring(0, MyBase.MaxLength)
			End If

			'MAXByteLengthチェック
			If Me._maxbytelength <> 0 AndAlso Not String.IsNullOrEmpty(value) AndAlso clsMisc.getByteLength(value) > Me.MaxByteLength Then
				value = clsMisc.fMidB(value, 0, Me.MaxByteLength)
			End If

			'Textセット
			MyBase.Text = value
		End Set
	End Property

	'''---------------------------------------------
	''' <summary>
	''' ふりがな連携するコントロール名
	''' </summary>
	''' <value></value>
	''' <returns></returns>
	''' <remarks>
	''' 2011/05/18 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	<Description("ふりがな連携するコントロールを指定します。"), _
	DefaultValue(vbNullString), _
	Category("カスタムプロパティ")> _
	Public Property LinkFuriControl() As String
		Get
			Return _linkfuricontrol
		End Get
		Set(ByVal value As String)
			_linkfuricontrol = value
		End Set
	End Property

'(A) STR V4-15013-000 029 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
	'''----------------------------------------
	''' <summary>
	''' 入力可・不可設定
	''' </summary>
	''' <value>True:入力可，False:入力不可</value>
	''' <returns></returns>
	''' <remarks>
	''' 2014/03/28 新規作成　ID)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	<Browsable(True), _
	Description("True:入力可，False:入力不可"), _
	DefaultValue(Enum_TextType.Nomarl), _
	Category("カスタムプロパティ")> _
	Public Property TextType() As Enum_TextType
		Get
			Return (_texttype)
		End Get
		Set(ByVal value As Enum_TextType)
			_texttype = value
			Select Case _texttype
				Case Enum_TextType.ScoreCode
					Me.ImeMode = Windows.Forms.ImeMode.Off
				Case Else
			End Select
		End Set
	End Property
'(A) END V4-15013-000 029 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応

#End Region

#Region "メソッド"

	'''---------------------------------------------
	''' <summary>
	''' 振り仮名初期化処理
	''' </summary>
	''' <remarks>
	''' 2011/05/18 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Public Sub exeIniFurigana()
		Try
			_cliFuriganaConv = New clsFuriganaConv.Furigana(Me)
		Catch ex As Exception
			Throw
		End Try
	End Sub

#End Region

#Region "オーバーライドメソッド"

'(A) STR V4-15013-000 026 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
	'''----------------------------------------
	''' <summary>
	''' IMEモード
	''' </summary>
	''' <remarks>
	''' 2014/03/28 新規作成　ID)荒川<BR/>
	''' </remarks>
	'''----------------------------------------
	Protected Overrides Sub OnImeModeChanged(e As System.EventArgs)
		Try
			MyBase.OnImeModeChanged(e)
			If Not Me.DesignMode AndAlso _caninput = True Then
				Select Case _texttype
					Case Enum_TextType.ScoreCode
						If Me.ImeMode = Windows.Forms.ImeMode.On OrElse Me.ImeMode = Windows.Forms.ImeMode.Hiragana Then Me.ImeMode = Windows.Forms.ImeMode.KatakanaHalf
					Case Else
				End Select
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub
'(A) END V4-15013-000 026 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応

	'''---------------------------------------------
	''' <summary>
	''' 編集開始時処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnEnter(ByVal e As System.EventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnEnter", "編集開始 Start")
		End If
		Try
			MyBase.OnEnter(e)
			If Not Me.DesignMode AndAlso _caninput = True Then
				Me.BackColor = clsConst.CST_ACTIVE_BACK_COLOR			'背景色を変える
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 編集終了時処理
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/03/05 新規作成　FJSK)柳原<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub OnLeave(ByVal e As System.EventArgs)
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "OnLeave", "編集終了 Start")
		End If
		Try
			MyBase.OnLeave(e)
			If Not Me.DesignMode AndAlso _caninput = True Then
				Me.BackColor = Nothing			'背景色を戻す
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 解放処理
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2011/05/18 新規作成 FJSK)荒川<BR/><BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub BT_TextBox_Disposed(sender As Object, e As System.EventArgs) Handles Me.Disposed
		Try
			Me._cliFuriganaConv = Nothing
		Catch ex As Exception
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' テキストチェンジイベント（バイト数チェック）
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/09/29 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub BT_TextBox_TextChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.TextChanged
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "BT_TextBox_TextChanged", "テキストチェンジイベント（バイト数チェック） Start")
		End If
		Try
			''バイト数チェックをTextChangedに持っていった理由

			''最初はKeyPressで実装していた。
			''検証を行った結果、下記の二つにおいてKeyPressでは修正できないことが判明
			''　１．Ctrl+V(貼り付け)では入力チェックは行えなかった。
			''　２．MAXバイト数分テキストが入力されている状態でMAXバイト数分の文字列をCtrl+V(貼り付け)で
			''　　　貼り付けを行うが反映されない
			''      ※チェック方法（｛入力文字　＋　これから入力される文字　＞　ＭＡＸバイト数｝
			''　　　　 　　　　　　 だったら、入力した文字を無視する）
			''上記の結果から、テキストが完全に反映されるTextChangedイベントで結果を切り捨てる方法で
			''実装するようにしました。
			''現在入力されている文字が指定バイト数以上だったらそれ以上入力させない。
			'If Me._maxbytelength <> 0 Then
			'	If (System.Text.Encoding.GetEncoding("Shift_JIS").GetByteCount(Me.Text)) > _maxbytelength Then
			'		'カーソル位置を取得
			'		Dim startidx As Integer = Me.SelectionStart

			'		'指定したMAXバイト数分残し、残りの文字列を削除する
			'		Me.Text = clsMisc.fMidB(Me.Text, 0, _maxbytelength)

			'		'保持したカーソル位置を設定
			'		Me.SelectionStart = startidx
			'	End If
			'End If
			If Me.DesignMode = False AndAlso Me.Parent IsNot Nothing AndAlso String.IsNullOrEmpty(_linkfuricontrol) = False AndAlso String.IsNullOrEmpty(MyBase.Text) Then			'Link先が設定されている場合
				Dim ctl As Control() = Me.Parent.Controls.Find(_linkfuricontrol, True)		'コントロールを取得
				If ctl.Length > 0 Then									'コントロールが見つかった場合
					ctl(0).Text = Nothing
				Else
					If Me.TopLevelControl IsNot Nothing Then
						'一つ上のコントロールを検索してない場合はTopLevelContorol階層まで登る
						ctl = Me.TopLevelControl.Controls.Find(_linkfuricontrol, True)
						If ctl.Length > 0 Then
							ctl(0).Text = Nothing
						End If
					End If
				End If
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' ふりがな確定イベント
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2011/05/18 新規作成 FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub _cliFuriganaConv_Converted(ByVal sender As Object, ByVal e As clsFuriganaConv.FuriganaCovEventArgs) _
		Handles _cliFuriganaConv.Converted
		If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
			CType(Me.TopLevelControl, frmBase).log(clsSysMst.logLevel.DBG, "_cliFuriganaConv_Converted", "ふりがな確定イベント Start")
		End If
		Try
			'-- 全角文字が含まれない場合のみ表示
			'   (IMEパッド等によりフリガナにそのままの文字列が返される場合あり)
			If sender.Equals(Me) Then
				If Me.DesignMode = False AndAlso Me.Parent IsNot Nothing AndAlso String.IsNullOrEmpty(_linkfuricontrol) = False AndAlso Not String.IsNullOrEmpty(e.FuriganaString) Then			'Link先が設定されている場合
					Dim ctl As Control() = Me.Parent.Controls.Find(_linkfuricontrol, True)		'コントロールを取得
					If ctl.Length > 0 Then									'コントロールが見つかった場合
					Else
						If Me.TopLevelControl IsNot Nothing Then
							'一つ上のコントロールを検索してない場合はTopLevelContorol階層まで登る
							ctl = Me.TopLevelControl.Controls.Find(_linkfuricontrol, True)
						End If
					End If

					If ctl.Length > 0 Then									'コントロールが見つかった場合
						ctl(0).Text = Mid(ctl(0).Text & e.FuriganaString, 1, DirectCast(ctl(0), TextBox).MaxLength)
					End If
				End If
			End If
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' Windowsメッセージを処理する
	''' </summary>
	''' <param name="m">Windowsメッセージ</param>
	''' <remarks>
	''' 2010/10/10 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Protected Overrides Sub WndProc(ByRef m As System.Windows.Forms.Message)
		Try
'(M) STR V4-15013-000 004 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
'			If _maxbytelength = 0 Then Exit Try
			If _maxbytelength = 0 AndAlso _texttype = Enum_TextType.Nomarl Then Exit Try
'(M) STR V4-15013-000 004 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応

			Select Case m.Msg
				Case CST_WM_CHAR
					'「キーボードから文字入力を受け取った」　というメッセージを処理する
					Dim eKeyPress As New KeyPressEventArgs(Microsoft.VisualBasic.ChrW(m.WParam.ToInt32()))

					'入力された文字判定
					Me.OnChar(eKeyPress)

					'入力文字がNGだったら処理を抜ける
					If eKeyPress.Handled Then
						Return
					End If
				Case CST_WM_PASTE
					'「貼り付けを行った」というメッセージを処理する
'(M) STR V4-15013-000 005 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
'					If _maxbytelength > 0 AndAlso Me.MaxLength * 2 > _maxbytelength Then
'						Me.OnPaste(New System.EventArgs())
					If Me.OnPaste(New System.EventArgs()) = True Then
'(M) END V4-15013-000 005 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
						Return
					End If
			End Select
		Catch ex As Exception
			If Not Me.DesignMode AndAlso Me.TopLevelControl IsNot Nothing Then
				CType(Me.TopLevelControl, frmBase).ErrorProc(ex)
			End If
		End Try
		MyBase.WndProc(m)
	End Sub

	'''---------------------------------------------
	''' <summary>
	''' 入力した文字を判断して、チェックを行う
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/10/10 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Sub OnChar(ByVal e As System.Windows.Forms.KeyPressEventArgs)
		Try
			If Char.IsControl(e.KeyChar) Then
				'制御文字は判断しない
				Return
			End If

			Dim textByteCount As Integer = clsMisc.getByteCnt(Me.Text)										'現在のテキストのバイト数チェック
			Dim inputByteCount As Integer = clsMisc.getByteCnt(e.KeyChar.ToString())							'入力文字のバイト数チェック
			Dim selectedTextByteCount As Integer = clsMisc.getByteCnt(Me.SelectedText)						'現在選択中の文字のバイト数チェック

			'現在のテキストバイト数　＋　入力文字のバイト数　ー　現在選択中の文字のバイト数　が指定MAXバイト数を超えたら
			'入力をキャンセルする　（指定MAXバイト数が０なら処理しない）
			If _maxbytelength > 0 AndAlso textByteCount + inputByteCount - selectedTextByteCount > _maxbytelength Then
				e.Handled = True
				Exit Sub
			End If

'(A) STR V4-15013-000 013 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
			'個別チェック
			Select Case _texttype
				Case Enum_TextType.ScoreCode
					'点数表コードの場合、半角のみ許す
					If inputByteCount <> e.KeyChar.ToString().Length Then
						' 半角のみ許容する
						e.Handled = True
						Exit Sub
					End If
				Case Else
			End Select
'(A) STR V4-15013-000 013 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
		Catch ex As Exception
			Throw
		End Try
	End Sub

'(M) STR V4-15013-000 121 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応
'	'''---------------------------------------------
'	''' <summary>
'	''' 貼り付けした時のイベント
'	''' </summary>
'	''' <param name="e"></param>
'	''' <remarks>
'	''' 2010/10/10 新規作成　FJSK)荒川<BR/>
'	''' </remarks>
'	'''---------------------------------------------
'	Private Sub OnPaste(ByVal e As System.EventArgs)
'		Try
'			'クリップボードにあるオブジェクトを取得する
'			Dim clipboardText As Object = Clipboard.GetDataObject().GetData(System.Windows.Forms.DataFormats.UnicodeText)
'			If clipboardText Is Nothing Then
'				Return
'			End If
'
'			Dim inputText As String = clipboardText.ToString()															'クリップボードのテキスト取得
'			Dim textByteCount As Integer = clsMisc.getByteCnt(Me.Text)															'現在のテキストのバイト数チェック
'			Dim inputByteCount As Integer = clsMisc.getByteCnt(inputText)														'入力文字のバイト数チェック
'			Dim selectedTextByteCount As Integer = clsMisc.getByteCnt(Me.SelectedText)											'現在選択中の文字のバイト数チェック
'
'			'貼り付け前の時点で貼り付け可能文字バイト数を取得
'			Dim remainByteCount As Integer = _maxbytelength - (textByteCount - selectedTextByteCount)
'			If remainByteCount <= 0 Then
'				Return
'			End If
'
'			'貼り付け可能文字バイト数を入力文字バイト数が下回っていたら貼り付け処理をする
'			'上回っていたら入力文字の先頭から必要な分だけ貼り付ける
'			If remainByteCount >= inputByteCount Then
'				Me.SelectedText = inputText
'			Else
'				'Me.SelectedText = inputText.Substring(0, remainByteCount)
'				Me.SelectedText = clsMisc.fMidB(inputText, 0, remainByteCount)
'			End If
'		Catch ex As Exception
'			Throw
'		End Try
'	End Sub
	'''---------------------------------------------
	''' <summary>
	''' 貼り付けした時のイベント
	''' </summary>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/10/10 新規作成　FJSK)荒川<BR/>
	''' </remarks>
	'''---------------------------------------------
	Private Function OnPaste(ByVal e As System.EventArgs) As Boolean
		Try
			If (_maxbytelength > 0 AndAlso Me.MaxLength * 2 > _maxbytelength) OrElse _texttype = Enum_TextType.ScoreCode Then
			Else
				Return False
			End If
			'クリップボードにあるオブジェクトを取得する
			Dim clipboardText As Object = Clipboard.GetDataObject().GetData(System.Windows.Forms.DataFormats.UnicodeText)
			If clipboardText Is Nothing Then
				Return False
			End If

			Dim inputText As String = clipboardText.ToString()																	'クリップボードのテキスト取得

			'個別チェック
			Select Case _texttype
				Case Enum_TextType.ScoreCode
					If clsMisc.getByteCnt(inputText) <> inputText.Length Then
						Dim temp As String = inputText
						' 全角を省く
						For idx As Integer = inputText.Length - 1 To 0 Step -1
							If clsMisc.getByteCnt(temp.Substring(idx, 1)) <> temp.Substring(idx, 1).Length Then
								temp = temp.Remove(idx, 1)
							End If
						Next
						inputText = temp
					End If
				Case Else
			End Select

			Dim textByteCount As Integer = clsMisc.getByteCnt(Me.Text)															'現在のテキストのバイト数チェック
			Dim inputByteCount As Integer = clsMisc.getByteCnt(inputText)														'入力文字のバイト数チェック
			Dim selectedTextByteCount As Integer = clsMisc.getByteCnt(Me.SelectedText)											'現在選択中の文字のバイト数チェック

			'貼り付け前の時点で貼り付け可能文字バイト数を取得
			Dim remainByteCount As Integer = _maxbytelength - (textByteCount - selectedTextByteCount)
			If remainByteCount <= 0 Then
				'Return
				Select Case _texttype
					Case Enum_TextType.ScoreCode
						If (Me.MaxLength - (Me.Text.Length - Me.SelectedText.Length)) <= 0 Then
							Me.SelectedText = inputText
						Else
							If (Me.MaxLength - (Me.Text.Length - Me.SelectedText.Length)) >= inputText.Length Then
								Me.SelectedText = inputText
							Else
								Me.SelectedText = inputText.Substring(0, (Me.MaxLength - (Me.Text.Length - Me.SelectedText.Length)))
							End If
						End If
						Return True
					Case Else
						Return False
				End Select
			Else
				'貼り付け可能文字バイト数を入力文字バイト数が下回っていたら貼り付け処理をする
				'上回っていたら入力文字の先頭から必要な分だけ貼り付ける
				If remainByteCount >= inputByteCount Then
					Me.SelectedText = inputText
				Else
					'Me.SelectedText = inputText.Substring(0, remainByteCount)
					Me.SelectedText = clsMisc.fMidB(inputText, 0, remainByteCount)
				End If
			End If

			'正常終了
			Return False
		Catch ex As Exception
			Throw
		End Try
	End Function
'(M) END V4-15013-000 121 2014/03/31 ID)荒川 点数表コードに半角カナも入力できるようにする対応

#End Region

End Class
