﻿#Region "データクラス"

''' ---------------------------------------------
''' <summary>
''' 診療情報管理 システム連携 医療費更新
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Friend NotInheritable Class datXSI020F010_HSP

    Public PATIENT_NO As String         '患者番号
    Public HSP_HISTORY_NO As Integer    '入退院歴番号
    Public HSP_DT As Date               '入院日
    Public OUT_HSP_DT As Date           '退院日

End Class

''' ---------------------------------------------
''' <summary>
''' 科歴情報
''' </summary>
''' ---------------------------------------------
Friend NotInheritable Class datXSI020F010_CH

    Public PATIENT_NO As String         '患者番号
    Public HSP_HISTORY_NO As Integer    '入退院歴番号
    Public CH_NO As Integer             '科歴番号
    Public START_DT As Date             '開始日
    Public END_DT As Date               '終了日

End Class

''' ---------------------------------------------
''' <summary>
''' 医療費MAX連番
''' </summary>
''' ---------------------------------------------
Friend NotInheritable Class datXSI020F010_MED_COST_INFO

    Public PATIENT_NO As String         '患者番号
    Public MED_COST_DATE As Date        '日付
    Public SERIAL_NO As Integer         '連番

End Class

''' ---------------------------------------------
''' <summary>
''' 医療費合計
''' </summary>
''' ---------------------------------------------
Friend NotInheritable Class datXSI020F010_TOTALCOST

    Public PATIENT_NO As String             '患者番号
    Public HSP_HISTORY_NO As Integer        '入退院歴番号
    Public CH_NO As Integer                 '科歴番号
    Public COST As Integer                  '医療費合計
    Public CNT As Integer                   '医療費数

End Class

#End Region

''' ---------------------------------------------
''' <summary>
''' 診療情報管理 システム連携 医療費更新SQLクラス
''' </summary>
''' ---------------------------------------------
Public Class sqlXSI020F010

    Public Const itmPATIENT_NO As String = "PATIENT_NO"                         '患者番号
    Public Const itmTOTAL_OBJECT_FLG As String = "TOTAL_OBJECT_FLG"             '合計対象フラグ
    Public Const itmMED_COST_CD As String = "MED_COST_CD"                       '医療費コード

    Public Const prmHOST_NM As String = "@HOST_NM"                              'ホスト名
    Public Const prmPATIENT_NO As String = "@PATIENT_NO"                        '患者番号
    Public Const prmHSP_HISTORY_NO As String = "@HSP_HISTORY_NO"                '入退院歴番号
    Public Const prmCH_NO As String = "@CH_NO"                                  '科歴番号
    Public Const prmTOTAL_MED_COST As String = "@TOTAL_MED_COST"                '医療費合計
    Public Const prmMED_COST_COUNT As String = "@MED_COST_COUNT"                '医療費数
    Public Const prmMED_COST_DATE As String = "@MED_COST_DATE"                  '日付 
    Public Const prmSERIAL_NO As String = "@SERIAL_NO"                          '連番
    Public Const prmOBJECT_FLG As String = "@OBJECT_FLG"                        '対象フラグ
    Public Const prmLASTUPDUSER_CD As String = "@LASTUPDUSER_CD"                '更新者コード
    Public Const prmLASTUPD_DT As String = "@LASTUPD_DT"                        '更新日
    Public Const prmDATA_CAPTURE_DT As String = "@DATA_CAPTURE_DT"              'データ取込日
    Public Const prmNEW_REG_DT As String = "@NEW_REG_DT"                        '新規登録日
    Public Const prmDATA_CAPTURE_DT_FROM As String = "@DATA_CAPTURE_DT_FROM"    'データ取込日From
    Public Const prmDATA_CAPTURE_DT_TO As String = "@DATA_CAPTURE_DT_TO"        'データ取込日To
    Public Const prmOUT_HSP_DT_FROM As String = "@OUT_HSP_DT_FROM"              '退院日From
    Public Const prmOUT_HSP_DT_TO As String = "@OUT_HSP_DT_TO"                  '退院日To

#Region "SELECT"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 条件データ取込日選択時の患者番号一覧取得
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlSel_PATIENT_DATA_CAPTURE_DT As String = _
        " SELECT " _
            & " PATIENT_NO" _
        & " FROM" _
            & " MTI_MED_COST_DETAILS" _
        & " WHERE " _
            & "     DATA_CAPTURE_DT >= " & prmDATA_CAPTURE_DT_FROM _
            & " AND DATA_CAPTURE_DT <" & prmDATA_CAPTURE_DT_TO _
        & " GROUP BY" _
            & " PATIENT_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 条件患者番号選択時：患者番号一覧取得
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlSel_PATIENT_DATA_PATIENT_NO As String =
        " SELECT" _
            & " PATIENT_NO" _
        & " FROM " _
            & " MTI_HSP" _
        & " WHERE" _
            & "     PATIENT_NO  = " & prmPATIENT_NO _
        & " GROUP BY" _
            & " PATIENT_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 条件退院日選択時：患者番号一覧取得
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlSel_MTI_PATIENT_OUT_HSP_DT As String = _
        " SELECT " _
            & " PATIENT_NO" _
        & " FROM" _
            & " MTI_HSP" _
        & " WHERE " _
            & "     OUT_HSP_DT BETWEEN  " & prmOUT_HSP_DT_FROM _
                                & " AND " & prmOUT_HSP_DT_TO _
        & " GROUP BY" _
            & " PATIENT_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 患者単位の入退院歴情報取得
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlSel_MTI_HSP As String = _
        " SELECT " _
            & " PATIENT_NO" _
            & ",HSP_HISTORY_NO" _
            & ",HSP_DT" _
            & ",HSP_TIME" _
            & ",OUT_HSP_DT" _
            & ",OUT_HSP_TIME" _
        & " FROM" _
            & " MTI_HSP" _
        & " WHERE " _
            & " PATIENT_NO  = " & prmPATIENT_NO _
        & " ORDER BY" _
            & " PATIENT_NO" _
            & ",HSP_HISTORY_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 患者単位の科歴情報取得
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlSel_MTI_CH As String = _
        " SELECT " _
            & " PATIENT_NO" _
            & ",HSP_HISTORY_NO" _
            & ",CH_NO" _
            & ",START_DT" _
            & ",START_TIME" _
            & ",END_DT" _
            & ",END_TIME" _
        & " FROM" _
            & " MTI_CH" _
        & " WHERE" _
            & " PATIENT_NO  = " & prmPATIENT_NO _
        & " ORDER BY" _
            & " PATIENT_NO" _
            & ",HSP_HISTORY_NO" _
            & ",CH_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' TR_医療費明細情報取得
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlSel_MTW_MED_COST_INFO As String = _
        " SELECT " _
            & " PATIENT_NO" _
            & ",MED_COST_DATE" _
            & ",SERIAL_NO" _
        & " FROM" _
            & " MTW_MED_COST_INFO" _
        & " WHERE " _
            & "     HOST_NM       = " & prmHOST_NM _
            & " AND PATIENT_NO    = " & prmPATIENT_NO _
        & " ORDER BY " _
            & " MED_COST_DATE" _
            & ",SERIAL_NO "

    ''' ---------------------------------------------
    ''' <summary>
    ''' 科歴情報から医療費合計、医療費数を取得(入退院)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlSel_MTI_HSP_TOTALMEDCOST_CH As String = _
        " SELECT" _
            & " PATIENT_NO" _
            & ",HSP_HISTORY_NO" _
            & ",SUM(TOTAL_MED_COST) AS COST" _
            & ",SUM(MED_COST_COUNT) AS CNT" _
        & " FROM" _
            & " MTI_CH " _
        & "	WHERE" _
            & " EXISTS (" _
                & "SELECT " _
                    & " PATIENT_NO" _
                    & ",HSP_HISTORY_NO " _
                    & ",CH_NO" _
                & " FROM " _
                    & " MTW_MED_COST_INFO " _
                & " WHERE " _
                    & "     HOST_NM                             = " & prmHOST_NM _
                    & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_CH.PATIENT_NO " _
                    & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_CH.HSP_HISTORY_NO " _
                    & " AND MTW_MED_COST_INFO.CH_NO             = MTI_CH.CH_NO" _
            & ") "

#End Region

#Region "INSERT"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 条件取込日選択時：TZ_医療費明細情報をTR_医療費明細情報にコピー
    ''' </summary>
    ''' ---------------------------------------------
	Public Const sqlIns_MTW_MED_COST_INFO_DATA_CAPTURE_DT As String = _
		" INSERT INTO MTW_MED_COST_INFO " _
			& " SELECT" _
				& " " & prmHOST_NM _
				& ",PATIENT_NO" _
				& ",MED_COST_DATE" _
				& ",SERIAL_NO" _
				& ",DEPT_CD" _
				& ",MNG_NO" _
				& ",MED_COST01" _
				& ",MED_COST02" _
				& ",MED_COST03" _
				& ",MED_COST04" _
				& ",MED_COST05" _
				& ",MED_COST06" _
				& ",MED_COST07" _
				& ",MED_COST08" _
				& ",MED_COST09" _
				& ",MED_COST10" _
				& ",MED_COST11" _
				& ",MED_COST12" _
				& ",MED_COST13" _
				& ",MED_COST14" _
				& ",MED_COST15" _
				& ",MED_COST16" _
				& ",MED_COST17" _
				& ",MED_COST18" _
				& ",MED_COST19" _
				& ",MED_COST20" _
				& ",MED_COST21" _
				& ",MED_COST22" _
				& ",MED_COST23" _
				& ",MED_COST24" _
				& ",MED_COST25" _
				& ",MED_COST26" _
				& ",MED_COST27" _
				& ",MED_COST28" _
				& ",MED_COST29" _
				& ",MED_COST30" _
				& ",MED_COST31" _
				& ",MED_COST32" _
				& ",MED_COST33" _
				& ",MED_COST34" _
				& ",MED_COST35" _
				& ",MED_COST36" _
				& ",MED_COST37" _
				& ",MED_COST38" _
				& ",MED_COST39" _
				& ",MED_COST40" _
				& ",MED_COST41" _
				& ",MED_COST42" _
				& ",MED_COST43" _
				& ",MED_COST44" _
				& ",MED_COST45" _
				& ",OTHER_DEPT_INFO" _
				& ",DATA_CAPTURE_DT" _
				& ",NEW_REG_DT" _
				& ",0" _
				& ",0" _
				& ",'0'" _
				& "," & prmLASTUPDUSER_CD _
				& "," & prmLASTUPD_DT _
			& " FROM" _
				& " MTI_MED_COST_DETAILS" _
			& " WHERE" _
				& " EXISTS (" _
					& " SELECT " _
						& " PATIENT_NO" _
					& " FROM" _
						& " MTI_MED_COST_DETAILS AS A" _
					& " WHERE" _
					& "     A.PATIENT_NO        = MTI_MED_COST_DETAILS.PATIENT_NO" _
					& " AND A.DATA_CAPTURE_DT	>=  " & prmDATA_CAPTURE_DT_FROM _
					& " AND A.DATA_CAPTURE_DT	<	" & prmDATA_CAPTURE_DT_TO _
				& ")"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 条件患者番号選択時：TZ_医療費明細情報をTR_医療費明細情報にコピー
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlIns_MTW_MED_COST_INFO_PATIENT_NO As String = _
        " INSERT INTO MTW_MED_COST_INFO " _
            & " SELECT" _
                & " " & prmHOST_NM _
                & ",PATIENT_NO" _
                & ",MED_COST_DATE" _
                & ",SERIAL_NO" _
                & ",DEPT_CD" _
                & ",MNG_NO" _
                & ",MED_COST01" _
                & ",MED_COST02" _
                & ",MED_COST03" _
                & ",MED_COST04" _
                & ",MED_COST05" _
                & ",MED_COST06" _
                & ",MED_COST07" _
                & ",MED_COST08" _
                & ",MED_COST09" _
                & ",MED_COST10" _
                & ",MED_COST11" _
                & ",MED_COST12" _
                & ",MED_COST13" _
                & ",MED_COST14" _
                & ",MED_COST15" _
                & ",MED_COST16" _
                & ",MED_COST17" _
                & ",MED_COST18" _
                & ",MED_COST19" _
                & ",MED_COST20" _
                & ",MED_COST21" _
                & ",MED_COST22" _
                & ",MED_COST23" _
                & ",MED_COST24" _
                & ",MED_COST25" _
                & ",MED_COST26" _
                & ",MED_COST27" _
                & ",MED_COST28" _
                & ",MED_COST29" _
                & ",MED_COST30" _
                & ",MED_COST31" _
                & ",MED_COST32" _
                & ",MED_COST33" _
                & ",MED_COST34" _
                & ",MED_COST35" _
                & ",MED_COST36" _
                & ",MED_COST37" _
                & ",MED_COST38" _
                & ",MED_COST39" _
                & ",MED_COST40" _
                & ",MED_COST41" _
                & ",MED_COST42" _
                & ",MED_COST43" _
                & ",MED_COST44" _
                & ",MED_COST45" _
                & ",OTHER_DEPT_INFO" _
                & ",DATA_CAPTURE_DT" _
                & ",NEW_REG_DT" _
                & ",0" _
                & ",0" _
                & ",'0'" _
                & "," & prmLASTUPDUSER_CD _
                & "," & prmLASTUPD_DT _
            & " FROM" _
                & " MTI_MED_COST_DETAILS" _
            & " WHERE" _
                & " PATIENT_NO   = " & prmPATIENT_NO

    ''' ---------------------------------------------
    ''' <summary>
    ''' 条件退院日選択時：TZ_医療費明細情報をTR_医療費明細情報にコピー
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlIns_MTW_MED_COST_INFO_OUT_HSP_DT As String = _
        " INSERT INTO MTW_MED_COST_INFO " _
            & " SELECT" _
                & " " & prmHOST_NM _
                & ",PATIENT_NO" _
                & ",MED_COST_DATE" _
                & ",SERIAL_NO" _
                & ",DEPT_CD" _
                & ",MNG_NO" _
                & ",MED_COST01" _
                & ",MED_COST02" _
                & ",MED_COST03" _
                & ",MED_COST04" _
                & ",MED_COST05" _
                & ",MED_COST06" _
                & ",MED_COST07" _
                & ",MED_COST08" _
                & ",MED_COST09" _
                & ",MED_COST10" _
                & ",MED_COST11" _
                & ",MED_COST12" _
                & ",MED_COST13" _
                & ",MED_COST14" _
                & ",MED_COST15" _
                & ",MED_COST16" _
                & ",MED_COST17" _
                & ",MED_COST18" _
                & ",MED_COST19" _
                & ",MED_COST20" _
                & ",MED_COST21" _
                & ",MED_COST22" _
                & ",MED_COST23" _
                & ",MED_COST24" _
                & ",MED_COST25" _
                & ",MED_COST26" _
                & ",MED_COST27" _
                & ",MED_COST28" _
                & ",MED_COST29" _
                & ",MED_COST30" _
                & ",MED_COST31" _
                & ",MED_COST32" _
                & ",MED_COST33" _
                & ",MED_COST34" _
                & ",MED_COST35" _
                & ",MED_COST36" _
                & ",MED_COST37" _
                & ",MED_COST38" _
                & ",MED_COST39" _
                & ",MED_COST40" _
                & ",MED_COST41" _
                & ",MED_COST42" _
                & ",MED_COST43" _
                & ",MED_COST44" _
                & ",MED_COST45" _
                & ",OTHER_DEPT_INFO" _
                & ",DATA_CAPTURE_DT" _
                & ",NEW_REG_DT" _
                & ",0" _
                & ",0" _
                & ",'0'" _
                & "," & prmLASTUPDUSER_CD _
                & "," & prmLASTUPD_DT _
            & " FROM" _
                & " MTI_MED_COST_DETAILS" _
            & " WHERE" _
                & " EXISTS (" _
                    & " SELECT " _
                        & " PATIENT_NO" _
                    & " FROM " _
                        & " MTI_HSP" _
                    & " WHERE" _
                    & "     MTI_HSP.PATIENT_NO = MTI_MED_COST_DETAILS.PATIENT_NO" _
                    & " AND OUT_HSP_DT BETWEEN  " & prmOUT_HSP_DT_FROM _
                                        & " AND " & prmOUT_HSP_DT_TO _
                & ")"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 医療費情報テーブルへ明細の合計結果を追加(科歴単位)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlIns_MTI_MED_COST_CH As String = _
        " INSERT INTO MTI_MED_COST " _
            & " SELECT" _
                & " PATIENT_NO" _
                & ",HSP_HISTORY_NO" _
                & ",CH_NO" _
                & ",SUM(MED_COST01)" _
                & ",SUM(MED_COST02)" _
                & ",SUM(MED_COST03)" _
                & ",SUM(MED_COST04)" _
                & ",SUM(MED_COST05)" _
                & ",SUM(MED_COST06)" _
                & ",SUM(MED_COST07)" _
                & ",SUM(MED_COST08)" _
                & ",SUM(MED_COST09)" _
                & ",SUM(MED_COST10)" _
                & ",SUM(MED_COST11)" _
                & ",SUM(MED_COST12)" _
                & ",SUM(MED_COST13)" _
                & ",SUM(MED_COST14)" _
                & ",SUM(MED_COST15)" _
                & ",SUM(MED_COST16)" _
                & ",SUM(MED_COST17)" _
                & ",SUM(MED_COST18)" _
                & ",SUM(MED_COST19)" _
                & ",SUM(MED_COST20)" _
                & ",SUM(MED_COST21)" _
                & ",SUM(MED_COST22)" _
                & ",SUM(MED_COST23)" _
                & ",SUM(MED_COST24)" _
                & ",SUM(MED_COST25)" _
                & ",SUM(MED_COST26)" _
                & ",SUM(MED_COST27)" _
                & ",SUM(MED_COST28)" _
                & ",SUM(MED_COST29)" _
                & ",SUM(MED_COST30)" _
                & ",SUM(MED_COST31)" _
                & ",SUM(MED_COST32)" _
                & ",SUM(MED_COST33)" _
                & ",SUM(MED_COST34)" _
                & ",SUM(MED_COST35)" _
                & ",SUM(MED_COST36)" _
                & ",SUM(MED_COST37)" _
                & ",SUM(MED_COST38)" _
                & ",SUM(MED_COST39)" _
                & ",SUM(MED_COST40)" _
                & ",SUM(MED_COST41)" _
                & ",SUM(MED_COST42)" _
                & ",SUM(MED_COST43)" _
                & ",SUM(MED_COST44)" _
                & ",SUM(MED_COST45)" _
                & "," & prmDATA_CAPTURE_DT _
                & "," & prmNEW_REG_DT _
                & "," & prmLASTUPDUSER_CD _
                & "," & prmLASTUPD_DT _
            & " FROM " _
                & " MTW_MED_COST_INFO " _
            & " WHERE " _
                & " HOST_NM = " & prmHOST_NM _
            & " GROUP BY " _
                & " PATIENT_NO" _
                & ",HSP_HISTORY_NO" _
                & ",CH_NO "

    ''' ---------------------------------------------
    ''' <summary>
    ''' 医療費情報テーブルへ明細の合計結果を追加(入退院単位)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlIns_MTI_MED_COST_HSP As String = _
        " INSERT INTO MTI_MED_COST " _
            & " SELECT" _
                & " PATIENT_NO" _
                & ",HSP_HISTORY_NO" _
                & ",0" _
                & ",SUM(MED_COST01)" _
                & ",SUM(MED_COST02)" _
                & ",SUM(MED_COST03)" _
                & ",SUM(MED_COST04)" _
                & ",SUM(MED_COST05)" _
                & ",SUM(MED_COST06)" _
                & ",SUM(MED_COST07)" _
                & ",SUM(MED_COST08)" _
                & ",SUM(MED_COST09)" _
                & ",SUM(MED_COST10)" _
                & ",SUM(MED_COST11)" _
                & ",SUM(MED_COST12)" _
                & ",SUM(MED_COST13)" _
                & ",SUM(MED_COST14)" _
                & ",SUM(MED_COST15)" _
                & ",SUM(MED_COST16)" _
                & ",SUM(MED_COST17)" _
                & ",SUM(MED_COST18)" _
                & ",SUM(MED_COST19)" _
                & ",SUM(MED_COST20)" _
                & ",SUM(MED_COST21)" _
                & ",SUM(MED_COST22)" _
                & ",SUM(MED_COST23)" _
                & ",SUM(MED_COST24)" _
                & ",SUM(MED_COST25)" _
                & ",SUM(MED_COST26)" _
                & ",SUM(MED_COST27)" _
                & ",SUM(MED_COST28)" _
                & ",SUM(MED_COST29)" _
                & ",SUM(MED_COST30)" _
                & ",SUM(MED_COST31)" _
                & ",SUM(MED_COST32)" _
                & ",SUM(MED_COST33)" _
                & ",SUM(MED_COST34)" _
                & ",SUM(MED_COST35)" _
                & ",SUM(MED_COST36)" _
                & ",SUM(MED_COST37)" _
                & ",SUM(MED_COST38)" _
                & ",SUM(MED_COST39)" _
                & ",SUM(MED_COST40)" _
                & ",SUM(MED_COST41)" _
                & ",SUM(MED_COST42)" _
                & ",SUM(MED_COST43)" _
                & ",SUM(MED_COST44)" _
                & ",SUM(MED_COST45)" _
                & "," & prmDATA_CAPTURE_DT _
                & "," & prmNEW_REG_DT _
                & "," & prmLASTUPDUSER_CD _
                & "," & prmLASTUPD_DT _
            & " FROM " _
                & " MTI_MED_COST " _
            & " WHERE " _
                & " EXISTS (" _
                    & " SELECT " _
                        & " PATIENT_NO" _
                        & ",HSP_HISTORY_NO" _
                    & " FROM " _
                        & " MTW_MED_COST_INFO" _
                    & " WHERE " _
                        & "     HOST_NM = " & prmHOST_NM _
                        & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_MED_COST.PATIENT_NO " _
                        & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_MED_COST.HSP_HISTORY_NO " _
                & " )" _
            & "	GROUP BY " _
                    & " MTI_MED_COST.PATIENT_NO" _
                    & ",MTI_MED_COST.HSP_HISTORY_NO"

#End Region

#Region "UPDATE"

    ''' ---------------------------------------------
    ''' <summary>
    ''' TR_医療費明細情報テーブルの入退院番号、科歴番号、対象フラグ更新
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlUpd_MTW_MED_COST_INFO As String = _
        " UPDATE MTW_MED_COST_INFO SET " _
            & " HSP_HISTORY_NO      = " & prmHSP_HISTORY_NO _
            & ",CH_NO               = " & prmCH_NO _
            & ",OBJECT_FLG          = " & prmOBJECT_FLG _
        & " WHERE" _
            & "     HOST_NM         = " & prmHOST_NM _
            & " AND PATIENT_NO      = " & prmPATIENT_NO _
            & " AND MED_COST_DATE   = " & prmMED_COST_DATE _
            & " AND SERIAL_NO       = " & prmSERIAL_NO

    ''' ---------------------------------------------
    ''' <summary>
    ''' 医療費合計、医療費数を取得(入退院)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlUpd_MTI_HSP_TOTALMEDCOST As String = _
        " UPDATE MTI_HSP SET " _
            & " TOTAL_MED_COST  = A.COST" _
            & ",MED_COST_COUNT  = A.CNT" _
            & ",DATA_CAPTURE_DT = " & prmDATA_CAPTURE_DT _
            & ",LASTUPDUSER_CD  = " & prmLASTUPDUSER_CD _
            & ",LASTUPD_DT      = " & prmLASTUPD_DT _
        & " FROM " _
            & " MTI_HSP INNER JOIN (" _
            & " SELECT" _
                & " MTI_HSP.PATIENT_NO" _
                & ",MTI_HSP.HSP_HISTORY_NO" _
                & ",({0}) AS COST" _
                & ",CASE WHEN MTI_MED_COST.PATIENT_NO IS NULL THEN 0 ELSE 1 END AS CNT " _
            & " FROM" _
                & " MTI_HSP " _
                & " LEFT JOIN MTI_MED_COST ON " _
                    & "     MTI_HSP.PATIENT_NO = MTI_MED_COST.PATIENT_NO " _
                    & " AND MTI_HSP.HSP_HISTORY_NO = MTI_MED_COST.HSP_HISTORY_NO " _
                    & " AND MTI_MED_COST.CH_NO = 0 " _
            & "	WHERE" _
                & " EXISTS (" _
                    & "SELECT " _
                        & " PATIENT_NO" _
                        & ",HSP_HISTORY_NO " _
                    & " FROM " _
                        & " MTW_MED_COST_INFO " _
                    & " WHERE " _
                        & "     HOST_NM                             = " & prmHOST_NM _
                        & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_HSP.PATIENT_NO " _
                        & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_HSP.HSP_HISTORY_NO " _
                & ") ) AS A ON " _
                & "     MTI_HSP.PATIENT_NO      = A.PATIENT_NO " _
                & " AND MTI_HSP.HSP_HISTORY_NO  = A.HSP_HISTORY_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 医療費合計、医療費数を取得(入退院)合計対象無し
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlUpd_MTI_HSP_TOTALMEDCOST_NOTCHECK As String = _
        " UPDATE MTI_HSP SET " _
            & " TOTAL_MED_COST  = A.COST" _
            & ",MED_COST_COUNT  = A.CNT" _
            & ",DATA_CAPTURE_DT = " & prmDATA_CAPTURE_DT _
            & ",LASTUPDUSER_CD  = " & prmLASTUPDUSER_CD _
            & ",LASTUPD_DT      = " & prmLASTUPD_DT _
        & " FROM " _
            & " MTI_HSP INNER JOIN (" _
            & " SELECT" _
                & " MTI_HSP.PATIENT_NO" _
                & ",MTI_HSP.HSP_HISTORY_NO" _
                & ",0 AS COST" _
                & ",CASE WHEN MTI_MED_COST.PATIENT_NO IS NULL THEN 0 ELSE 1 END AS CNT " _
            & " FROM" _
                & " MTI_HSP " _
                & " LEFT JOIN MTI_MED_COST ON " _
                    & "     MTI_HSP.PATIENT_NO = MTI_MED_COST.PATIENT_NO " _
                    & " AND MTI_HSP.HSP_HISTORY_NO = MTI_MED_COST.HSP_HISTORY_NO " _
                    & " AND MTI_MED_COST.CH_NO = 0 " _
            & "	WHERE" _
                & " EXISTS (" _
                    & "SELECT " _
                        & " PATIENT_NO" _
                        & ",HSP_HISTORY_NO " _
                    & " FROM " _
                        & " MTW_MED_COST_INFO " _
                    & " WHERE " _
                        & "     HOST_NM                             = " & prmHOST_NM _
                        & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_HSP.PATIENT_NO " _
                        & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_HSP.HSP_HISTORY_NO " _
                & ") ) AS A ON " _
                & "     MTI_HSP.PATIENT_NO      = A.PATIENT_NO " _
                & " AND MTI_HSP.HSP_HISTORY_NO  = A.HSP_HISTORY_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 医療費合計、医療費数を取得(科歴)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlUpd_MTI_CH_TOTALMEDCOST As String = _
        " UPDATE MTI_CH SET " _
            & " TOTAL_MED_COST  = A.COST" _
            & ",MED_COST_COUNT  = A.CNT" _
            & ",DATA_CAPTURE_DT = " & prmDATA_CAPTURE_DT _
            & ",LASTUPDUSER_CD  = " & prmLASTUPDUSER_CD _
            & ",LASTUPD_DT      = " & prmLASTUPD_DT _
        & " FROM " _
            & " MTI_CH INNER JOIN (" _
                & " SELECT" _
                    & " MTI_CH.PATIENT_NO" _
                    & ",MTI_CH.HSP_HISTORY_NO" _
                    & ",MTI_CH.CH_NO" _
                    & ",({0}) AS COST" _
                    & ",CASE WHEN MTI_MED_COST.PATIENT_NO IS NULL THEN 0 ELSE 1 END AS CNT " _
                & " FROM" _
                    & " MTI_CH " _
                    & " LEFT JOIN MTI_MED_COST ON " _
                        & "     MTI_CH.PATIENT_NO       = MTI_MED_COST.PATIENT_NO" _
                        & " AND MTI_CH.HSP_HISTORY_NO   = MTI_MED_COST.HSP_HISTORY_NO" _
                        & " AND MTI_CH.CH_NO            = MTI_MED_COST.CH_NO" _
                & "	WHERE" _
                    & " EXISTS (" _
                        & "SELECT " _
                            & " PATIENT_NO" _
                            & ",HSP_HISTORY_NO " _
                            & ",CH_NO" _
                        & " FROM " _
                            & " MTW_MED_COST_INFO " _
                        & " WHERE " _
                            & "     HOST_NM                             = " & prmHOST_NM _
                            & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_CH.PATIENT_NO " _
                            & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_CH.HSP_HISTORY_NO " _
                            & " AND MTW_MED_COST_INFO.CH_NO             = MTI_CH.CH_NO" _
                    & ") ) AS A ON " _
                        & "     MTI_CH.PATIENT_NO       = A.PATIENT_NO " _
                        & " AND MTI_CH.HSP_HISTORY_NO   = A.HSP_HISTORY_NO" _
                        & " AND MTI_CH.CH_NO            = A.CH_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 医療費合計、医療費数を取得(科歴)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlUpd_MTI_CH_TOTALMEDCOST_NOTCHECK As String = _
        " UPDATE MTI_CH SET " _
            & " TOTAL_MED_COST  = A.COST" _
            & ",MED_COST_COUNT  = A.CNT" _
            & ",DATA_CAPTURE_DT    = " & prmDATA_CAPTURE_DT _
            & ",LASTUPDUSER_CD     = " & prmLASTUPDUSER_CD _
            & ",LASTUPD_DT         = " & prmLASTUPD_DT _
        & " FROM " _
            & " MTI_CH INNER JOIN (" _
                & " SELECT" _
                    & " MTI_CH.PATIENT_NO" _
                    & ",MTI_CH.HSP_HISTORY_NO" _
                    & ",MTI_CH.CH_NO" _
                    & ",0 AS COST" _
                    & ",CASE WHEN MTI_MED_COST.PATIENT_NO IS NULL THEN 0 ELSE 1 END AS CNT " _
                & " FROM" _
                    & " MTI_CH " _
                    & " LEFT JOIN MTI_MED_COST ON " _
                        & "     MTI_CH.PATIENT_NO       = MTI_MED_COST.PATIENT_NO" _
                        & " AND MTI_CH.HSP_HISTORY_NO   = MTI_MED_COST.HSP_HISTORY_NO" _
                        & " AND MTI_CH.CH_NO            = MTI_MED_COST.CH_NO" _
                & "	WHERE" _
                    & " EXISTS (" _
                        & "SELECT " _
                            & " PATIENT_NO" _
                            & ",HSP_HISTORY_NO " _
                            & ",CH_NO" _
                        & " FROM " _
                            & " MTW_MED_COST_INFO " _
                        & " WHERE " _
                            & "     HOST_NM                             = " & prmHOST_NM _
                            & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_CH.PATIENT_NO " _
                            & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_CH.HSP_HISTORY_NO " _
                            & " AND MTW_MED_COST_INFO.CH_NO             = MTI_CH.CH_NO" _
                    & ") ) AS A ON " _
                        & "     MTI_CH.PATIENT_NO       = A.PATIENT_NO " _
                        & " AND MTI_CH.HSP_HISTORY_NO   = A.HSP_HISTORY_NO" _
                        & " AND MTI_CH.CH_NO            = A.CH_NO"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 科歴情報から医療費合計、医療費数を取得(入退院)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlUpd_MTI_HSP_TOTALMEDCOST_CH As String = _
        " UPDATE MTI_HSP SET " _
            & " TOTAL_MED_COST = A.COST" _
            & ",MED_COST_COUNT = CASE WHEN A.CNT > 0 THEN 1 ELSE 0 END" _
            & ",DATA_CAPTURE_DT    = " & prmDATA_CAPTURE_DT _
            & ",LASTUPDUSER_CD     = " & prmLASTUPDUSER_CD _
            & ",LASTUPD_DT         = " & prmLASTUPD_DT _
        & " FROM " _
            & "MTI_HSP INNER JOIN (" _
            & " SELECT" _
                & " PATIENT_NO" _
                & ",HSP_HISTORY_NO" _
                & ",SUM(TOTAL_MED_COST) AS COST" _
                & ",SUM(MED_COST_COUNT) AS CNT" _
            & " FROM" _
                & " MTI_CH " _
            & "	WHERE" _
                & " EXISTS (" _
                    & "SELECT " _
                        & " PATIENT_NO" _
                        & ",HSP_HISTORY_NO " _
                   & " FROM " _
                        & " MTW_MED_COST_INFO " _
                    & " WHERE " _
                        & "     HOST_NM                             = " & prmHOST_NM _
                        & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_CH.PATIENT_NO " _
                        & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_CH.HSP_HISTORY_NO " _
                    & ")" _
            & " GROUP BY " _
                & " MTI_CH.PATIENT_NO" _
                & ",MTI_CH.HSP_HISTORY_NO " _
            & ") AS A ON " _
                & "     MTI_HSP.PATIENT_NO       = A.PATIENT_NO " _
                & " AND MTI_HSP.HSP_HISTORY_NO   = A.HSP_HISTORY_NO"

#End Region

#Region "DELETE"

    ''' ---------------------------------------------
    ''' <summary>
    ''' TR_医療費明細情報テーブルの削除
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlDel_MTW_MED_COST_INFO As String = _
        " DELETE FROM MTW_MED_COST_INFO " _
        & " WHERE " _
            & "     HOST_NM = " & prmHOST_NM _
            & " AND (OBJECT_FLG = " & prmOBJECT_FLG _
                & " OR OBJECT_FLG IS NULL) "

    ''' ---------------------------------------------
    ''' <summary>
    ''' 医療費情報削除(入退院管理)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlDel_MTI_MED_COST_HSP As String =
        " DELETE FROM MTI_MED_COST" _
            & " WHERE" _
                & " EXISTS (" _
                    & " SELECT " _
                        & " PATIENT_NO" _
                    & " FROM" _
                        & " MTW_MED_COST_INFO" _
                    & " WHERE" _
                        & "     MTW_MED_COST_INFO.HOST_NM   = " & prmHOST_NM _
                        & " AND MTI_MED_COST.PATIENT_NO     = MTW_MED_COST_INFO.PATIENT_NO" _
                        & " AND MTI_MED_COST.HSP_HISTORY_NO = MTW_MED_COST_INFO.HSP_HISTORY_NO" _
                        & " AND MTI_MED_COST.CH_NO          = 0" _
                & ")"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 医療費情報削除(科歴管理)
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlDel_MTI_MED_COST_CH As String =
        " DELETE FROM MTI_MED_COST" _
            & " WHERE" _
                & " EXISTS (" _
                    & " SELECT " _
                        & " PATIENT_NO" _
                    & " FROM" _
                        & " MTW_MED_COST_INFO" _
                    & " WHERE" _
                        & "     MTW_MED_COST_INFO.HOST_NM   = " & prmHOST_NM _
                        & " AND MTI_MED_COST.PATIENT_NO     = MTW_MED_COST_INFO.PATIENT_NO" _
                        & " AND MTI_MED_COST.HSP_HISTORY_NO = MTW_MED_COST_INFO.HSP_HISTORY_NO" _
                        & " AND MTI_MED_COST.CH_NO          = MTW_MED_COST_INFO.CH_NO" _
                & ")"

    ''' ---------------------------------------------
    ''' <summary>
    ''' TI_医療費情報テーブルの削除（全医療費が0のレコード）
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlDel_MTI_MED_COST_AT0_1 As String = _
        " DELETE FROM MTI_MED_COST" _
        & " WHERE" _
            & " EXISTS" _
                & " (SELECT" _
                    & " PATIENT_NO," _
                    & " HSP_HISTORY_NO" _
                & " FROM" _
                    & " MTW_MED_COST_INFO" _
                & " WHERE" _
                    & "     MTW_MED_COST_INFO.HOST_NM           = " & prmHOST_NM _
                    & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_MED_COST.PATIENT_NO" _
                    & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_MED_COST.HSP_HISTORY_NO" _
                & ")" _
        & " AND CH_NO      = 0" _
        & " AND MED_COST01 = 0" _
        & " AND MED_COST02 = 0" _
        & " AND MED_COST03 = 0" _
        & " AND MED_COST04 = 0" _
        & " AND MED_COST05 = 0" _
        & " AND MED_COST06 = 0" _
        & " AND MED_COST07 = 0" _
        & " AND MED_COST08 = 0" _
        & " AND MED_COST09 = 0" _
        & " AND MED_COST10 = 0" _
        & " AND MED_COST11 = 0" _
        & " AND MED_COST12 = 0" _
        & " AND MED_COST13 = 0" _
        & " AND MED_COST14 = 0" _
        & " AND MED_COST15 = 0" _
        & " AND MED_COST16 = 0" _
        & " AND MED_COST17 = 0" _
        & " AND MED_COST18 = 0" _
        & " AND MED_COST19 = 0" _
        & " AND MED_COST20 = 0" _
        & " AND MED_COST21 = 0" _
        & " AND MED_COST22 = 0" _
        & " AND MED_COST23 = 0" _
        & " AND MED_COST24 = 0" _
        & " AND MED_COST25 = 0" _
        & " AND MED_COST26 = 0" _
        & " AND MED_COST27 = 0" _
        & " AND MED_COST28 = 0" _
        & " AND MED_COST29 = 0" _
        & " AND MED_COST30 = 0" _
        & " AND MED_COST31 = 0" _
        & " AND MED_COST32 = 0" _
        & " AND MED_COST33 = 0" _
        & " AND MED_COST34 = 0" _
        & " AND MED_COST35 = 0" _
        & " AND MED_COST36 = 0" _
        & " AND MED_COST37 = 0" _
        & " AND MED_COST38 = 0" _
        & " AND MED_COST39 = 0" _
        & " AND MED_COST40 = 0" _
        & " AND MED_COST41 = 0" _
        & " AND MED_COST42 = 0" _
        & " AND MED_COST43 = 0" _
        & " AND MED_COST44 = 0" _
        & " AND MED_COST45 = 0"

    ''' ---------------------------------------------
    ''' <summary>
    ''' TI_医療費情報テーブルの削除（全医療費が0のレコード）
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlDel_MTI_MED_COST_AT0_2 As String = _
        " DELETE FROM MTI_MED_COST" _
        & " WHERE" _
            & " EXISTS" _
                & " (SELECT" _
                    & " PATIENT_NO," _
                    & " HSP_HISTORY_NO" _
                & " FROM" _
                    & " MTW_MED_COST_INFO" _
                & " WHERE" _
                    & "     MTW_MED_COST_INFO.HOST_NM           = " & prmHOST_NM _
                    & " AND MTW_MED_COST_INFO.PATIENT_NO        = MTI_MED_COST.PATIENT_NO" _
                    & " AND MTW_MED_COST_INFO.HSP_HISTORY_NO    = MTI_MED_COST.HSP_HISTORY_NO" _
                    & " AND MTW_MED_COST_INFO.CH_NO             = MTI_MED_COST.CH_NO" _
                & ")" _
        & " AND MED_COST01 = 0" _
        & " AND MED_COST02 = 0" _
        & " AND MED_COST03 = 0" _
        & " AND MED_COST04 = 0" _
        & " AND MED_COST05 = 0" _
        & " AND MED_COST06 = 0" _
        & " AND MED_COST07 = 0" _
        & " AND MED_COST08 = 0" _
        & " AND MED_COST09 = 0" _
        & " AND MED_COST10 = 0" _
        & " AND MED_COST11 = 0" _
        & " AND MED_COST12 = 0" _
        & " AND MED_COST13 = 0" _
        & " AND MED_COST14 = 0" _
        & " AND MED_COST15 = 0" _
        & " AND MED_COST16 = 0" _
        & " AND MED_COST17 = 0" _
        & " AND MED_COST18 = 0" _
        & " AND MED_COST19 = 0" _
        & " AND MED_COST20 = 0" _
        & " AND MED_COST21 = 0" _
        & " AND MED_COST22 = 0" _
        & " AND MED_COST23 = 0" _
        & " AND MED_COST24 = 0" _
        & " AND MED_COST25 = 0" _
        & " AND MED_COST26 = 0" _
        & " AND MED_COST27 = 0" _
        & " AND MED_COST28 = 0" _
        & " AND MED_COST29 = 0" _
        & " AND MED_COST30 = 0" _
        & " AND MED_COST31 = 0" _
        & " AND MED_COST32 = 0" _
        & " AND MED_COST33 = 0" _
        & " AND MED_COST34 = 0" _
        & " AND MED_COST35 = 0" _
        & " AND MED_COST36 = 0" _
        & " AND MED_COST37 = 0" _
        & " AND MED_COST38 = 0" _
        & " AND MED_COST39 = 0" _
        & " AND MED_COST40 = 0" _
        & " AND MED_COST41 = 0" _
        & " AND MED_COST42 = 0" _
        & " AND MED_COST43 = 0" _
        & " AND MED_COST44 = 0" _
        & " AND MED_COST45 = 0"

    ''' ---------------------------------------------
    ''' <summary>
    ''' ワークテーブル削除
    ''' </summary>
    ''' ---------------------------------------------
    Public Const sqlDel_MTW_MED_COST_INFO_ALL As String =
        " DELETE FROM MTW_MED_COST_INFO WHERE HOST_NM   =" & prmHOST_NM

#End Region

End Class
