﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 補足項目２情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_ASST2
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
    ''' 2010/12/07 新規作成 CS)溝渕<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If Not Me.disposed Then
        End If
        Me.disposed = True
    End Sub

    ''' ---------------------------------------------	
    ''' <summary>
    ''' Finalize（解放処理）
    ''' </summary>
    ''' <remarks>
    ''' 2010/12/07 新規作成 CS)溝渕<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Public Overloads Sub Dispose() Implements IDisposable.Dispose
        Dispose(True)
        GC.SuppressFinalize(Me)
    End Sub

    ''' ---------------------------------------------	
    ''' <summary>
    ''' Finalize（解放処理）※外からはよばない
    ''' </summary>
    ''' <remarks>
    ''' 2010/12/07 新規作成 CS)溝渕<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Protected Overrides Sub Finalize()
        Dispose(False)
        MyBase.Finalize()
    End Sub
#End Region

    ''' ---------------------------------------------
    ''' <summary>
    ''' コンストラクタ
    ''' </summary>
    ''' <remarks>
    ''' 2010/12/07 新規作成 CS)溝渕<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Sub New()
    End Sub

    ''' ---------------------------------------------
    ''' <summary>
    ''' パラメータの整合性のチェック
    ''' </summary>
    ''' <param name="pPatientNo">患者番号</param>
    ''' <returns>True:正常</returns>
    ''' <remarks>
    ''' 2010/12/07 新規作成 CS)溝渕<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Private Function chkParam(ByVal pPatientNo As String) As Boolean
        Try
            Return Not String.IsNullOrWhiteSpace(pPatientNo)
        Catch ex As Exception
            Throw
        End Try
    End Function

    ''' ---------------------------------------------
    ''' <summary>
    ''' パラメータの整合性のチェック
    ''' </summary>
    ''' <param name="pPatientNo">患者番号</param>
    ''' <param name="pHspHistoryNo">入退院歴番号</param>
    ''' <returns>True:正常</returns>
    ''' <remarks>
    ''' 2010/12/07 新規作成 CS)溝渕<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
        Try
            Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
        Catch ex As Exception
            Throw
        End Try
    End Function

    ''' ---------------------------------------------
    ''' <summary>
    ''' パラメータの整合性のチェック
    ''' </summary>
    ''' <param name="pPatientNo">患者番号</param>
    ''' <param name="pHspHistoryNo">入退院歴番号</param>
    ''' <param name="pChNo">科歴番号</param>
    ''' <returns>True:正常</returns>
    ''' <remarks>
    ''' 2010/12/07 新規作成 CS)溝渕<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
        Try
            Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
        Catch ex As Exception
            Throw
        End Try
    End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目２情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の補足項目２情報（ArrayList内にdatMTI_ASST2_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst2Hsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getAsst2Hsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目２情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の補足項目２情報（ArrayList内にdatMTI_ASST2_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst2Hsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_ASST2.sqlSelAsst2_Hsp)	'SELECT文設定
			db.setParam(sqlMTI_ASST2.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_ASST2.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setVal(sqlMTI_ASST2.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_ASST2.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_ASST2_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目２情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>１入退院分の補足項目２情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst2HspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getAsst2HspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目２情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の補足項目２情報</returns>
	''' <remarks>
	''' 2010/12/24 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst2HspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_ASST2.sqlSelAsst2_Hsp)	'SELECT文設定

			db.setParamDa(sqlMTI_ASST2.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_ASST2.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setValDa(sqlMTI_ASST2.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_ASST2.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目２情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>補足項目２情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst2OneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_ASST2_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getAsst2OneRec(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目２情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>補足項目２情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst2OneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_ASST2_OneRec
		Dim retDat As datMTI_ASST2_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_ASST2.sqlSelAsst2_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_ASST2.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	  '患者番号
			db.setParam(sqlMTI_ASST2.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_ASST2.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_ASST2.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_ASST2.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_ASST2.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_ASST2_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_ASST2_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目２情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>補足項目２情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst2OneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getAsst2OneRecDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目２情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>補足項目２情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getAsst2OneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_ASST2.sqlSelAsst2_OneRec)

			db.setParamDa(sqlMTI_ASST2.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	  '患者番号
			db.setParamDa(sqlMTI_ASST2.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_ASST2.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setValDa(sqlMTI_ASST2.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_ASST2.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_ASST2.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の補足項目２情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelAsst2Patient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "補足項目２情報アクセスクラス", "１患者分の補足項目２情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_ASST2.sqlDelAsst2_Patient)	'DELETE文設定
				db.setParam(sqlMTI_ASST2.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	  '患者番号
				db.setVal(sqlMTI_ASST2.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の補足項目２情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelAsst2Hsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "補足項目２情報アクセスクラス", "１入退院分の補足項目２情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_ASST2.sqlDelAsst2_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_ASST2.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	  '患者番号
				db.setParam(sqlMTI_ASST2.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setVal(sqlMTI_ASST2.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_ASST2.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目２情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelAsst2OneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "補足項目２情報アクセスクラス", "補足項目２情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_ASST2.sqlDelAsst2_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_ASST2.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_ASST2.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setParam(sqlMTI_ASST2.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
				db.setVal(sqlMTI_ASST2.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_ASST2.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_ASST2.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目２情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pAsst2Rec">補足項目２情報クラス</param>
	''' <remarks>
	''' 2010/12/23 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsAsst2OneRec(ByVal db As clsDB, ByVal pAsst2Rec As datMTI_ASST2_OneRec) As Integer
		Try
			Return execInsAsst2OneRec(db, pAsst2Rec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 補足項目２情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pAsst2Rec">補足項目２情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/23 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsAsst2OneRec(ByVal db As clsDB, ByVal pAsst2Rec As datMTI_ASST2_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "補足項目２情報アクセスクラス", "補足項目２情報１データを追加 Start")
		Try
			If pAsst2Rec Is Nothing Then
				Return 0
			End If
			Select Case False
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT1)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT2)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT3)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT4)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT5)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT6)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT7)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT8)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT9)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT10)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT11)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT12)
				Case Not pAsst2Rec.NUMBER1.HasValue
				Case Not pAsst2Rec.NUMBER2.HasValue
				Case Not pAsst2Rec.NUMBER3.HasValue
				Case Not pAsst2Rec.NUMBER4.HasValue
				Case Not pAsst2Rec.NUMBER5.HasValue
				Case Not pAsst2Rec.NUMBER6.HasValue
				Case Not pAsst2Rec.NUMBER7.HasValue
				Case Not pAsst2Rec.NUMBER8.HasValue
				Case Not pAsst2Rec.NUMBER9.HasValue
				Case Not pAsst2Rec.NUMBER10.HasValue
				Case Not pAsst2Rec.NUMBER11.HasValue
				Case Not pAsst2Rec.NUMBER12.HasValue
				Case Not pAsst2Rec.DATE1.HasValue
				Case Not pAsst2Rec.DATE2.HasValue
				Case Not pAsst2Rec.DATE3.HasValue
				Case Not pAsst2Rec.DATE4.HasValue
				Case Not pAsst2Rec.DATE5.HasValue
				Case Not pAsst2Rec.DATE6.HasValue
				Case Not pAsst2Rec.DATE7.HasValue
				Case Not pAsst2Rec.DATE8.HasValue
				Case Not pAsst2Rec.DATE9.HasValue
				Case Not pAsst2Rec.DATE10.HasValue
				Case Not pAsst2Rec.DATE11.HasValue
				Case Not pAsst2Rec.DATE12.HasValue
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO1)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO2)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO3)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO4)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO5)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO6)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO7)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO8)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO9)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO10)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO11)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO12)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT13)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT14)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT15)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT16)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT17)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT18)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT19)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT20)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT21)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT22)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT23)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT24)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT25)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT26)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT27)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT28)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT29)
				Case String.IsNullOrEmpty(pAsst2Rec.TEXT30)
				Case Not pAsst2Rec.NUMBER13.HasValue
				Case Not pAsst2Rec.NUMBER14.HasValue
				Case Not pAsst2Rec.NUMBER15.HasValue
				Case Not pAsst2Rec.NUMBER16.HasValue
				Case Not pAsst2Rec.NUMBER17.HasValue
				Case Not pAsst2Rec.NUMBER18.HasValue
				Case Not pAsst2Rec.NUMBER19.HasValue
				Case Not pAsst2Rec.NUMBER20.HasValue
				Case Not pAsst2Rec.NUMBER21.HasValue
				Case Not pAsst2Rec.NUMBER22.HasValue
				Case Not pAsst2Rec.NUMBER23.HasValue
				Case Not pAsst2Rec.NUMBER24.HasValue
				Case Not pAsst2Rec.NUMBER25.HasValue
				Case Not pAsst2Rec.NUMBER26.HasValue
				Case Not pAsst2Rec.NUMBER27.HasValue
				Case Not pAsst2Rec.NUMBER28.HasValue
				Case Not pAsst2Rec.NUMBER29.HasValue
				Case Not pAsst2Rec.NUMBER30.HasValue
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO13)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO14)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO15)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO16)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO17)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO18)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO19)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO20)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO21)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO22)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO23)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO24)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO25)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO26)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO27)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO28)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO29)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO30)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO31)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO32)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO33)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO34)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO35)
				Case String.IsNullOrEmpty(pAsst2Rec.COMBO36)
				Case Else
					' 全て項目未設定なら追加しない
					Return 0
			End Select
			' INSERT文設定
			db.setSQL(sqlMTI_ASST2.sqlInsAsst2_OneRec)
			' 患者番号
			db.setParam(sqlMTI_ASST2.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmPATIENT_NO, pAsst2Rec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_ASST2.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST2.prmHSP_HISTORY_NO, pAsst2Rec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_ASST2.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_ASST2.prmCH_NO, pAsst2Rec.CH_NO, False)
			' テキスト１
			db.setParam(sqlMTI_ASST2.prmTEXT1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT1, pAsst2Rec.TEXT1)
			' テキスト２
			db.setParam(sqlMTI_ASST2.prmTEXT2, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT2, pAsst2Rec.TEXT2)
			' テキスト３
			db.setParam(sqlMTI_ASST2.prmTEXT3, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT3, pAsst2Rec.TEXT3)
			' テキスト４
			db.setParam(sqlMTI_ASST2.prmTEXT4, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT4, pAsst2Rec.TEXT4)
			' テキスト５
			db.setParam(sqlMTI_ASST2.prmTEXT5, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT5, pAsst2Rec.TEXT5)
			' テキスト６
			db.setParam(sqlMTI_ASST2.prmTEXT6, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT6, pAsst2Rec.TEXT6)
			' テキスト７
			db.setParam(sqlMTI_ASST2.prmTEXT7, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT7, pAsst2Rec.TEXT7)
			' テキスト８
			db.setParam(sqlMTI_ASST2.prmTEXT8, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT8, pAsst2Rec.TEXT8)
			' テキスト９
			db.setParam(sqlMTI_ASST2.prmTEXT9, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT9, pAsst2Rec.TEXT9)
			' テキスト１０
			db.setParam(sqlMTI_ASST2.prmTEXT10, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT10, pAsst2Rec.TEXT10)
			' テキスト１１
			db.setParam(sqlMTI_ASST2.prmTEXT11, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT11, pAsst2Rec.TEXT11)
			' テキスト１２
			db.setParam(sqlMTI_ASST2.prmTEXT12, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT12, pAsst2Rec.TEXT12)
			' 数字１
			db.setParam(sqlMTI_ASST2.prmNUMBER1, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER1.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER1, pAsst2Rec.NUMBER1.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER1, 0)
			End If
			' 数字２
			db.setParam(sqlMTI_ASST2.prmNUMBER2, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER2.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER2, pAsst2Rec.NUMBER2.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER2, 0)
			End If
			' 数字３
			db.setParam(sqlMTI_ASST2.prmNUMBER3, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER3.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER3, pAsst2Rec.NUMBER3.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER3, 0)
			End If
			' 数字４
			db.setParam(sqlMTI_ASST2.prmNUMBER4, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER4.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER4, pAsst2Rec.NUMBER4.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER4, 0)
			End If
			' 数字５
			db.setParam(sqlMTI_ASST2.prmNUMBER5, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER5.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER5, pAsst2Rec.NUMBER5.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER5, 0)
			End If
			' 数字６
			db.setParam(sqlMTI_ASST2.prmNUMBER6, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER6.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER6, pAsst2Rec.NUMBER6.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER6, 0)
			End If
			' 数字７
			db.setParam(sqlMTI_ASST2.prmNUMBER7, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER7.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER7, pAsst2Rec.NUMBER7.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER7, 0)
			End If
			' 数字８
			db.setParam(sqlMTI_ASST2.prmNUMBER8, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER8.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER8, pAsst2Rec.NUMBER8.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER8, 0)
			End If
			' 数字９
			db.setParam(sqlMTI_ASST2.prmNUMBER9, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER9.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER9, pAsst2Rec.NUMBER9.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER9, 0)
			End If
			' 数字１０
			db.setParam(sqlMTI_ASST2.prmNUMBER10, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER10.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER10, pAsst2Rec.NUMBER10.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER10, 0)
			End If
			' 数字１１
			db.setParam(sqlMTI_ASST2.prmNUMBER11, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER11.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER11, pAsst2Rec.NUMBER11.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER11, 0)
			End If
			' 数字１２
			db.setParam(sqlMTI_ASST2.prmNUMBER12, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER12.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER12, pAsst2Rec.NUMBER12.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER12, 0)
			End If
			' 日付１
			db.setParam(sqlMTI_ASST2.prmDATE1, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE1.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE1, pAsst2Rec.DATE1.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE1, Date.MinValue)
			End If
			' 日付２
			db.setParam(sqlMTI_ASST2.prmDATE2, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE2.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE2, pAsst2Rec.DATE2.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE2, Date.MinValue)
			End If
			' 日付３
			db.setParam(sqlMTI_ASST2.prmDATE3, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE3.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE3, pAsst2Rec.DATE3.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE3, Date.MinValue)
			End If
			' 日付４
			db.setParam(sqlMTI_ASST2.prmDATE4, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE4.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE4, pAsst2Rec.DATE4.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE4, Date.MinValue)
			End If
			' 日付５
			db.setParam(sqlMTI_ASST2.prmDATE5, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE5.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE5, pAsst2Rec.DATE5.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE5, Date.MinValue)
			End If
			' 日付６
			db.setParam(sqlMTI_ASST2.prmDATE6, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE6.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE6, pAsst2Rec.DATE6.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE6, Date.MinValue)
			End If
			' 日付７
			db.setParam(sqlMTI_ASST2.prmDATE7, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE7.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE7, pAsst2Rec.DATE7.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE7, Date.MinValue)
			End If
			' 日付８
			db.setParam(sqlMTI_ASST2.prmDATE8, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE8.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE8, pAsst2Rec.DATE8.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE8, Date.MinValue)
			End If
			' 日付９
			db.setParam(sqlMTI_ASST2.prmDATE9, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE9.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE9, pAsst2Rec.DATE9.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE9, Date.MinValue)
			End If
			' 日付１０
			db.setParam(sqlMTI_ASST2.prmDATE10, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE10.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE10, pAsst2Rec.DATE10.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE10, Date.MinValue)
			End If
			' 日付１１
			db.setParam(sqlMTI_ASST2.prmDATE11, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE11.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE11, pAsst2Rec.DATE11.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE11, Date.MinValue)
			End If
			' 日付１２
			db.setParam(sqlMTI_ASST2.prmDATE12, clsDB.Enum_dbType.dbDateTime)
			If pAsst2Rec.DATE12.HasValue Then
				db.setVal(sqlMTI_ASST2.prmDATE12, pAsst2Rec.DATE12.Value)
			Else
				db.setVal(sqlMTI_ASST2.prmDATE12, Date.MinValue)
			End If
			' コンボ１
			db.setParam(sqlMTI_ASST2.prmCOMBO1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO1, pAsst2Rec.COMBO1)
			' コンボ２
			db.setParam(sqlMTI_ASST2.prmCOMBO2, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO2, pAsst2Rec.COMBO2)
			' コンボ３
			db.setParam(sqlMTI_ASST2.prmCOMBO3, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO3, pAsst2Rec.COMBO3)
			' コンボ４
			db.setParam(sqlMTI_ASST2.prmCOMBO4, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO4, pAsst2Rec.COMBO4)
			' コンボ５
			db.setParam(sqlMTI_ASST2.prmCOMBO5, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO5, pAsst2Rec.COMBO5)
			' コンボ６
			db.setParam(sqlMTI_ASST2.prmCOMBO6, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO6, pAsst2Rec.COMBO6)
			' コンボ７
			db.setParam(sqlMTI_ASST2.prmCOMBO7, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO7, pAsst2Rec.COMBO7)
			' コンボ８
			db.setParam(sqlMTI_ASST2.prmCOMBO8, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO8, pAsst2Rec.COMBO8)
			' コンボ９
			db.setParam(sqlMTI_ASST2.prmCOMBO9, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO9, pAsst2Rec.COMBO9)
			' コンボ１０
			db.setParam(sqlMTI_ASST2.prmCOMBO10, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO10, pAsst2Rec.COMBO10)
			' コンボ１１
			db.setParam(sqlMTI_ASST2.prmCOMBO11, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO11, pAsst2Rec.COMBO11)
			' コンボ１２
			db.setParam(sqlMTI_ASST2.prmCOMBO12, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO12, pAsst2Rec.COMBO12)
			' テキスト１３
			db.setParam(sqlMTI_ASST2.prmTEXT13, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT13, pAsst2Rec.TEXT13)
			' テキスト１４
			db.setParam(sqlMTI_ASST2.prmTEXT14, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT14, pAsst2Rec.TEXT14)
			' テキスト１５
			db.setParam(sqlMTI_ASST2.prmTEXT15, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT15, pAsst2Rec.TEXT15)
			' テキスト１６
			db.setParam(sqlMTI_ASST2.prmTEXT16, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT16, pAsst2Rec.TEXT16)
			' テキスト１７
			db.setParam(sqlMTI_ASST2.prmTEXT17, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT17, pAsst2Rec.TEXT17)
			' テキスト１８
			db.setParam(sqlMTI_ASST2.prmTEXT18, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT18, pAsst2Rec.TEXT18)
			' テキスト１９
			db.setParam(sqlMTI_ASST2.prmTEXT19, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT19, pAsst2Rec.TEXT19)
			' テキスト２０
			db.setParam(sqlMTI_ASST2.prmTEXT20, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT20, pAsst2Rec.TEXT20)
			' テキスト２１
			db.setParam(sqlMTI_ASST2.prmTEXT21, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT21, pAsst2Rec.TEXT21)
			' テキスト２２
			db.setParam(sqlMTI_ASST2.prmTEXT22, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT22, pAsst2Rec.TEXT22)
			' テキスト２３
			db.setParam(sqlMTI_ASST2.prmTEXT23, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT23, pAsst2Rec.TEXT23)
			' テキスト２４
			db.setParam(sqlMTI_ASST2.prmTEXT24, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT24, pAsst2Rec.TEXT24)
			' テキスト２５
			db.setParam(sqlMTI_ASST2.prmTEXT25, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT25, pAsst2Rec.TEXT25)
			' テキスト２６
			db.setParam(sqlMTI_ASST2.prmTEXT26, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT26, pAsst2Rec.TEXT26)
			' テキスト２７
			db.setParam(sqlMTI_ASST2.prmTEXT27, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT27, pAsst2Rec.TEXT27)
			' テキスト２８
			db.setParam(sqlMTI_ASST2.prmTEXT28, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT28, pAsst2Rec.TEXT28)
			' テキスト２９
			db.setParam(sqlMTI_ASST2.prmTEXT29, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT29, pAsst2Rec.TEXT29)
			' テキスト３０
			db.setParam(sqlMTI_ASST2.prmTEXT30, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmTEXT30, pAsst2Rec.TEXT30)
			' 数字１３		
			db.setParam(sqlMTI_ASST2.prmNUMBER13, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER13.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER13, pAsst2Rec.NUMBER13.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER13, 0)
			End If
			' 数字１４		
			db.setParam(sqlMTI_ASST2.prmNUMBER14, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER14.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER14, pAsst2Rec.NUMBER14.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER14, 0)
			End If
			' 数字１５		
			db.setParam(sqlMTI_ASST2.prmNUMBER15, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER15.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER15, pAsst2Rec.NUMBER15.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER15, 0)
			End If
			' 数字１６		
			db.setParam(sqlMTI_ASST2.prmNUMBER16, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER16.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER16, pAsst2Rec.NUMBER16.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER16, 0)
			End If
			' 数字１７		
			db.setParam(sqlMTI_ASST2.prmNUMBER17, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER17.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER17, pAsst2Rec.NUMBER17.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER17, 0)
			End If
			' 数字１８		
			db.setParam(sqlMTI_ASST2.prmNUMBER18, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER18.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER18, pAsst2Rec.NUMBER18.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER18, 0)
			End If
			' 数字１９		
			db.setParam(sqlMTI_ASST2.prmNUMBER19, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER19.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER19, pAsst2Rec.NUMBER19.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER19, 0)
			End If
			' 数字２０		
			db.setParam(sqlMTI_ASST2.prmNUMBER20, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER20.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER20, pAsst2Rec.NUMBER20.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER20, 0)
			End If
			' 数字２１		
			db.setParam(sqlMTI_ASST2.prmNUMBER21, clsDB.Enum_dbType.dbInt)
			If pAsst2Rec.NUMBER21.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER21, pAsst2Rec.NUMBER21.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER21, 0)
			End If
			' 数字２２		
			db.setParam(sqlMTI_ASST2.prmNUMBER22, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER22.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER22, pAsst2Rec.NUMBER22.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER22, 0)
			End If
			' 数字２３		
			db.setParam(sqlMTI_ASST2.prmNUMBER23, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER23.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER23, pAsst2Rec.NUMBER23.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER23, 0)
			End If
			' 数字２４		
			db.setParam(sqlMTI_ASST2.prmNUMBER24, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER24.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER24, pAsst2Rec.NUMBER24.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER24, 0)
			End If
			' 数字２５		
			db.setParam(sqlMTI_ASST2.prmNUMBER25, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER25.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER25, pAsst2Rec.NUMBER25.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER25, 0)
			End If
			' 数字２６		
			db.setParam(sqlMTI_ASST2.prmNUMBER26, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER26.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER26, pAsst2Rec.NUMBER26.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER26, 0)
			End If
			' 数字２７		
			db.setParam(sqlMTI_ASST2.prmNUMBER27, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER27.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER27, pAsst2Rec.NUMBER27.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER27, 0)
			End If
			' 数字２８		
			db.setParam(sqlMTI_ASST2.prmNUMBER28, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER28.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER28, pAsst2Rec.NUMBER28.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER28, 0)
			End If
			' 数字２９		
			db.setParam(sqlMTI_ASST2.prmNUMBER29, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER29.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER29, pAsst2Rec.NUMBER29.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER29, 0)
			End If
			' 数字３０		
			db.setParam(sqlMTI_ASST2.prmNUMBER30, clsDB.Enum_dbType.dbNumeric)
			If pAsst2Rec.NUMBER30.HasValue Then
				db.setVal(sqlMTI_ASST2.prmNUMBER30, pAsst2Rec.NUMBER30.Value, False)
			Else
				db.setVal(sqlMTI_ASST2.prmNUMBER30, 0)
			End If
			' コンボ１３
			db.setParam(sqlMTI_ASST2.prmCOMBO13, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO13, pAsst2Rec.COMBO13)
			' コンボ１４
			db.setParam(sqlMTI_ASST2.prmCOMBO14, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO14, pAsst2Rec.COMBO14)
			' コンボ１５
			db.setParam(sqlMTI_ASST2.prmCOMBO15, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO15, pAsst2Rec.COMBO15)
			' コンボ１６
			db.setParam(sqlMTI_ASST2.prmCOMBO16, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO16, pAsst2Rec.COMBO16)
			' コンボ１７
			db.setParam(sqlMTI_ASST2.prmCOMBO17, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO17, pAsst2Rec.COMBO17)
			' コンボ１８
			db.setParam(sqlMTI_ASST2.prmCOMBO18, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO18, pAsst2Rec.COMBO18)
			' コンボ１９
			db.setParam(sqlMTI_ASST2.prmCOMBO19, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO19, pAsst2Rec.COMBO19)
			' コンボ２０
			db.setParam(sqlMTI_ASST2.prmCOMBO20, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO20, pAsst2Rec.COMBO20)
			' コンボ２１
			db.setParam(sqlMTI_ASST2.prmCOMBO21, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO21, pAsst2Rec.COMBO21)
			' コンボ２２
			db.setParam(sqlMTI_ASST2.prmCOMBO22, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO22, pAsst2Rec.COMBO22)
			' コンボ２３
			db.setParam(sqlMTI_ASST2.prmCOMBO23, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO23, pAsst2Rec.COMBO23)
			' コンボ２４
			db.setParam(sqlMTI_ASST2.prmCOMBO24, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO24, pAsst2Rec.COMBO24)
			' コンボ２５
			db.setParam(sqlMTI_ASST2.prmCOMBO25, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO25, pAsst2Rec.COMBO25)
			' コンボ２６
			db.setParam(sqlMTI_ASST2.prmCOMBO26, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO26, pAsst2Rec.COMBO26)
			' コンボ２７
			db.setParam(sqlMTI_ASST2.prmCOMBO27, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO27, pAsst2Rec.COMBO27)
			' コンボ２８
			db.setParam(sqlMTI_ASST2.prmCOMBO28, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO28, pAsst2Rec.COMBO28)
			' コンボ２９
			db.setParam(sqlMTI_ASST2.prmCOMBO29, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO29, pAsst2Rec.COMBO29)
			' コンボ３０
			db.setParam(sqlMTI_ASST2.prmCOMBO30, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO30, pAsst2Rec.COMBO30)
			' コンボ３１
			db.setParam(sqlMTI_ASST2.prmCOMBO31, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO31, pAsst2Rec.COMBO31)
			' コンボ３２
			db.setParam(sqlMTI_ASST2.prmCOMBO32, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO32, pAsst2Rec.COMBO32)
			' コンボ３３
			db.setParam(sqlMTI_ASST2.prmCOMBO33, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO33, pAsst2Rec.COMBO33)
			' コンボ３４
			db.setParam(sqlMTI_ASST2.prmCOMBO34, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO34, pAsst2Rec.COMBO34)
			' コンボ３５
			db.setParam(sqlMTI_ASST2.prmCOMBO35, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO35, pAsst2Rec.COMBO35)
			' コンボ３６
			db.setParam(sqlMTI_ASST2.prmCOMBO36, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_ASST2.prmCOMBO36, pAsst2Rec.COMBO36)
			' 更新者コード
			db.setParam(sqlMTI_ASST2.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pAsst2Rec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_ASST2.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_ASST2.prmLASTUPDUSER_CD, pAsst2Rec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_ASST2.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pAsst2Rec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_ASST2.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_ASST2.prmLASTUPD_DT, pAsst2Rec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
