﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 分娩子情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_CB_CHILD
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso (pCbSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' チェックボックス表示内容の取得
	''' </summary>
	''' <param name="flg">
	''' チェックボックスON＆OFFフラグ
	''' 0:OFF
	''' -1:ON
	''' </param>
	''' <returns>チェックフラグ表示内容</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getCheckFlgDisp(ByVal flg As clsConst.Enum_CheckBox_Flg) As String
		Dim row() As DataRow = Nothing
		Dim iflg As Integer = flg
		Try
			Using dt As DataTable = clsConst.getCheckBox
				row = dt.Select(clsConst.CHK_CD & " = '" & iflg.ToString & "'")
				If row Is Nothing OrElse row.Length = 0 Then
					Return String.Empty
				Else
					Return row(0).Item(clsConst.CHK_NM)
				End If
			End Using
		Catch ex As Exception
			Throw
		Finally
			row = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より分娩子情報クラスを作成
	''' </summary>
	''' <param name="pRow">分娩子情報 DataRow</param>
	''' <returns>分娩子情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getCbChildRecFromDataRow(ByVal pRow As DataRow) As datMTI_CB_CHILD_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子情報アクセスクラス", "DataRow より分娩子情報クラスを作成 Start")
		Dim retDat As datMTI_CB_CHILD_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_CB_CHILD_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の分娩子情報（ArrayList内にdatMTI_CB_CHILD_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbChildCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の分娩子情報（ArrayList内にdatMTI_CB_CHILD_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB_CHILD.sqlSelCbChild_Ch)	'SELECT文設定
			db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_CB_CHILD_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の分娩子情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbChildChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の分娩子情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB_CHILD.sqlSelCbChild_Ch)	'SELECT文設定

			db.setParamDa(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>分娩子情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As datMTI_CB_CHILD_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbChildOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>分娩子情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As datMTI_CB_CHILD_OneRec
		Dim retDat As datMTI_CB_CHILD_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB_CHILD.sqlSelCbChild_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParam(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'分娩子連番
			db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, pCbSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_CB_CHILD_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_CB_CHILD_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>分娩子情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbChildOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>分娩子情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB_CHILD.sqlSelCbChild_OneRec)

			db.setParamDa(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'分娩子連番
			db.setValDa(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, pCbSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pItemCd1">項目コード１</param>
	''' <param name="pItemCd2">項目コード２</param>
	''' <param name="pItemCd3">項目コード３</param>
	''' <param name="pItemCd4">項目コード４</param>
	''' <returns>１科歴分の分娩子情報＋名称（ArrayList内にdatMTI_CB_CHILD_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildPlusCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pItemCd1 As String, ByVal pItemCd2 As String, ByVal pItemCd3 As String, ByVal pItemCd4 As String) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbChildPlusCh(db, pPatientNo, pHspHistoryNo, pChNo, pItemCd1, pItemCd2, pItemCd3, pItemCd4)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報＋名称を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pItemCd1">項目コード１</param>
	''' <param name="pItemCd2">項目コード２</param>
	''' <param name="pItemCd3">項目コード３</param>
	''' <param name="pItemCd4">項目コード４</param>
	''' <returns>１科歴分の分娩子情報＋名称（ArrayList内にdatMTI_CB_CHILD_PLUS_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildPlusCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pItemCd1 As String, ByVal pItemCd2 As String, ByVal pItemCd3 As String, ByVal pItemCd4 As String) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB_CHILD.sqlSelCbChild_Plus_Ch)	'SELECT文設定
			db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParam(sqlMTI_CB_CHILD.prmITEM_CD1, clsDB.Enum_dbType.dbNVarChar)		'項目コード１
			db.setParam(sqlMTI_CB_CHILD.prmITEM_CD2, clsDB.Enum_dbType.dbNVarChar)		'項目コード２
			db.setParam(sqlMTI_CB_CHILD.prmITEM_CD3, clsDB.Enum_dbType.dbNVarChar)		'項目コード３
			db.setParam(sqlMTI_CB_CHILD.prmITEM_CD4, clsDB.Enum_dbType.dbNVarChar)		'項目コード４
			db.setParam(sqlMTI_CB_CHILD.prmCheckOff, clsDB.Enum_dbType.dbInt)			'チェックボックスOFFフラグ
			db.setParam(sqlMTI_CB_CHILD.prmCheckOn, clsDB.Enum_dbType.dbInt)				'チェックボックスONフラグ
			db.setParam(sqlMTI_CB_CHILD.prmCheckOffDisp, clsDB.Enum_dbType.dbNVarChar)	'チェックボックスOFFの表示
			db.setParam(sqlMTI_CB_CHILD.prmCheckOnDisp, clsDB.Enum_dbType.dbNVarChar)		'チェックボックスONの表示
			db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_CB_CHILD.prmITEM_CD1, pItemCd1)
			db.setVal(sqlMTI_CB_CHILD.prmITEM_CD2, pItemCd2)
			db.setVal(sqlMTI_CB_CHILD.prmITEM_CD3, pItemCd3)
			db.setVal(sqlMTI_CB_CHILD.prmITEM_CD4, pItemCd4)
			db.setVal(sqlMTI_CB_CHILD.prmCheckOff, clsConst.Enum_CheckBox_Flg.CheckOff, False)
			db.setVal(sqlMTI_CB_CHILD.prmCheckOn, clsConst.Enum_CheckBox_Flg.CheckOn, False)
			db.setVal(sqlMTI_CB_CHILD.prmCheckOffDisp, getCheckFlgDisp(clsConst.Enum_CheckBox_Flg.CheckOff))
			db.setVal(sqlMTI_CB_CHILD.prmCheckOnDisp, getCheckFlgDisp(clsConst.Enum_CheckBox_Flg.CheckOn))
			iRet = db.execQuery(GetType(datMTI_CB_CHILD_PLUS_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pItemCd1">項目コード１</param>
	''' <param name="pItemCd2">項目コード２</param>
	''' <param name="pItemCd3">項目コード３</param>
	''' <param name="pItemCd4">項目コード４</param>
	''' <returns>１科歴分の分娩子情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildPlusChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pItemCd1 As String, ByVal pItemCd2 As String, ByVal pItemCd3 As String, ByVal pItemCd4 As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbChildPlusChDa(db, pPatientNo, pHspHistoryNo, pChNo, pItemCd1, pItemCd2, pItemCd3, pItemCd4)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報＋名称を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pItemCd1">項目コード１</param>
	''' <param name="pItemCd2">項目コード２</param>
	''' <param name="pItemCd3">項目コード３</param>
	''' <param name="pItemCd4">項目コード４</param>
	''' <returns>１科歴分の分娩子情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildPlusChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pItemCd1 As String, ByVal pItemCd2 As String, ByVal pItemCd3 As String, ByVal pItemCd4 As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB_CHILD.sqlSelCbChild_Plus_Ch)	'SELECT文設定

			db.setParamDa(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_CB_CHILD.prmITEM_CD1, clsDB.Enum_dbType.dbNVarChar)		'項目コード１
			db.setParamDa(sqlMTI_CB_CHILD.prmITEM_CD2, clsDB.Enum_dbType.dbNVarChar)		'項目コード２
			db.setParamDa(sqlMTI_CB_CHILD.prmITEM_CD3, clsDB.Enum_dbType.dbNVarChar)		'項目コード３
			db.setParamDa(sqlMTI_CB_CHILD.prmITEM_CD4, clsDB.Enum_dbType.dbNVarChar)		'項目コード４
			db.setParamDa(sqlMTI_CB_CHILD.prmCheckOff, clsDB.Enum_dbType.dbInt)			'チェックボックスOFFフラグ
			db.setParamDa(sqlMTI_CB_CHILD.prmCheckOn, clsDB.Enum_dbType.dbInt)			'チェックボックスONフラグ
			db.setParamDa(sqlMTI_CB_CHILD.prmCheckOffDisp, clsDB.Enum_dbType.dbNVarChar)	'チェックボックスOFFの表示
			db.setParamDa(sqlMTI_CB_CHILD.prmCheckOnDisp, clsDB.Enum_dbType.dbNVarChar)	'チェックボックスONの表示
			db.setValDa(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_CB_CHILD.prmITEM_CD1, pItemCd1)
			db.setValDa(sqlMTI_CB_CHILD.prmITEM_CD2, pItemCd2)
			db.setValDa(sqlMTI_CB_CHILD.prmITEM_CD3, pItemCd3)
			db.setValDa(sqlMTI_CB_CHILD.prmITEM_CD4, pItemCd4)
			db.setValDa(sqlMTI_CB_CHILD.prmCheckOff, clsConst.Enum_CheckBox_Flg.CheckOff, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCheckOn, clsConst.Enum_CheckBox_Flg.CheckOn, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCheckOffDisp, getCheckFlgDisp(clsConst.Enum_CheckBox_Flg.CheckOff))
			db.setValDa(sqlMTI_CB_CHILD.prmCheckOnDisp, getCheckFlgDisp(clsConst.Enum_CheckBox_Flg.CheckOn))
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <param name="pItemCd1">項目コード１</param>
	''' <param name="pItemCd2">項目コード２</param>
	''' <param name="pItemCd3">項目コード３</param>
	''' <param name="pItemCd4">項目コード４</param>
	''' <returns>分娩子情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildPlusOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer, ByVal pItemCd1 As String, ByVal pItemCd2 As String, ByVal pItemCd3 As String, ByVal pItemCd4 As String) As datMTI_CB_CHILD_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbChildPlusOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo, pItemCd1, pItemCd2, pItemCd3, pItemCd4)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <param name="pItemCd1">項目コード１</param>
	''' <param name="pItemCd2">項目コード２</param>
	''' <param name="pItemCd3">項目コード３</param>
	''' <param name="pItemCd4">項目コード４</param>
	''' <returns>分娩子情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildPlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer, ByVal pItemCd1 As String, ByVal pItemCd2 As String, ByVal pItemCd3 As String, ByVal pItemCd4 As String) As datMTI_CB_CHILD_PLUS_OneRec
		Dim retDat As datMTI_CB_CHILD_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB_CHILD.sqlSelCbChild_Plus_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParam(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'分娩子連番
			db.setParam(sqlMTI_CB_CHILD.prmITEM_CD1, clsDB.Enum_dbType.dbNVarChar)		'項目コード１
			db.setParam(sqlMTI_CB_CHILD.prmITEM_CD2, clsDB.Enum_dbType.dbNVarChar)		'項目コード２
			db.setParam(sqlMTI_CB_CHILD.prmITEM_CD3, clsDB.Enum_dbType.dbNVarChar)		'項目コード３
			db.setParam(sqlMTI_CB_CHILD.prmITEM_CD4, clsDB.Enum_dbType.dbNVarChar)		'項目コード４
			db.setParam(sqlMTI_CB_CHILD.prmCheckOff, clsDB.Enum_dbType.dbInt)			'チェックボックスOFFフラグ
			db.setParam(sqlMTI_CB_CHILD.prmCheckOn, clsDB.Enum_dbType.dbInt)				'チェックボックスONフラグ
			db.setParam(sqlMTI_CB_CHILD.prmCheckOffDisp, clsDB.Enum_dbType.dbNVarChar)	'チェックボックスOFFの表示
			db.setParam(sqlMTI_CB_CHILD.prmCheckOnDisp, clsDB.Enum_dbType.dbNVarChar)		'チェックボックスONの表示
			db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, pCbSerialNo, False)
			db.setVal(sqlMTI_CB_CHILD.prmITEM_CD1, pItemCd1)
			db.setVal(sqlMTI_CB_CHILD.prmITEM_CD2, pItemCd2)
			db.setVal(sqlMTI_CB_CHILD.prmITEM_CD3, pItemCd3)
			db.setVal(sqlMTI_CB_CHILD.prmITEM_CD4, pItemCd4)
			db.setVal(sqlMTI_CB_CHILD.prmCheckOff, clsConst.Enum_CheckBox_Flg.CheckOff, False)
			db.setVal(sqlMTI_CB_CHILD.prmCheckOn, clsConst.Enum_CheckBox_Flg.CheckOn, False)
			db.setVal(sqlMTI_CB_CHILD.prmCheckOffDisp, getCheckFlgDisp(clsConst.Enum_CheckBox_Flg.CheckOff))
			db.setVal(sqlMTI_CB_CHILD.prmCheckOnDisp, getCheckFlgDisp(clsConst.Enum_CheckBox_Flg.CheckOn))
			iRet = db.execQuery(GetType(datMTI_CB_CHILD_PLUS_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_CB_CHILD_PLUS_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <param name="pItemCd1">項目コード１</param>
	''' <param name="pItemCd2">項目コード２</param>
	''' <param name="pItemCd3">項目コード３</param>
	''' <param name="pItemCd4">項目コード４</param>
	''' <returns>分娩子情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildPlusOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer, ByVal pItemCd1 As String, ByVal pItemCd2 As String, ByVal pItemCd3 As String, ByVal pItemCd4 As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbChildPlusOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo, pItemCd1, pItemCd2, pItemCd3, pItemCd4)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <param name="pItemCd1">項目コード１</param>
	''' <param name="pItemCd2">項目コード２</param>
	''' <param name="pItemCd3">項目コード３</param>
	''' <param name="pItemCd4">項目コード４</param>
	''' <returns>分娩子情報＋名称</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbChildPlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer, ByVal pItemCd1 As String, ByVal pItemCd2 As String, ByVal pItemCd3 As String, ByVal pItemCd4 As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB_CHILD.sqlSelCbChild_Plus_OneRec)

			db.setParamDa(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setParamDa(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'分娩子連番
			db.setParamDa(sqlMTI_CB_CHILD.prmITEM_CD1, clsDB.Enum_dbType.dbNVarChar)		'項目コード１
			db.setParamDa(sqlMTI_CB_CHILD.prmITEM_CD2, clsDB.Enum_dbType.dbNVarChar)		'項目コード２
			db.setParamDa(sqlMTI_CB_CHILD.prmITEM_CD3, clsDB.Enum_dbType.dbNVarChar)		'項目コード３
			db.setParamDa(sqlMTI_CB_CHILD.prmITEM_CD4, clsDB.Enum_dbType.dbNVarChar)		'項目コード４
			db.setParamDa(sqlMTI_CB_CHILD.prmCheckOff, clsDB.Enum_dbType.dbInt)			'チェックボックスOFFフラグ
			db.setParamDa(sqlMTI_CB_CHILD.prmCheckOn, clsDB.Enum_dbType.dbInt)			'チェックボックスONフラグ
			db.setParamDa(sqlMTI_CB_CHILD.prmCheckOffDisp, clsDB.Enum_dbType.dbNVarChar)	'チェックボックスOFFの表示
			db.setParamDa(sqlMTI_CB_CHILD.prmCheckOnDisp, clsDB.Enum_dbType.dbNVarChar)	'チェックボックスONの表示
			db.setValDa(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, pCbSerialNo, False)
			db.setValDa(sqlMTI_CB_CHILD.prmITEM_CD1, pItemCd1)
			db.setValDa(sqlMTI_CB_CHILD.prmITEM_CD2, pItemCd2)
			db.setValDa(sqlMTI_CB_CHILD.prmITEM_CD3, pItemCd3)
			db.setValDa(sqlMTI_CB_CHILD.prmITEM_CD4, pItemCd4)
			db.setValDa(sqlMTI_CB_CHILD.prmCheckOff, clsConst.Enum_CheckBox_Flg.CheckOff, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCheckOn, clsConst.Enum_CheckBox_Flg.CheckOn, False)
			db.setValDa(sqlMTI_CB_CHILD.prmCheckOffDisp, getCheckFlgDisp(clsConst.Enum_CheckBox_Flg.CheckOff))
			db.setValDa(sqlMTI_CB_CHILD.prmCheckOnDisp, getCheckFlgDisp(clsConst.Enum_CheckBox_Flg.CheckOn))

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の分娩子情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbChildPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子情報アクセスクラス", "１患者分の分娩子情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB_CHILD.sqlDelCbChild_Patient)	'DELETE文設定
				db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の分娩子情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbChildHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子情報アクセスクラス", "１入退院分の分娩子情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB_CHILD.sqlDelCbChild_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbChildCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子情報アクセスクラス", "１科歴分の分娩子情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB_CHILD.sqlDelCbChild_Ch)	'DELETE文設定
				db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbChildOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子情報アクセスクラス", "分娩子情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB_CHILD.sqlDelCbChild_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setParam(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'分娩子連番
				db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_CB_CHILD.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, pCbSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCbChildRec">分娩子情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbChildOneRec(ByVal db As clsDB, ByVal pCbChildRec As datMTI_CB_CHILD_OneRec) As Integer
		Try
			Return execInsCbChildOneRec(db, pCbChildRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">分娩子情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbChildOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pCbChildRec As datMTI_CB_CHILD_OneRec = Nothing
		Try
			Return execInsCbChildOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pCbChildRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">分娩子情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbChildOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pCbChildRec As datMTI_CB_CHILD_OneRec = Nothing
		Try
			pCbChildRec = getCbChildRecFromDataRow(pRow)
			Return execInsCbChildOneRec(db, pCbChildRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pCbChildRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCbChildPlusRec">分娩子情報＋名称クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbChildOneRec(ByVal db As clsDB, ByVal pCbChildPlusRec As datMTI_CB_CHILD_PLUS_OneRec) As Integer
		Try
			Return execInsCbChildOneRec(db, pCbChildPlusRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCbChildPlusRec">分娩子情報＋名称クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbChildOneRec(ByVal db As clsDB, ByVal pCbChildPlusRec As datMTI_CB_CHILD_PLUS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		Dim pCbChildRec As datMTI_CB_CHILD_OneRec = Nothing
		Try
			If pCbChildPlusRec IsNot Nothing Then
				pCbChildRec = pCbChildPlusRec.OrgCopy
			End If
			Return execInsCbChildOneRec(db, pCbChildRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pCbChildRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCbChildRec">分娩子情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbChildOneRec(ByVal db As clsDB, ByVal pCbChildRec As datMTI_CB_CHILD_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子情報アクセスクラス", "分娩子情報１データを追加 Start")
		Try
			If pCbChildRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_CB_CHILD.sqlInsCbChild_OneRec)
			' 患者番号
			db.setParam(sqlMTI_CB_CHILD.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmPATIENT_NO, pCbChildRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmHSP_HISTORY_NO, pCbChildRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_CB_CHILD.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmCH_NO, pCbChildRec.CH_NO, False)
			' 分娩子連番
			db.setParam(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmCB_SERIAL_NO, pCbChildRec.CB_SERIAL_NO, False)
			' 性別コード
			db.setParam(sqlMTI_CB_CHILD.prmGENDER_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmGENDER_CD, pCbChildRec.GENDER_CD)
			' 新生児身長
			db.setParam(sqlMTI_CB_CHILD.prmNEWBORN_STATURE, clsDB.Enum_dbType.dbNumeric)
			If pCbChildRec.NEWBORN_STATURE.HasValue Then
				db.setVal(sqlMTI_CB_CHILD.prmNEWBORN_STATURE, pCbChildRec.NEWBORN_STATURE.Value, False)
			Else
				db.setVal(sqlMTI_CB_CHILD.prmNEWBORN_STATURE, 0)
			End If
			' 新生児体重
			db.setParam(sqlMTI_CB_CHILD.prmNEWBORN_WEIGHT, clsDB.Enum_dbType.dbInt)
			If pCbChildRec.NEWBORN_WEIGHT.HasValue Then
				db.setVal(sqlMTI_CB_CHILD.prmNEWBORN_WEIGHT, pCbChildRec.NEWBORN_WEIGHT.Value, False)
			Else
				db.setVal(sqlMTI_CB_CHILD.prmNEWBORN_WEIGHT, 0, False)	'必ず値を設定する
			End If
			' アプガー指数１分
			db.setParam(sqlMTI_CB_CHILD.prmAPGARSCORE_1MIN, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmAPGARSCORE_1MIN, pCbChildRec.APGARSCORE_1MIN)
			' アプガー指数５分
			db.setParam(sqlMTI_CB_CHILD.prmAPGARSCORE_5MIN, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmAPGARSCORE_5MIN, pCbChildRec.APGARSCORE_5MIN)
			' 未熟
			db.setParam(sqlMTI_CB_CHILD.prmIMMATURE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmIMMATURE, pCbChildRec.IMMATURE, False)
			' 奇形
			db.setParam(sqlMTI_CB_CHILD.prmDEFORMITY, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmDEFORMITY, pCbChildRec.DEFORMITY, False)
			' 流死産
			db.setParam(sqlMTI_CB_CHILD.prmSTILLBIRTH, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmSTILLBIRTH, pCbChildRec.STILLBIRTH, False)
			' 分娩様式コード１
			db.setParam(sqlMTI_CB_CHILD.prmCB_PTN1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCB_PTN1, pCbChildRec.CB_PTN1)
			' 分娩様式コード２
			db.setParam(sqlMTI_CB_CHILD.prmCB_PTN2, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCB_PTN2, pCbChildRec.CB_PTN2)
			' 分娩様式コード３
			db.setParam(sqlMTI_CB_CHILD.prmCB_PTN3, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCB_PTN3, pCbChildRec.CB_PTN3)
			' 分娩様式コード４
			db.setParam(sqlMTI_CB_CHILD.prmCB_PTN4, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCB_PTN4, pCbChildRec.CB_PTN4)
			' 新生児番号
			db.setParam(sqlMTI_CB_CHILD.prmNEWBORN_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmNEWBORN_NO, pCbChildRec.NEWBORN_NO)
			' 子分娩日
			db.setParam(sqlMTI_CB_CHILD.prmCHD_CB_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_CB_DT, pCbChildRec.CHD_CB_DT)
			' 子分娩時刻
			db.setParam(sqlMTI_CB_CHILD.prmCHD_CB_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_CB_TIME, pCbChildRec.CHD_CB_TIME)
			' 子血液型コード
			db.setParam(sqlMTI_CB_CHILD.prmCHD_BLOODTYPE_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_BLOODTYPE_CD, pCbChildRec.CHD_BLOODTYPE_CD)
			' 子Ｒｈコード
			db.setParam(sqlMTI_CB_CHILD.prmCHD_RH_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_RH_CD, pCbChildRec.CHD_RH_CD)
			' 子患者番号
			db.setParam(sqlMTI_CB_CHILD.prmCHD_PATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_PATIENT_NO, pCbChildRec.CHD_PATIENT_NO)
			' 子備考
			db.setParam(sqlMTI_CB_CHILD.prmCHD_REMARKS, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_REMARKS, pCbChildRec.CHD_REMARKS)
			' 子分娩チェック項目１
			db.setParam(sqlMTI_CB_CHILD.prmCHD_CB_CHK1, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_CB_CHK1, pCbChildRec.CHD_CB_CHK1, False)
			' 子分娩チェック項目２
			db.setParam(sqlMTI_CB_CHILD.prmCHD_CB_CHK2, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_CB_CHK2, pCbChildRec.CHD_CB_CHK2, False)
			' 子分娩チェック項目３
			db.setParam(sqlMTI_CB_CHILD.prmCHD_CB_CHK3, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_CB_CHK3, pCbChildRec.CHD_CB_CHK3, False)
			' 子分娩チェック項目４
			db.setParam(sqlMTI_CB_CHILD.prmCHD_CB_CHK4, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_CB_CHK4, pCbChildRec.CHD_CB_CHK4, False)
			' 子分娩チェック項目５
			db.setParam(sqlMTI_CB_CHILD.prmCHD_CB_CHK5, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_CHILD.prmCHD_CB_CHK5, pCbChildRec.CHD_CB_CHK5, False)
			' 更新者コード
			db.setParam(sqlMTI_CB_CHILD.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pCbChildRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_CB_CHILD.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_CB_CHILD.prmLASTUPDUSER_CD, pCbChildRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_CB_CHILD.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pCbChildRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_CB_CHILD.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_CB_CHILD.prmLASTUPD_DT, pCbChildRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
