﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 分娩子流死産情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_CB_SB
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo, pChNo) AndAlso (pCbSerialNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' DataRow より分娩子流死産情報クラスを作成
	''' </summary>
	''' <param name="pRow">分娩子流死産情報 DataRow</param>
	''' <returns>分娩子流死産情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getCbSbRecFromDataRow(ByVal pRow As DataRow) As datMTI_CB_SB_OneRec
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子流死産情報アクセスクラス", "DataRow より分娩子流死産情報クラスを作成 Start")
		Dim retDat As datMTI_CB_SB_OneRec
		Dim hType As Type = Nothing
		Dim hFieldInfos As FieldInfo() = Nothing
		Dim objValue As Object = Nothing
		Dim bSetValue As Boolean = False
		Try
			' DataRow 無しの場合
			If pRow Is Nothing OrElse pRow.Table.Columns.Count = 0 Then
				Return Nothing
			End If

			' インスタンス生成
			retDat = New datMTI_CB_SB_OneRec

			' クラス要素の取得
			hType = retDat.GetType
			hFieldInfos = hType.GetFields(BindingFlags.GetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly)

			' 値の取得および設定
			For Each aFieldInfo As FieldInfo In hFieldInfos
				' 値を取得
				If Not pRow.Table.Columns.Contains(aFieldInfo.Name) Then
					Continue For
				End If
				objValue = pRow(aFieldInfo.Name)
				' 値を設定
				If objValue IsNot Nothing AndAlso objValue IsNot DBNull.Value Then
					hType.InvokeMember(aFieldInfo.Name, _
					 BindingFlags.SetField Or BindingFlags.Public Or BindingFlags.Instance Or BindingFlags.DeclaredOnly, _
					 Nothing, _
					 retDat, _
					 New Object() {objValue})
					bSetValue = True
				End If
			Next
			If bSetValue Then
				Return retDat
			Else
				Return Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			hType = Nothing
			hFieldInfos = Nothing
			objValue = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子流死産情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の分娩子流死産情報（ArrayList内にdatMTI_CB_SB_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbSbCh(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbSbCh(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子流死産情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の分娩子流死産情報（ArrayList内にdatMTI_CB_SB_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbSbCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB_SB.sqlSelCbSb_Ch)	'SELECT文設定
			db.setParam(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParam(sqlMTI_CB_SB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParam(sqlMTI_CB_SB.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setVal(sqlMTI_CB_SB.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CB_SB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CB_SB.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_CB_SB_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子流死産情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の分娩子流死産情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbSbChDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbSbChDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子流死産情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>１科歴分の分娩子流死産情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成　CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbSbChDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB_SB.sqlSelCbSb_Ch)	'SELECT文設定

			db.setParamDa(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
			db.setParamDa(sqlMTI_CB_SB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
			db.setParamDa(sqlMTI_CB_SB.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_CB_SB.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CB_SB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CB_SB.prmCH_NO, pChNo, False)
			db.execQueryDa(retDat)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>分娩子流死産情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbSbOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As datMTI_CB_SB_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbSbOneRec(db, pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>分娩子流死産情報クラス</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbSbOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As datMTI_CB_SB_OneRec
		Dim retDat As datMTI_CB_SB_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_CB_SB.sqlSelCbSb_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_CB_SB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_CB_SB.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setParam(sqlMTI_CB_SB.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'分娩子連番
			db.setVal(sqlMTI_CB_SB.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_CB_SB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_CB_SB.prmCH_NO, pChNo, False)
			db.setVal(sqlMTI_CB_SB.prmCB_SERIAL_NO, pCbSerialNo, False)
			iRet = db.execQuery(GetType(datMTI_CB_SB_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_CB_SB_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>分娩子流死産情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbSbOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getCbSbOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <returns>分娩子流死産情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getCbSbOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_CB_SB.sqlSelCbSb_OneRec)

			db.setParamDa(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_CB_SB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_CB_SB.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setParamDa(sqlMTI_CB_SB.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)		'分娩子連番
			db.setValDa(sqlMTI_CB_SB.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_CB_SB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_CB_SB.prmCH_NO, pChNo, False)
			db.setValDa(sqlMTI_CB_SB.prmCB_SERIAL_NO, pCbSerialNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の分娩子流死産情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbSbPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子流死産情報アクセスクラス", "１患者分の分娩子流死産情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB_SB.sqlDelCbSb_Patient)	'DELETE文設定
				db.setParam(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_CB_SB.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の分娩子流死産情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbSbHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子流死産情報アクセスクラス", "１入退院分の分娩子流死産情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB_SB.sqlDelCbSb_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CB_SB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setVal(sqlMTI_CB_SB.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CB_SB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １科歴分の分娩子流死産情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbSbCh(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子流死産情報アクセスクラス", "１科歴分の分娩子流死産情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB_SB.sqlDelCbSb_Ch)	'DELETE文設定
				db.setParam(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CB_SB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_CB_SB.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setVal(sqlMTI_CB_SB.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CB_SB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_CB_SB.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <param name="pCbSerialNo">分娩子連番</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelCbSbOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer, ByVal pCbSerialNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子流死産情報アクセスクラス", "分娩子流死産情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo, pCbSerialNo) Then
				' 削除実行
				db.setSQL(sqlMTI_CB_SB.sqlDelCbSb_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setParam(sqlMTI_CB_SB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
				db.setParam(sqlMTI_CB_SB.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
				db.setParam(sqlMTI_CB_SB.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)	'分娩子連番
				db.setVal(sqlMTI_CB_SB.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_CB_SB.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_CB_SB.prmCH_NO, pChNo, False)
				db.setVal(sqlMTI_CB_SB.prmCB_SERIAL_NO, pCbSerialNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCbSbRec">分娩子流死産情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbSbOneRec(ByVal db As clsDB, ByVal pCbSbRec As datMTI_CB_SB_OneRec) As Integer
		Try
			Return execInsCbSbOneRec(db, pCbSbRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">分娩子流死産情報 DataRow</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbSbOneRec(ByVal db As clsDB, ByVal pRow As DataRow) As Integer
		Dim pCbSbRec As datMTI_CB_SB_OneRec = Nothing
		Try
			Return execInsCbSbOneRec(db, pRow, True)
		Catch ex As Exception
			Throw
		Finally
			pCbSbRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pRow">分娩子流死産情報 DataRow</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbSbOneRec(ByVal db As clsDB, ByVal pRow As DataRow, ByVal bLastUpdate As Boolean) As Integer
		Dim pCbSbRec As datMTI_CB_SB_OneRec = Nothing
		Try
			pCbSbRec = getCbSbRecFromDataRow(pRow)
			Return execInsCbSbOneRec(db, pCbSbRec, bLastUpdate)
		Catch ex As Exception
			Throw
		Finally
			pCbSbRec = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 分娩子流死産情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pCbSbRec">分娩子流死産情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsCbSbOneRec(ByVal db As clsDB, ByVal pCbSbRec As datMTI_CB_SB_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "分娩子流死産情報アクセスクラス", "分娩子流死産情報１データを追加 Start")
		Try
			If pCbSbRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_CB_SB.sqlInsCbSb_OneRec)
			' 患者番号
			db.setParam(sqlMTI_CB_SB.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmPATIENT_NO, pCbSbRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_CB_SB.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_SB.prmHSP_HISTORY_NO, pCbSbRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_CB_SB.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_SB.prmCH_NO, pCbSbRec.CH_NO, False)
			' 分娩子連番
			db.setParam(sqlMTI_CB_SB.prmCB_SERIAL_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_SB.prmCB_SERIAL_NO, pCbSbRec.CB_SERIAL_NO, False)
			' 流死産番号
			db.setParam(sqlMTI_CB_SB.prmSB_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmSB_NO, pCbSbRec.SB_NO)
			' 流死産日
			db.setParam(sqlMTI_CB_SB.prmSB_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_CB_SB.prmSB_DT, pCbSbRec.SB_DT)
			' 流死産時刻
			db.setParam(sqlMTI_CB_SB.prmSB_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmSB_TIME, pCbSbRec.SB_TIME)
			' 週数
			db.setParam(sqlMTI_CB_SB.prmWEEK_COUNT, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_CB_SB.prmWEEK_COUNT, pCbSbRec.WEEK_COUNT, False)
			' 流死産場所コード
			db.setParam(sqlMTI_CB_SB.prmSB_LCT, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmSB_LCT, pCbSbRec.SB_LCT)
			' 剖検有無コード
			db.setParam(sqlMTI_CB_SB.prmAUTOPSY_CHK, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmAUTOPSY_CHK, pCbSbRec.AUTOPSY_CHK)
			' 剖検番号
			db.setParam(sqlMTI_CB_SB.prmAUTOPSY_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmAUTOPSY_NO, pCbSbRec.AUTOPSY_NO)
			' 人工中絶有無コード
			db.setParam(sqlMTI_CB_SB.prmINDUCED_ABORTION_CHK, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmINDUCED_ABORTION_CHK, pCbSbRec.INDUCED_ABORTION_CHK)
			' 母体合併症有無コード
			db.setParam(sqlMTI_CB_SB.prmMOTHER_CMPC_CHK, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmMOTHER_CMPC_CHK, pCbSbRec.MOTHER_CMPC_CHK)
			' コメント
			db.setParam(sqlMTI_CB_SB.prmREMARKS, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_CB_SB.prmREMARKS, pCbSbRec.REMARKS)
			' 更新者コード
			db.setParam(sqlMTI_CB_SB.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pCbSbRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_CB_SB.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_CB_SB.prmLASTUPDUSER_CD, pCbSbRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_CB_SB.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pCbSbRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_CB_SB.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_CB_SB.prmLASTUPD_DT, pCbSbRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
