﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 死亡情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_DEATH
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' SQLパラメータをセットする
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="ptnNo">ＳＱＬパターン</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function setSqlParam(ByVal db As clsDB, ByVal ptnNo As sqlMTI_DEATH.Enum_SqlNo, ByVal pPatientNo As String) As Boolean
		Try
			' パラメータの整合性のチェック
			If Not chkParam(pPatientNo) Then
				Return False
			End If

			' SELECT文設定＆患者番号
			Select Case ptnNo
				Case sqlMTI_DEATH.Enum_SqlNo.sqlSelDeath_OneRec
					db.setSQL(sqlMTI_DEATH.sqlSelDeath_OneRec)								'SELECT文設定
					db.setParam(sqlMTI_DEATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
					db.setVal(sqlMTI_DEATH.prmPATIENT_NO, pPatientNo)
				Case sqlMTI_DEATH.Enum_SqlNo.sqlSelDeath_OneRec_Da
					db.setSQLDa(sqlMTI_DEATH.sqlSelDeath_OneRec)							'SELECT文設定
					db.setParamDa(sqlMTI_DEATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
					db.setValDa(sqlMTI_DEATH.prmPATIENT_NO, pPatientNo)
				Case sqlMTI_DEATH.Enum_SqlNo.sqlSelDeath_Plus_OneRec
					db.setSQL(sqlMTI_DEATH.sqlSelDeath_Plus_OneRec)							'SELECT文設定
					db.setParam(sqlMTI_DEATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
					db.setVal(sqlMTI_DEATH.prmPATIENT_NO, pPatientNo)
				Case sqlMTI_DEATH.Enum_SqlNo.sqlSelDeath_Plus_OneRec_Da
					db.setSQLDa(sqlMTI_DEATH.sqlSelDeath_Plus_OneRec)						'SELECT文設定
					db.setParamDa(sqlMTI_DEATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
					db.setValDa(sqlMTI_DEATH.prmPATIENT_NO, pPatientNo)
				Case Else
					Return False
			End Select
			Return True
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>死亡情報クラス</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDeathOneRec(ByVal pPatientNo As String) As datMTI_DEATH_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getDeathOneRec(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>死亡情報クラス</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDeathOneRec(ByVal db As clsDB, ByVal pPatientNo As String) As datMTI_DEATH_OneRec
		Dim retDat As datMTI_DEATH_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()
			If setSqlParam(db, sqlMTI_DEATH.Enum_SqlNo.sqlSelDeath_OneRec, pPatientNo) Then
				iRet = db.execQuery(GetType(datMTI_DEATH_OneRec), arData)	'値取得
				If iRet > 0 Then										'レコードあり
					retDat = DirectCast(arData(0), datMTI_DEATH_OneRec)
				End If
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>死亡情報</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDeathOneRecDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getDeathOneRecDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>死亡情報</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDeathOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable
			If setSqlParam(db, sqlMTI_DEATH.Enum_SqlNo.sqlSelDeath_OneRec_Da, pPatientNo) Then
				db.execQueryDa(retDat)	'値取得
			End If
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>死亡情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDeathPlusOneRec(ByVal pPatientNo As String) As datMTI_DEATH_PLUS_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getDeathPlusOneRec(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報＋名称を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>死亡情報＋名称クラス</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDeathPlusOneRec(ByVal db As clsDB, ByVal pPatientNo As String) As datMTI_DEATH_PLUS_OneRec
		Dim retDat As datMTI_DEATH_PLUS_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()
			If setSqlParam(db, sqlMTI_DEATH.Enum_SqlNo.sqlSelDeath_Plus_OneRec, pPatientNo) Then
				iRet = db.execQuery(GetType(datMTI_DEATH_PLUS_OneRec), arData)	'値取得
				If iRet > 0 Then										'レコードあり
					retDat = DirectCast(arData(0), datMTI_DEATH_PLUS_OneRec)
				End If
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>死亡情報＋名称</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDeathPlusOneRecDa(ByVal pPatientNo As String) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getDeathPlusOneRecDa(db, pPatientNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報＋名称を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>死亡情報＋名称</returns>
	''' <remarks>
	''' 2010/10/26 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getDeathPlusOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable
			If setSqlParam(db, sqlMTI_DEATH.Enum_SqlNo.sqlSelDeath_Plus_OneRec_Da, pPatientNo) Then
				db.execQueryDa(retDat)	'値取得
			End If
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelDeathOneRec(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "死亡情報アクセスクラス", "死亡情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_DEATH.sqlDelDeath_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_DEATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
				db.setVal(sqlMTI_DEATH.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pDeathRec">死亡情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsDeathOneRec(ByVal db As clsDB, ByVal pDeathRec As datMTI_DEATH_OneRec) As Integer
		Try
			Return execInsDeathOneRec(db, pDeathRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pDeathRec">死亡情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsDeathOneRec(ByVal db As clsDB, ByVal pDeathRec As datMTI_DEATH_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "死亡情報アクセスクラス", "死亡情報１データを追加 Start")
		Try
			If pDeathRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_DEATH.sqlInsDeath_OneRec)
			' 患者番号
			db.setParam(sqlMTI_DEATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmPATIENT_NO, pDeathRec.PATIENT_NO)
			' 死亡日
			db.setParam(sqlMTI_DEATH.prmDEATH_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_DEATH.prmDEATH_DT, pDeathRec.DEATH_DT)
			' 死亡時刻
			db.setParam(sqlMTI_DEATH.prmDEATH_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_TIME, pDeathRec.DEATH_TIME)
			' 死亡時年齢
			db.setParam(sqlMTI_DEATH.prmDEATH_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_DEATH.prmDEATH_AGE, pDeathRec.DEATH_AGE, False)
			' 死亡時月齢
			db.setParam(sqlMTI_DEATH.prmDEATH_MONTH_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_DEATH.prmDEATH_MONTH_AGE, pDeathRec.DEATH_MONTH_AGE, False)
			' 死亡時日齢
			db.setParam(sqlMTI_DEATH.prmDEATH_DAY_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_DEATH.prmDEATH_DAY_AGE, pDeathRec.DEATH_DAY_AGE, False)
			' 剖検有無区分コード
			db.setParam(sqlMTI_DEATH.prmAUTOPSY_CHK, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmAUTOPSY_CHK, pDeathRec.AUTOPSY_CHK)
			' 剖検番号
			db.setParam(sqlMTI_DEATH.prmAUTOPSY_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmAUTOPSY_NO, pDeathRec.AUTOPSY_NO)
			' 死亡区分コード
			db.setParam(sqlMTI_DEATH.prmDEATH_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DIV, pDeathRec.DEATH_DIV)
			' 術後死亡区分コード
			db.setParam(sqlMTI_DEATH.prmAFTER_OPE_DEATH_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmAFTER_OPE_DEATH_DIV, pDeathRec.AFTER_OPE_DEATH_DIV)
			' 死亡場所コード
			db.setParam(sqlMTI_DEATH.prmDEATH_LCT_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_LCT_CD, pDeathRec.DEATH_LCT_CD)
			' 死亡場所
			db.setParam(sqlMTI_DEATH.prmDEATH_LCT, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_LCT, pDeathRec.DEATH_LCT)
			' 死亡病名１コード
			db.setParam(sqlMTI_DEATH.prmDEATH_DISEASE1_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DISEASE1_CD, pDeathRec.DEATH_DISEASE1_CD)
			' 死亡病名１
			db.setParam(sqlMTI_DEATH.prmDEATH_DISEASE1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DISEASE1, pDeathRec.DEATH_DISEASE1)
			' 死亡病名２コード
			db.setParam(sqlMTI_DEATH.prmDEATH_DISEASE2_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DISEASE2_CD, pDeathRec.DEATH_DISEASE2_CD)
			' 死亡病名２
			db.setParam(sqlMTI_DEATH.prmDEATH_DISEASE2, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DISEASE2, pDeathRec.DEATH_DISEASE2)
			' コメント
			db.setParam(sqlMTI_DEATH.prmDEATH_REMARKS, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_REMARKS, pDeathRec.DEATH_REMARKS)
			' 更新者コード
			db.setParam(sqlMTI_DEATH.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pDeathRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_DEATH.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_DEATH.prmLASTUPDUSER_CD, pDeathRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_DEATH.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pDeathRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_DEATH.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_DEATH.prmLASTUPD_DT, pDeathRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pDeathPlusRec">死亡情報＋名称クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsDeathOneRec(ByVal db As clsDB, ByVal pDeathPlusRec As datMTI_DEATH_PLUS_OneRec) As Integer
		Try
			Return execInsDeathOneRec(db, pDeathPlusRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 死亡情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pDeathPlusRec">死亡情報＋名称クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsDeathOneRec(ByVal db As clsDB, ByVal pDeathPlusRec As datMTI_DEATH_PLUS_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "死亡情報アクセスクラス", "死亡情報１データを追加 Start")
		Try
			If pDeathPlusRec Is Nothing Then
				Return 0
			End If
			' INSERT文設定
			db.setSQL(sqlMTI_DEATH.sqlInsDeath_OneRec)
			' 患者番号
			db.setParam(sqlMTI_DEATH.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmPATIENT_NO, pDeathPlusRec.PATIENT_NO)
			' 死亡日
			db.setParam(sqlMTI_DEATH.prmDEATH_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_DEATH.prmDEATH_DT, pDeathPlusRec.DEATH_DT)
			' 死亡時刻
			db.setParam(sqlMTI_DEATH.prmDEATH_TIME, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_TIME, pDeathPlusRec.DEATH_TIME)
			' 死亡時年齢
			db.setParam(sqlMTI_DEATH.prmDEATH_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_DEATH.prmDEATH_AGE, pDeathPlusRec.DEATH_AGE, False)
			' 死亡時月齢
			db.setParam(sqlMTI_DEATH.prmDEATH_MONTH_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_DEATH.prmDEATH_MONTH_AGE, pDeathPlusRec.DEATH_MONTH_AGE, False)
			' 死亡時日齢
			db.setParam(sqlMTI_DEATH.prmDEATH_DAY_AGE, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_DEATH.prmDEATH_DAY_AGE, pDeathPlusRec.DEATH_DAY_AGE, False)
			' 剖検有無区分コード
			db.setParam(sqlMTI_DEATH.prmAUTOPSY_CHK, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmAUTOPSY_CHK, pDeathPlusRec.AUTOPSY_CHK)
			' 剖検番号
			db.setParam(sqlMTI_DEATH.prmAUTOPSY_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmAUTOPSY_NO, pDeathPlusRec.AUTOPSY_NO)
			' 死亡区分コード
			db.setParam(sqlMTI_DEATH.prmDEATH_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DIV, pDeathPlusRec.DEATH_DIV)
			' 術後死亡区分コード
			db.setParam(sqlMTI_DEATH.prmAFTER_OPE_DEATH_DIV, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmAFTER_OPE_DEATH_DIV, pDeathPlusRec.AFTER_OPE_DEATH_DIV)
			' 死亡場所コード
			db.setParam(sqlMTI_DEATH.prmDEATH_LCT_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_LCT_CD, pDeathPlusRec.DEATH_LCT_CD)
			' 死亡場所
			db.setParam(sqlMTI_DEATH.prmDEATH_LCT, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_LCT, pDeathPlusRec.DEATH_LCT)
			' 死亡病名１コード
			db.setParam(sqlMTI_DEATH.prmDEATH_DISEASE1_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DISEASE1_CD, pDeathPlusRec.DEATH_DISEASE1_CD)
			' 死亡病名１
			db.setParam(sqlMTI_DEATH.prmDEATH_DISEASE1, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DISEASE1, pDeathPlusRec.DEATH_DISEASE1)
			' 死亡病名２コード
			db.setParam(sqlMTI_DEATH.prmDEATH_DISEASE2_CD, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DISEASE2_CD, pDeathPlusRec.DEATH_DISEASE2_CD)
			' 死亡病名２
			db.setParam(sqlMTI_DEATH.prmDEATH_DISEASE2, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_DISEASE2, pDeathPlusRec.DEATH_DISEASE2)
			' コメント
			db.setParam(sqlMTI_DEATH.prmDEATH_REMARKS, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_DEATH.prmDEATH_REMARKS, pDeathPlusRec.DEATH_REMARKS)
			' 更新者コード
			db.setParam(sqlMTI_DEATH.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pDeathPlusRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_DEATH.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_DEATH.prmLASTUPDUSER_CD, pDeathPlusRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_DEATH.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pDeathPlusRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_DEATH.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_DEATH.prmLASTUPD_DT, pDeathPlusRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
