﻿Imports XCM
Imports System.Reflection

''' ---------------------------------------------
''' <summary>
''' 医療費情報アクセスクラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class clsMTI_MED_COST
	Implements IDisposable

#Region "解放処理"

	'解放処理時使用＊＊
	Protected disposed As Boolean = False

	''' ---------------------------------------------	
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If Not Me.disposed Then
		End If
		Me.disposed = True
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------	
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' </summary>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New()
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String) As Boolean
		Try
			Return Not String.IsNullOrWhiteSpace(pPatientNo)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo) AndAlso (pHspHistoryNo > 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータの整合性のチェック
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>True:正常</returns>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkParam(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As Boolean
		Try
			Return chkParam(pPatientNo, pHspHistoryNo) AndAlso (pChNo >= 0)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の医療費情報を取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の医療費情報（ArrayList内にdatMTI_MED_COST_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostHsp(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostHsp(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の医療費情報を取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の医療費情報（ArrayList内にdatMTI_MED_COST_OneRecクラス）</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As ArrayList
		Dim retData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			retData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_MED_COST.sqlSelMedCost_Hsp)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_MED_COST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setVal(sqlMTI_MED_COST.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_MED_COST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			iRet = db.execQuery(GetType(datMTI_MED_COST_OneRec), retData)	'値取得
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retData
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の医療費情報を取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の医療費情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostHspDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostHspDa(db, pPatientNo, pHspHistoryNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の医療費情報を取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <returns>１入退院分の医療費情報</returns>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostHspDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST.sqlSelMedCost_Hsp)

			db.setParamDa(sqlMTI_MED_COST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_MED_COST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setValDa(sqlMTI_MED_COST.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_MED_COST.prmHSP_HISTORY_NO, pHspHistoryNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>医療費情報クラス</returns>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostOneRec(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_MED_COST_OneRec
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostOneRec(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費情報を１件取得します（データクラス）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>医療費情報クラス</returns>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As datMTI_MED_COST_OneRec
		Dim retDat As datMTI_MED_COST_OneRec = Nothing
		Dim arData As ArrayList = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()

			'キーチェック
			If Not chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				Return Nothing
			End If

			db.setSQL(sqlMTI_MED_COST.sqlSelMedCost_OneRec)	'SELECT文設定
			db.setParam(sqlMTI_MED_COST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParam(sqlMTI_MED_COST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParam(sqlMTI_MED_COST.prmCH_NO, clsDB.Enum_dbType.dbInt)			'科歴番号
			db.setVal(sqlMTI_MED_COST.prmPATIENT_NO, pPatientNo)
			db.setVal(sqlMTI_MED_COST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setVal(sqlMTI_MED_COST.prmCH_NO, pChNo, False)
			iRet = db.execQuery(GetType(datMTI_MED_COST_OneRec), arData)	'値取得
			If iRet > 0 Then									   'レコードあり
				retDat = DirectCast(arData(0), datMTI_MED_COST_OneRec)
			Else
				retDat = Nothing
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>医療費情報</returns>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostOneRecDa(ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Try
			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData)
				Return getMedCostOneRecDa(db, pPatientNo, pHspHistoryNo, pChNo)
			End Using
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費情報を１件取得します（データテーブル）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <returns>医療費情報</returns>
	''' <remarks>
	''' 2010/11/30 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function getMedCostOneRecDa(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer) As DataTable
		Dim retDat As DataTable = Nothing
		Try
			retDat = New DataTable

			'SQL文設定
			db.setSQLDa(sqlMTI_MED_COST.sqlSelMedCost_OneRec)

			db.setParamDa(sqlMTI_MED_COST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	'患者番号
			db.setParamDa(sqlMTI_MED_COST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)	'入退院歴番号
			db.setParamDa(sqlMTI_MED_COST.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
			db.setValDa(sqlMTI_MED_COST.prmPATIENT_NO, pPatientNo)
			db.setValDa(sqlMTI_MED_COST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
			db.setValDa(sqlMTI_MED_COST.prmCH_NO, pChNo, False)

			'値取得
			db.execQueryDa(retDat)
		Catch ex As Exception
			Throw
		End Try
		'返り値設定
		Return retDat
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' １患者分の医療費情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelMedCostPatient(ByVal db As clsDB, ByVal pPatientNo As String)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費情報アクセスクラス", "１患者分の医療費情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo) Then
				' 削除実行
				db.setSQL(sqlMTI_MED_COST.sqlDelMedCost_Patient)	'DELETE文設定
				db.setParam(sqlMTI_MED_COST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setVal(sqlMTI_MED_COST.prmPATIENT_NO, pPatientNo)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' １入退院分の医療費情報を削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelMedCostHsp(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費情報アクセスクラス", "１入退院分の医療費情報を削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo) Then
				' 削除実行
				db.setSQL(sqlMTI_MED_COST.sqlDelMedCost_Hsp)	'DELETE文設定
				db.setParam(sqlMTI_MED_COST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_MED_COST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setVal(sqlMTI_MED_COST.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_MED_COST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 医療費情報１データを削除します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pPatientNo">患者番号</param>
	''' <param name="pHspHistoryNo">入退院歴番号</param>
	''' <param name="pChNo">科歴番号</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub execDelMedCostOneRec(ByVal db As clsDB, ByVal pPatientNo As String, ByVal pHspHistoryNo As Integer, ByVal pChNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費情報アクセスクラス", "医療費情報１データを削除 Start")
		Try
			'キーチェック
			If chkParam(pPatientNo, pHspHistoryNo, pChNo) Then
				' 削除実行
				db.setSQL(sqlMTI_MED_COST.sqlDelMedCost_OneRec)	'DELETE文設定
				db.setParam(sqlMTI_MED_COST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)		'患者番号
				db.setParam(sqlMTI_MED_COST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)		'入退院歴番号
				db.setParam(sqlMTI_MED_COST.prmCH_NO, clsDB.Enum_dbType.dbInt)				'科歴番号
				db.setVal(sqlMTI_MED_COST.prmPATIENT_NO, pPatientNo)
				db.setVal(sqlMTI_MED_COST.prmHSP_HISTORY_NO, pHspHistoryNo, False)
				db.setVal(sqlMTI_MED_COST.prmCH_NO, pChNo, False)
				db.execNonQuery(False)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 医療費情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pMedCostRec">医療費情報クラス</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsMedCostOneRec(ByVal db As clsDB, ByVal pMedCostRec As datMTI_MED_COST_OneRec) As Integer
		Try
			Return execInsMedCostOneRec(db, pMedCostRec, True)
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 医療費情報１データを追加します
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <param name="pMedCostRec">医療費情報クラス</param>
	''' <param name="bLastUpdate">最終更新日の変更可否</param>
	''' <remarks>
	''' 2010/12/07 新規作成 CS)溝渕<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function execInsMedCostOneRec(ByVal db As clsDB, ByVal pMedCostRec As datMTI_MED_COST_OneRec, ByVal bLastUpdate As Boolean) As Integer
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, MethodBase.GetCurrentMethod.Name, "共通基盤", "医療費情報アクセスクラス", "医療費情報１データを追加 Start")
		Try
			If pMedCostRec Is Nothing Then
				Return 0
			End If
			Select Case False
				Case (pMedCostRec.MED_COST01 = 0)
				Case (pMedCostRec.MED_COST02 = 0)
				Case (pMedCostRec.MED_COST03 = 0)
				Case (pMedCostRec.MED_COST04 = 0)
				Case (pMedCostRec.MED_COST05 = 0)
				Case (pMedCostRec.MED_COST06 = 0)
				Case (pMedCostRec.MED_COST07 = 0)
				Case (pMedCostRec.MED_COST08 = 0)
				Case (pMedCostRec.MED_COST09 = 0)
				Case (pMedCostRec.MED_COST10 = 0)
				Case (pMedCostRec.MED_COST11 = 0)
				Case (pMedCostRec.MED_COST12 = 0)
				Case (pMedCostRec.MED_COST13 = 0)
				Case (pMedCostRec.MED_COST14 = 0)
				Case (pMedCostRec.MED_COST15 = 0)
				Case (pMedCostRec.MED_COST16 = 0)
				Case (pMedCostRec.MED_COST17 = 0)
				Case (pMedCostRec.MED_COST18 = 0)
				Case (pMedCostRec.MED_COST19 = 0)
				Case (pMedCostRec.MED_COST20 = 0)
				Case (pMedCostRec.MED_COST21 = 0)
				Case (pMedCostRec.MED_COST22 = 0)
				Case (pMedCostRec.MED_COST23 = 0)
				Case (pMedCostRec.MED_COST24 = 0)
				Case (pMedCostRec.MED_COST25 = 0)
				Case (pMedCostRec.MED_COST26 = 0)
				Case (pMedCostRec.MED_COST27 = 0)
				Case (pMedCostRec.MED_COST28 = 0)
				Case (pMedCostRec.MED_COST29 = 0)
				Case (pMedCostRec.MED_COST30 = 0)
				Case (pMedCostRec.MED_COST31 = 0)
				Case (pMedCostRec.MED_COST32 = 0)
				Case (pMedCostRec.MED_COST33 = 0)
				Case (pMedCostRec.MED_COST34 = 0)
				Case (pMedCostRec.MED_COST35 = 0)
				Case (pMedCostRec.MED_COST36 = 0)
				Case (pMedCostRec.MED_COST37 = 0)
				Case (pMedCostRec.MED_COST38 = 0)
				Case (pMedCostRec.MED_COST39 = 0)
				Case (pMedCostRec.MED_COST40 = 0)
				Case (pMedCostRec.MED_COST41 = 0)
				Case (pMedCostRec.MED_COST42 = 0)
				Case (pMedCostRec.MED_COST43 = 0)
				Case (pMedCostRec.MED_COST44 = 0)
				Case (pMedCostRec.MED_COST45 = 0)
				Case Else
					' 医療費が全て０なら追加しない
					Return 0
			End Select
			' INSERT文設定
			db.setSQL(sqlMTI_MED_COST.sqlInsMedCost_OneRec)
			' 患者番号
			db.setParam(sqlMTI_MED_COST.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
			db.setVal(sqlMTI_MED_COST.prmPATIENT_NO, pMedCostRec.PATIENT_NO)
			' 入退院歴番号
			db.setParam(sqlMTI_MED_COST.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmHSP_HISTORY_NO, pMedCostRec.HSP_HISTORY_NO, False)
			' 科歴番号
			db.setParam(sqlMTI_MED_COST.prmCH_NO, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmCH_NO, pMedCostRec.CH_NO, False)
			' 医療費０１
			db.setParam(sqlMTI_MED_COST.prmMED_COST01, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST01, pMedCostRec.MED_COST01, False)
			' 医療費０２
			db.setParam(sqlMTI_MED_COST.prmMED_COST02, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST02, pMedCostRec.MED_COST02, False)
			' 医療費０３
			db.setParam(sqlMTI_MED_COST.prmMED_COST03, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST03, pMedCostRec.MED_COST03, False)
			' 医療費０４
			db.setParam(sqlMTI_MED_COST.prmMED_COST04, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST04, pMedCostRec.MED_COST04, False)
			' 医療費０５
			db.setParam(sqlMTI_MED_COST.prmMED_COST05, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST05, pMedCostRec.MED_COST05, False)
			' 医療費０６
			db.setParam(sqlMTI_MED_COST.prmMED_COST06, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST06, pMedCostRec.MED_COST06, False)
			' 医療費０７
			db.setParam(sqlMTI_MED_COST.prmMED_COST07, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST07, pMedCostRec.MED_COST07, False)
			' 医療費０８
			db.setParam(sqlMTI_MED_COST.prmMED_COST08, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST08, pMedCostRec.MED_COST08, False)
			' 医療費０９
			db.setParam(sqlMTI_MED_COST.prmMED_COST09, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST09, pMedCostRec.MED_COST09, False)
			' 医療費１０
			db.setParam(sqlMTI_MED_COST.prmMED_COST10, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST10, pMedCostRec.MED_COST10, False)
			' 医療費１１
			db.setParam(sqlMTI_MED_COST.prmMED_COST11, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST11, pMedCostRec.MED_COST11, False)
			' 医療費１２
			db.setParam(sqlMTI_MED_COST.prmMED_COST12, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST12, pMedCostRec.MED_COST12, False)
			' 医療費１３
			db.setParam(sqlMTI_MED_COST.prmMED_COST13, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST13, pMedCostRec.MED_COST13, False)
			' 医療費１４
			db.setParam(sqlMTI_MED_COST.prmMED_COST14, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST14, pMedCostRec.MED_COST14, False)
			' 医療費１５
			db.setParam(sqlMTI_MED_COST.prmMED_COST15, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST15, pMedCostRec.MED_COST15, False)
			' 医療費１６
			db.setParam(sqlMTI_MED_COST.prmMED_COST16, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST16, pMedCostRec.MED_COST16, False)
			' 医療費１７
			db.setParam(sqlMTI_MED_COST.prmMED_COST17, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST17, pMedCostRec.MED_COST17, False)
			' 医療費１８
			db.setParam(sqlMTI_MED_COST.prmMED_COST18, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST18, pMedCostRec.MED_COST18, False)
			' 医療費１９
			db.setParam(sqlMTI_MED_COST.prmMED_COST19, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST19, pMedCostRec.MED_COST19, False)
			' 医療費２０
			db.setParam(sqlMTI_MED_COST.prmMED_COST20, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST20, pMedCostRec.MED_COST20, False)
			' 医療費２１
			db.setParam(sqlMTI_MED_COST.prmMED_COST21, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST21, pMedCostRec.MED_COST21, False)
			' 医療費２２
			db.setParam(sqlMTI_MED_COST.prmMED_COST22, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST22, pMedCostRec.MED_COST22, False)
			' 医療費２３
			db.setParam(sqlMTI_MED_COST.prmMED_COST23, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST23, pMedCostRec.MED_COST23, False)
			' 医療費２４
			db.setParam(sqlMTI_MED_COST.prmMED_COST24, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST24, pMedCostRec.MED_COST24, False)
			' 医療費２５
			db.setParam(sqlMTI_MED_COST.prmMED_COST25, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST25, pMedCostRec.MED_COST25, False)
			' 医療費２６
			db.setParam(sqlMTI_MED_COST.prmMED_COST26, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST26, pMedCostRec.MED_COST26, False)
			' 医療費２７
			db.setParam(sqlMTI_MED_COST.prmMED_COST27, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST27, pMedCostRec.MED_COST27, False)
			' 医療費２８
			db.setParam(sqlMTI_MED_COST.prmMED_COST28, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST28, pMedCostRec.MED_COST28, False)
			' 医療費２９
			db.setParam(sqlMTI_MED_COST.prmMED_COST29, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST29, pMedCostRec.MED_COST29, False)
			' 医療費３０
			db.setParam(sqlMTI_MED_COST.prmMED_COST30, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST30, pMedCostRec.MED_COST30, False)
			' 医療費３１
			db.setParam(sqlMTI_MED_COST.prmMED_COST31, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST31, pMedCostRec.MED_COST31, False)
			' 医療費３２
			db.setParam(sqlMTI_MED_COST.prmMED_COST32, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST32, pMedCostRec.MED_COST32, False)
			' 医療費３３
			db.setParam(sqlMTI_MED_COST.prmMED_COST33, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST33, pMedCostRec.MED_COST33, False)
			' 医療費３４
			db.setParam(sqlMTI_MED_COST.prmMED_COST34, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST34, pMedCostRec.MED_COST34, False)
			' 医療費３５
			db.setParam(sqlMTI_MED_COST.prmMED_COST35, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST35, pMedCostRec.MED_COST35, False)
			' 医療費３６
			db.setParam(sqlMTI_MED_COST.prmMED_COST36, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST36, pMedCostRec.MED_COST36, False)
			' 医療費３７
			db.setParam(sqlMTI_MED_COST.prmMED_COST37, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST37, pMedCostRec.MED_COST37, False)
			' 医療費３８
			db.setParam(sqlMTI_MED_COST.prmMED_COST38, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST38, pMedCostRec.MED_COST38, False)
			' 医療費３９
			db.setParam(sqlMTI_MED_COST.prmMED_COST39, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST39, pMedCostRec.MED_COST39, False)
			' 医療費４０
			db.setParam(sqlMTI_MED_COST.prmMED_COST40, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST40, pMedCostRec.MED_COST40, False)
			' 医療費４１
			db.setParam(sqlMTI_MED_COST.prmMED_COST41, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST41, pMedCostRec.MED_COST41, False)
			' 医療費４２
			db.setParam(sqlMTI_MED_COST.prmMED_COST42, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST42, pMedCostRec.MED_COST42, False)
			' 医療費４３
			db.setParam(sqlMTI_MED_COST.prmMED_COST43, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST43, pMedCostRec.MED_COST43, False)
			' 医療費４４
			db.setParam(sqlMTI_MED_COST.prmMED_COST44, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST44, pMedCostRec.MED_COST44, False)
			' 医療費４５
			db.setParam(sqlMTI_MED_COST.prmMED_COST45, clsDB.Enum_dbType.dbInt)
			db.setVal(sqlMTI_MED_COST.prmMED_COST45, pMedCostRec.MED_COST45, False)
			' データ取込日
			db.setParam(sqlMTI_MED_COST.prmDATA_CAPTURE_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_MED_COST.prmDATA_CAPTURE_DT, pMedCostRec.DATA_CAPTURE_DT)
			' 新規登録日
			db.setParam(sqlMTI_MED_COST.prmNEW_REG_DT, clsDB.Enum_dbType.dbDateTime)
			db.setVal(sqlMTI_MED_COST.prmNEW_REG_DT, pMedCostRec.NEW_REG_DT)
			' 更新者コード
			db.setParam(sqlMTI_MED_COST.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
			If bLastUpdate OrElse String.IsNullOrEmpty(pMedCostRec.LASTUPDUSER_CD) Then
				' 更新者コード←ログインＩＤ
				db.setVal(sqlMTI_MED_COST.prmLASTUPDUSER_CD, clsSysMst.getLoginId)
			Else
				db.setVal(sqlMTI_MED_COST.prmLASTUPDUSER_CD, pMedCostRec.LASTUPDUSER_CD)
			End If
			' 最終更新日
			db.setParam(sqlMTI_MED_COST.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			If bLastUpdate OrElse pMedCostRec.LASTUPD_DT.Equals(Nothing) Then
				' 最終更新日←システム日付
				db.setVal(sqlMTI_MED_COST.prmLASTUPD_DT, Now())
			Else
				db.setVal(sqlMTI_MED_COST.prmLASTUPD_DT, pMedCostRec.LASTUPD_DT)
			End If
			' 追加実行
			Return db.execNonQuery(False)
		Catch ex As Exception
			Throw
		End Try
	End Function
End Class
